@@ -1,13 +1,5 @@
 $(document).ready(function() {
 
-    // javascript code to enable download links of notebooks and scripts *.py
-    // https://stackoverflow.com/questions/2304941
-    if (document.readyState == "interactive") {
-         document.getElementsByClassName("last")[0].children[0].children[0].setAttribute("target", "_blank")
-         document.getElementsByClassName("last")[0].children[2].children[1].setAttribute("download", "")
-         document.getElementsByClassName("last")[0].children[2].children[2].setAttribute("download", "")
-     }
-
     // add info note for past releases
     var verFile = new XMLHttpRequest();
     verFile.open("GET", "https://docs.gammapy.org/stable/index.html", true);
