@@ -7,7 +7,7 @@ from gammapy.astro.population import FaucherSpiral
 from gammapy.utils.coordinates import polar, cartesian
 
 catalog = simulate.make_base_catalog_galactic(
-    n_sources=int(1e4), rad_dis="YK04", vel_dis="H05", max_age=Quantity(1E6, "yr")
+    n_sources=int(1e4), rad_dis="YK04", vel_dis="H05", max_age=Quantity(1e6, "yr")
 )
 
 spiral = FaucherSpiral()
