@@ -12,12 +12,12 @@ for key in velocity_distributions:
     label = model.__class__.__name__
     x = velocity.value
     y = normalize(model, velocity[0].value, velocity[-1].value)(velocity.value)
-    plt.plot(x, y, linestyle='-', label=label)
+    plt.plot(x, y, linestyle="-", label=label)
 
 plt.xlim(velocity[0].value, velocity[-1].value)
 plt.ylim(0, 0.005)
-plt.xlabel('Velocity [km/s]')
-plt.ylabel('Probability Density [(km / s)^-1]')
+plt.xlabel("Velocity [km/s]")
+plt.ylabel("Probability Density [(km / s)^-1]")
 plt.semilogx()
-plt.legend(prop={'size': 10})
+plt.legend(prop={"size": 10})
 plt.show()
