@@ -11,6 +11,6 @@ pulsar = Pulsar(P_0=Quantity(0.01, "s"), logB=12)
 plt.plot(t.value, 1 / pulsar.period(t).cgs.value)
 plt.xlabel("time [years]")
 plt.ylabel("frequency [1/s]")
-plt.ylim(1E0, 1E2)
+plt.ylim(1e0, 1e2)
 plt.loglog()
 plt.show()
