@@ -1,7 +1,5 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-"""
-Astrophysical source models.
-"""
+"""Astrophysical source models."""
 from .pulsar import *
 from .snr import *
 from .pwn import *
