@@ -1,7 +1,5 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-"""
-Source catalogs and objects.
-"""
+"""Source catalogs."""
 from .core import *
 from .fermi import *
 from .hawc import *
@@ -10,4 +8,3 @@ from .gammacat import *
 from .registry import *
 from .snrcat import *
 from .utils import *
-from .xmatch import *
