@@ -56,12 +56,11 @@ SOURCES = [
 
 @pytest.fixture(scope="session")
 def gammacat():
-    filename = "$GAMMAPY_EXTRA/datasets/catalogs/gammacat/gammacat.fits.gz"
+    filename = "$GAMMAPY_DATA/catalogs/gammacat/gammacat.fits.gz"
     return SourceCatalogGammaCat(filename=filename)
 
 
-@requires_data("gammapy-extra")
-@requires_data("gamma-cat")
+@requires_data("gammapy-data")
 class TestSourceCatalogGammaCat:
     def test_source_table(self, gammacat):
         assert gammacat.name == "gamma-cat"
@@ -79,12 +78,12 @@ class TestSourceCatalogGammaCat:
         for name in names:
             assert str(gammacat[name]) == str(gammacat["W28"])
 
-    def test_sort_table(self):
+    def test_sort_table(self, gammacat):
         name = "HESS J1848-018"
         sort_keys = ["ra", "dec", "reference_id"]
         for sort_key in sort_keys:
             # this test modifies the catalog, so we make a copy
-            cat = gammacat()
+            cat = gammacat.copy()
             cat.table.sort(sort_key)
             assert cat[name].name == name
 
@@ -97,8 +96,7 @@ class TestSourceCatalogGammaCat:
         assert_allclose(source.spectral_model.parameters["index"].value, 2.2)
 
 
-@requires_data("gammapy-extra")
-@requires_data("gamma-cat")
+@requires_data("gammapy-data")
 class TestSourceCatalogObjectGammaCat:
     def test_data(self, gammacat):
         source = gammacat[0]
