@@ -2,9 +2,22 @@
 # by importing them here in conftest.py they are discoverable by py.test
 # no matter how it is invoked within the source tree.
 import os
-from astropy.tests.pytest_plugins import PYTEST_HEADER_MODULES, TESTED_VERSIONS
 from . import version
 
+from astropy.version import version as astropy_version
+
+if astropy_version < "3.0":
+    # With older versions of Astropy, we actually need to import the pytest
+    # plugins themselves in order to make them discoverable by pytest.
+    from astropy.tests.pytest_plugins import *
+else:
+    # As of Astropy 3.0, the pytest plugins provided by Astropy are
+    # automatically made available when Astropy is installed. This means it's
+    # not necessary to import them here, but we still need to import global
+    # variables that are used for configuration.
+    from astropy.tests.plugins.display import PYTEST_HEADER_MODULES, TESTED_VERSIONS
+
+
 packagename = os.path.basename(os.path.dirname(__file__))
 TESTED_VERSIONS[packagename] = version.version
 
@@ -32,13 +45,13 @@ def pytest_configure(config):
     print("")
     print("Gammapy test data availability:")
 
-    has_it = "yes" if has_data("gammapy-extra") else "no"
-    print("gammapy-extra ... {}".format(has_it))
+    has_it = "yes" if has_data("gammapy-data") else "no"
+    print("gammapy-data ... {}".format(has_it))
 
     print("Gammapy environment variables:")
 
-    var = os.environ.get("GAMMAPY_EXTRA", "not set")
-    print("GAMMAPY_EXTRA = {}".format(var))
+    var = os.environ.get("GAMMAPY_DATA", "not set")
+    print("GAMMAPY_DATA = {}".format(var))
 
     try:
         # Switch to non-interactive plotting backend to avoid GUI windows
