@@ -14,7 +14,9 @@ pytest.importorskip("healpy")
 
 @pytest.fixture(scope="session")
 def aeff():
-    filename = "$GAMMAPY_EXTRA/datasets/cta-1dc/caldb/data/cta/1dc/bcf/South_z20_50h/irf_file.fits"
+    filename = (
+        "$GAMMAPY_DATA/cta-1dc/caldb/data/cta/1dc/bcf/South_z20_50h/irf_file.fits"
+    )
     return EffectiveAreaTable2D.read(filename, hdu="EFFECTIVE AREA")
 
 
@@ -28,7 +30,7 @@ def geom(map_type, ebounds):
         raise ValueError()
 
 
-@requires_data("gammapy-extra")
+@requires_data("gammapy-data")
 @pytest.mark.parametrize(
     "pars",
     [
