@@ -1,22 +1,13 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-"""
-Data and observation handling.
-"""
-
-
-class InvalidDataError(Exception):
-    """Invalid data found."""
-
-from .utils import *
-from .target import *
+"""Data and observation handling."""
 from .pointing import *
-from .data_manager import *
 from .data_store import *
 from .event_list import *
 from .gti import *
 from .hdu_index_table import *
 from .observers import *
 from .obs_table import *
-from .obs_group import *
 from .obs_summary import *
 from .obs_stats import *
+from .observations import *
+from .filters import *
