@@ -20,7 +20,7 @@ class DataStore(object):
     The data selection and access happens using an observation
     and an HDU index file as described at :ref:`gadf:iact-storage`.
 
-    See :gp-extra-notebook:`cta_1dc_introduction` for usage examples.
+    See :gp-notebook:`cta_1dc_introduction` for usage examples.
 
     Parameters
     ----------
