@@ -268,6 +268,16 @@ class EventListBase(object):
 
     def select_time(self, time_interval):
         """Select events in time interval.
+
+        Parameters
+        ----------
+        time_interval : `astropy.time.Time`
+            Start time (inclusive) and stop time (exclusive) for the selection.
+
+        Returns
+        -------
+        events : `EventList`
+            Copy of event list with selection applied.
         """
         time = self.time
         mask = time_interval[0] <= time
@@ -369,6 +379,33 @@ class EventListBase(object):
             mask = np.union1d(mask, temp)
         return mask
 
+    def select_parameter(self, parameter, band):
+        """Select events with respect to a specified parameter
+
+        Parameters
+        ----------
+        parameter : str
+            Parameter used for the selection. Must be present in `self.table`.
+        band : tuple or `astropy.units.Quantity`
+            Min and max value for the parameter to be selected (min <= parameter < max).
+            If parameter is not dimensionless you have to provide a Quantity.
+
+        Returns
+        -------
+        event_list : `EventList`
+            Copy of event list with selection applied.
+
+        Examples
+        --------
+        >>> from gammapy.data import EventList
+        >>> event_list = EventList.read('events.fits')
+        >>> phase_region = (0.3, 0.5)
+        >>> event_list = event_list.select_parameter(parameter='PHASE', band=phase_region)
+        """
+        mask = band[0] <= self.table[parameter].quantity
+        mask &= self.table[parameter].quantity < band[1]
+        return self.select_row_subset(mask)
+
     def _default_plot_ebounds(self):
         energy = self.energy
         return EnergyBounds.equal_log_spacing(energy.min(), energy.max(), 50)
@@ -685,10 +722,10 @@ class EventListLAT(EventListBase):
 
     Examples
     --------
-    To load an example Fermi-LAT event list (the one corresponding to the 2FHL catalog dataset):
+    To load an example Fermi-LAT event list:
 
     >>> from gammapy.data import EventListLAT
-    >>> filename = '$GAMMAPY_DATA/fermi_2fhl/2fhl_events.fits.gz'
+    >>> filename = "$GAMMAPY_DATA/fermi-3fhl-gc/fermi-3fhl-gc-events.fits.gz"
     >>> events = EventListLAT.read(filename)
     """
 
@@ -800,11 +837,11 @@ class EventListChecker(Checker):
 
     def check_times(self):
         dt = (self.event_list.time - self.event_list.observation_time_start).sec
-        if dt.min() < self.accuracy["time"].to("s").value:
+        if dt.min() < self.accuracy["time"].to_value("s"):
             yield self._record(level="error", msg="Event times before obs start time")
 
         dt = (self.event_list.time - self.event_list.observation_time_end).sec
-        if dt.max() > self.accuracy["time"].to("s").value:
+        if dt.max() > self.accuracy["time"].to_value("s"):
             yield self._record(level="error", msg="Event times after the obs end time")
 
         if np.min(np.diff(dt)) <= 0:
