@@ -1,5 +1,6 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 from __future__ import absolute_import, division, print_function, unicode_literals
+import copy
 import logging
 
 __all__ = ["ObservationFilter"]
@@ -30,7 +31,7 @@ class ObservationFilter(object):
     >>> from astropy.coordinates import Angle
     >>>
     >>> time_filter = Time(['2021-03-27T20:10:00', '2021-03-27T20:20:00'])
-    >>> phase_filter = {'type': 'custom', 'opts': dict(parameter='PHASE', limits=(0.2, 0.8))}
+    >>> phase_filter = {'type': 'custom', 'opts': dict(parameter='PHASE', band=(0.2, 0.8))}
     >>>
     >>> my_obs_filter = ObservationFilter(time_filter=time_filter, event_filters=[phase_filter])
     >>>
@@ -39,9 +40,7 @@ class ObservationFilter(object):
     """
 
     EVENT_FILTER_TYPES = dict(
-        box_region="select_sky_box",
-        circular_region="select_circular_region",
-        custom="select_custom",
+        circular_region="select_circular_region", custom="select_parameter"
     )
 
     def __init__(self, time_filter=None, event_filters=None):
@@ -95,3 +94,7 @@ class ObservationFilter(object):
             return data.select_time(self.time_filter)
         else:
             return data
+
+    def copy(self):
+        """Copy the `ObservationFilter` object."""
+        return copy.deepcopy(self)
