@@ -1,6 +1,5 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 from __future__ import absolute_import, division, print_function, unicode_literals
-import numpy as np
 import astropy.units as u
 from ..stats import Stats, significance_on_off
 
@@ -25,27 +24,12 @@ class ObservationStats(Stats):
         Relative background exposure of the off region
     obs_id : int
         ID of the observation
-    livetime : float
+    livetime : `~astropy.units.Quantity`
         Livetime of the observation
-    alpha : float
-        Normalisation between the on and the off exposure
-    bg_rate : float
-        Background rate (/min)
-    gamma_rate : float
-        Gamma rate (/min)
     """
 
     def __init__(
-        self,
-        n_on=None,
-        n_off=None,
-        a_on=None,
-        a_off=None,
-        obs_id=None,
-        livetime=None,
-        alpha=None,
-        gamma_rate=None,
-        bg_rate=None,
+        self, n_on=None, n_off=None, a_on=None, a_off=None, obs_id=None, livetime=None
     ):
         super(ObservationStats, self).__init__(
             n_on=n_on, n_off=n_off, a_on=a_on, a_off=a_off
@@ -53,22 +37,13 @@ class ObservationStats(Stats):
 
         self.obs_id = obs_id
         self.livetime = livetime
-        if alpha is not None:
-            self.a_on = alpha
-            self.a_off = 1
-            self.alpha_obs = alpha
-        elif a_off > 0:
+        if a_off > 0:
             self.alpha_obs = a_on / a_off
         else:
             self.alpha_obs = 0
 
-        if gamma_rate is None:
-            gamma_rate = self.excess / livetime
-        self.gamma_rate = gamma_rate
-
-        if bg_rate is None:
-            bg_rate = self.alpha_obs * n_off / livetime
-        self.bg_rate = bg_rate
+        self.gamma_rate = self.excess / livetime
+        self.bg_rate = self.alpha_obs * n_off / livetime
 
     @classmethod
     def from_observation(cls, observation, bg_estimate):
@@ -88,12 +63,7 @@ class ObservationStats(Stats):
 
         obs_id = observation.obs_id
         livetime = observation.observation_live_time_duration
-        alpha = 0
-        if a_off > 0:
-            alpha = a_on / a_off
 
-        gamma_rate = n_on / livetime.to(u.min)
-        bg_rate = (alpha * n_off) / livetime.to(u.min)
         stats = cls(
             n_on=n_on,
             n_off=n_off,
@@ -101,9 +71,6 @@ class ObservationStats(Stats):
             a_off=a_off,
             obs_id=obs_id,
             livetime=livetime,
-            alpha=alpha,
-            gamma_rate=gamma_rate,
-            bg_rate=bg_rate,
         )
         return stats
 
@@ -143,10 +110,6 @@ class ObservationStats(Stats):
         a_off_backup = 0
         obs_id = []
         livetime = 0
-        alpha = 0
-        alpha_backup = 0
-        gamma_rate = 0
-        bg_rate = 0
         for stats in stats_list:
             if stats.a_off > 0:
                 livetime += stats.livetime
@@ -156,25 +119,16 @@ class ObservationStats(Stats):
             a_on_backup += stats.a_on * stats.livetime.value
             a_off += stats.a_off * stats.n_off
             a_off_backup += stats.a_off * stats.livetime.value
-            alpha += stats.alpha * stats.n_off
-            alpha_backup += stats.alpha * stats.livetime.value
             obs_id.append(stats.obs_id)
-            gamma_rate += stats.n_on - stats.alpha * stats.n_off
-            bg_rate += stats.n_off * stats.alpha
 
-        # if no off events the weighting of alpha is done
+        # if no off events the weighting of exposure is done
         # with the livetime
         if n_off == 0:
-            alpha = alpha_backup / livetime.value
             a_on = a_on_backup / livetime.value
             a_off = a_off_backup / livetime.value
         else:
             a_on /= n_off
             a_off /= n_off
-            alpha /= n_off
-
-        gamma_rate /= livetime.to(u.min)
-        bg_rate /= livetime.to(u.min)
 
         return cls(
             n_on=n_on,
@@ -183,9 +137,6 @@ class ObservationStats(Stats):
             a_off=a_off,
             obs_id=obs_id,
             livetime=livetime,
-            alpha=alpha,
-            gamma_rate=gamma_rate,
-            bg_rate=bg_rate,
         )
 
     def to_dict(self):
@@ -195,7 +146,7 @@ class ObservationStats(Stats):
         """
         return {
             "obs_id": self.obs_id,
-            "livetime": self.livetime,
+            "livetime": self.livetime.to("min"),
             "n_on": self.n_on,
             "n_off": self.n_off,
             "a_on": self.a_on,
@@ -204,8 +155,8 @@ class ObservationStats(Stats):
             "background": self.background,
             "excess": self.excess,
             "sigma": self.sigma,
-            "gamma_rate": self.gamma_rate,
-            "bg_rate": self.bg_rate,
+            "gamma_rate": self.gamma_rate.to("1/min"),
+            "bg_rate": self.bg_rate.to("1/min"),
         }
 
     def __str__(self):
@@ -221,10 +172,10 @@ class ObservationStats(Stats):
         ss += "Alpha: {:.3f}\n".format(self.alpha)
         ss += "Bkg events in On region: {:.2f}\n".format(self.background)
         ss += "Excess: {:.2f}\n".format(self.excess)
-        with np.errstate(invalid="ignore", divide="ignore"):
+        if self.background > 0:
             ss += "Excess / Background: {:.2f}\n".format(self.excess / self.background)
-        ss += "Gamma rate: {:.2f}\n".format(self.gamma_rate)
-        ss += "Bkg rate: {:.2f}\n".format(self.bg_rate)
+        ss += "Gamma rate: {:.2f}\n".format(self.gamma_rate.to("1/min"))
+        ss += "Bkg rate: {:.2f}\n".format(self.bg_rate.to("1/min"))
         ss += "Sigma: {:.2f}\n".format(self.sigma)
 
         return ss
