@@ -205,9 +205,9 @@ class ObservationSummary(object):
         ax.plot(self.livetime.to(u.h), self.sigma, "o", **kwargs)
 
         ax.set_xlabel("Livetime ({})".format(u.h))
-        ax.set_ylabel("Significance ($\sigma$)")
+        ax.set_ylabel("Significance")
 
-        xmax = np.amax(self.livetime.to(u.h).value) * 1.2
+        xmax = np.amax(self.livetime.to_value("h")) * 1.2
         ymax = np.amax(self.sigma) * 1.2
         ax.axis([0, xmax, 0, ymax])
         ax.set_title("Significance evolution")
@@ -234,7 +234,7 @@ class ObservationSummary(object):
         ax.set_xlabel("Livetime ({})".format(u.h))
         ax.set_ylabel("Excess")
 
-        xmax = np.amax(self.livetime.to(u.h).value) * 1.2
+        xmax = np.amax(self.livetime.to_value("h")) * 1.2
         ymax = np.amax(self.excess) * 1.2
         ax.axis([0, xmax, 0, ymax])
         ax.set_title("Excess evolution")
@@ -261,7 +261,7 @@ class ObservationSummary(object):
         ax.set_xlabel("Livetime ({})".format(u.h))
         ax.set_ylabel("Background")
 
-        xmax = np.amax(self.livetime.to(u.h).value) * 1.2
+        xmax = np.amax(self.livetime.to_value("h")) * 1.2
         ymax = np.amax(self.background) * 1.2
         ax.axis([0, xmax, 0, ymax])
         ax.set_title("Background evolution")
@@ -287,13 +287,13 @@ class ObservationSummary(object):
         xtick_vals, xtick_labels = self._get_xtick_info()
 
         ax.plot(xtick_vals, self.gamma_rate, "o", **kwargs)
-        ax.set_xlabel("Observation Ids")
+        ax.set_xlabel("Observation ID")
 
         ax.set_xticks(xtick_vals)
         ax.set_xticklabels(xtick_labels, rotation=-22.5)
-        ax.set_ylabel("$\gamma$ rate ({})".format(self.gamma_rate.unit))
-        ax.axis([0, len(self.gamma_rate), 0., np.amax(self.gamma_rate.value) * 1.2])
-        ax.set_title("$\gamma$ rates")
+        ax.set_ylabel("Excess rate ({})".format(self.gamma_rate.unit))
+        ax.axis([0, len(self.gamma_rate), 0.0, np.amax(self.gamma_rate.value) * 1.2])
+        ax.set_title("Excess rates")
         return ax
 
     def plot_background_rate(self, ax=None, **kwargs):
@@ -321,7 +321,7 @@ class ObservationSummary(object):
         ax.set_xticks(xtick_vals)
         ax.set_xticklabels(xtick_labels, rotation=-22.5)
         ax.set_ylabel("Background rate ({})".format(self.bg_rate.unit))
-        ax.axis([0, len(self.bg_rate), 0., np.amax(self.bg_rate.value) * 1.2])
+        ax.axis([0, len(self.bg_rate), 0.0, np.amax(self.bg_rate.value) * 1.2])
         ax.set_title("Background rates")
         return ax
 
