@@ -1,18 +1,18 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 from __future__ import absolute_import, division, print_function, unicode_literals
-import sys
+from collections import namedtuple, OrderedDict
 import numpy as np
 from astropy.table import Table
-from astropy.units import Quantity
+from astropy.units import Unit, Quantity
 from astropy.coordinates import Angle, SkyCoord
 from astropy.time import Time
 from astropy.utils import lazyproperty
 from ..utils.scripts import make_path
 from ..utils.time import time_relative_to_ref
+from ..utils.testing import Checker
+from .gti import GTI
 
-__all__ = [
-    'ObservationTable',
-]
+__all__ = ["ObservationTable"]
 
 
 class ObservationTable(Table):
@@ -36,18 +36,20 @@ class ObservationTable(Table):
     @property
     def pointing_radec(self):
         """Pointing positions as ICRS (`~astropy.coordinates.SkyCoord`)"""
-        return SkyCoord(self['RA_PNT'], self['DEC_PNT'], unit='deg', frame='icrs')
+        return SkyCoord(self["RA_PNT"], self["DEC_PNT"], unit="deg", frame="icrs")
 
     @property
     def pointing_galactic(self):
         """Pointing positions as Galactic (`~astropy.coordinates.SkyCoord`)"""
-        return SkyCoord(self['GLON_PNT'], self['GLAT_PNT'], unit='deg', frame='galactic')
+        return SkyCoord(
+            self["GLON_PNT"], self["GLAT_PNT"], unit="deg", frame="galactic"
+        )
 
     @lazyproperty
     def _index_dict(self):
         """Dict containing row index for all obs ids"""
         # TODO: Switch to http://docs.astropy.org/en/latest/table/indexing.html once it is more stable
-        temp = (zip(self['OBS_ID'], np.arange(len(self))))
+        temp = zip(self["OBS_ID"], np.arange(len(self)))
         return dict(temp)
 
     def get_obs_idx(self, obs_id):
@@ -80,32 +82,28 @@ class ObservationTable(Table):
         """
         return self[self.get_obs_idx(obs_id)]
 
-    def summary(self, file=None):
+    def summary(self):
         """Info string (str)"""
-        if not file:
-            file = sys.stdout
+        obs_name = self.meta.get("OBSERVATORY_NAME", "N/A")
 
-        print('Observation table:', file=file)
-
-        if 'OBSERVATORY_NAME' in self.meta:
-            obs_name = self.meta['OBSERVATORY_NAME']
-            print('Observatory name: {}'.format(obs_name), file=file)
-
-        print('Number of observations: {}'.format(len(self)), file=file)
-
-        # TODO: clean this up. Make those properties?
-        # ontime = Quantity(self['ONTIME'].sum(), self['ONTIME'].unit)
-        #
-        # ss += 'Total observation time: {}\n'.format(ontime)
-        # livetime = Quantity(self['LIVETIME'].sum(), self['LIVETIME'].unit)
-        # ss += 'Total live time: {}\n'.format(livetime)
-        # dtf = 100. * (1 - livetime / ontime)
-        # ss += 'Average dead time fraction: {:5.2f}%\n'.format(dtf)
-        # time_ref = time_ref_from_dict(self.meta)
-        # time_ref_unit = time_ref_from_dict(self.meta).format
-        # ss += 'Time reference: {} {}'.format(time_ref, time_ref_unit)
-        #
-        # return ss
+        return "\n".join(
+            [
+                "Observation table:",
+                "Observatory name: {!r}".format(obs_name),
+                "Number of observations: {}".format(len(self)),
+                # TODO: clean this up. Make those properties?
+                # ontime = Quantity(self['ONTIME'].sum(), self['ONTIME'].unit)
+                #
+                # ss += 'Total observation time: {}\n'.format(ontime)
+                # livetime = Quantity(self['LIVETIME'].sum(), self['LIVETIME'].unit)
+                # ss += 'Total live time: {}\n'.format(livetime)
+                # dtf = 100. * (1 - livetime / ontime)
+                # ss += 'Average dead time fraction: {:5.2f}%\n'.format(dtf)
+                # time_ref = time_ref_from_dict(self.meta)
+                # time_ref_unit = time_ref_from_dict(self.meta).format
+                # ss += 'Time reference: {} {}'.format(time_ref, time_ref_unit)
+            ]
+        )
 
     def select_linspace_subset(self, num):
         """Select subset of observations.
@@ -125,7 +123,7 @@ class ObservationTable(Table):
         """
         indices = np.linspace(start=0, stop=len(self), num=num, endpoint=False)
         # Round down to nearest integer
-        indices = indices.astype('int')
+        indices = indices.astype("int")
         return self[indices]
 
     def select_range(self, selection_variable, value_range, inverted=False):
@@ -166,7 +164,7 @@ class ObservationTable(Table):
         mask = (value_range[0] <= value) & (value < value_range[1])
 
         if np.allclose(value_range[0].value, value_range[1].value):
-            mask = (value_range[0] == value)
+            mask = value_range[0] == value
 
         if inverted:
             mask = np.invert(mask)
@@ -198,7 +196,7 @@ class ObservationTable(Table):
         obs_table : `~gammapy.data.ObservationTable`
             Observation table after selection.
         """
-        if self.meta['TIME_FORMAT'] == 'absolute':
+        if self.meta["TIME_FORMAT"] == "absolute":
             # read times into a Time object
             time = Time(self[selection_variable])
         else:
@@ -311,38 +309,168 @@ class ObservationTable(Table):
         """
         from ..catalog import select_sky_box, select_sky_circle
 
-        if 'inverted' not in selection.keys():
-            selection['inverted'] = False
+        if "inverted" not in selection.keys():
+            selection["inverted"] = False
 
-        if selection['type'] == 'sky_circle':
-            lon = selection['lon']
-            lat = selection['lat']
-            radius = selection['radius'] + selection['border']
+        if selection["type"] == "sky_circle":
+            lon = selection["lon"]
+            lat = selection["lat"]
+            radius = selection["radius"] + selection["border"]
             return select_sky_circle(
-                self, lon_cen=lon, lat_cen=lat, radius=radius,
-                frame=selection['frame'], inverted=selection['inverted']
+                self,
+                lon_cen=lon,
+                lat_cen=lat,
+                radius=radius,
+                frame=selection["frame"],
+                inverted=selection["inverted"],
             )
 
-        elif selection['type'] == 'sky_box':
-            lon = selection['lon']
-            lat = selection['lat']
-            border = selection['border']
+        elif selection["type"] == "sky_box":
+            lon = selection["lon"]
+            lat = selection["lat"]
+            border = selection["border"]
             lon = Angle([lon[0] - border, lon[1] + border])
             lat = Angle([lat[0] - border, lat[1] + border])
             return select_sky_box(
-                self, lon_lim=lon, lat_lim=lat,
-                frame=selection['frame'], inverted=selection['inverted']
+                self,
+                lon_lim=lon,
+                lat_lim=lat,
+                frame=selection["frame"],
+                inverted=selection["inverted"],
             )
 
-        elif selection['type'] == 'time_box':
+        elif selection["type"] == "time_box":
             return self.select_time_range(
-                'TSTART', selection['time_range'], selection['inverted']
+                "TSTART", selection["time_range"], selection["inverted"]
             )
 
-        elif selection['type'] == 'par_box':
+        elif selection["type"] == "par_box":
             return self.select_range(
-                selection['variable'], selection['value_range'], selection['inverted']
+                selection["variable"], selection["value_range"], selection["inverted"]
             )
 
         else:
-            raise ValueError('Invalid selection type: {}'.format(selection['type']))
+            raise ValueError("Invalid selection type: {}".format(selection["type"]))
+
+    def create_gti(self, obs_id):
+        """Returns a GTI table containing TSTART and TSTOP from the table.
+
+        TODO: This method can be removed once GTI tables are explicitly required in Gammapy.
+
+        Parameters
+        ----------
+        obs_id : int
+            ID of the observation for which the GTI table will be created
+
+        Returns
+        -------
+        gti : `~gammapy.data.GTI`
+            GTI table containing one row (TSTART and TSTOP of the observation with `obs_id`)
+        """
+        meta = OrderedDict(
+            EXTNAME="GTI",
+            HDUCLASS="GADF",
+            HDUDOC="https://github.com/open-gamma-ray-astro/gamma-astro-data-formats",
+            HDUVERS="0.2",
+            HDUCLAS1="GTI",
+            MJDREFI=self.meta["MJDREFI"],
+            MJDREFF=self.meta["MJDREFF"],
+            TIMEUNIT=self.meta.get("TIMEUNIT", "s"),
+            TIMESYS=self.meta["TIMESYS"],
+            TIMEREF=self.meta.get("TIMEREF", "LOCAL"),
+        )
+
+        obs = self.select_obs_id(obs_id)
+
+        gti = Table(meta=meta)
+        gti["START"] = obs["TSTART"].quantity.to("s")
+        gti["STOP"] = obs["TSTOP"].quantity.to("s")
+
+        return GTI(gti)
+
+
+class ObservationTableChecker(Checker):
+    """Event list checker.
+
+    Data format specification: ref:`gadf:iact-events`
+
+    Parameters
+    ----------
+    event_list : `~gammapy.data.EventList`
+        Event list
+    """
+
+    CHECKS = {
+        "meta": "check_meta",
+        "columns": "check_columns",
+        # "times": "check_times",
+        # "coordinates_galactic": "check_coordinates_galactic",
+        # "coordinates_altaz": "check_coordinates_altaz",
+    }
+
+    # accuracy = {"angle": Angle("1 arcsec"), "time": Quantity(1, "microsecond")}
+
+    # https://gamma-astro-data-formats.readthedocs.io/en/latest/events/events.html#mandatory-header-keywords
+    meta_required = [
+        "HDUCLASS",
+        "HDUDOC",
+        "HDUVERS",
+        "HDUCLAS1",
+        "HDUCLAS2",
+        # https://gamma-astro-data-formats.readthedocs.io/en/latest/general/time.html#time-formats
+        "MJDREFI",
+        "MJDREFF",
+        "TIMEUNIT",
+        "TIMESYS",
+        "TIMEREF",
+        # https://gamma-astro-data-formats.readthedocs.io/en/latest/general/coordinates.html#coords-location
+        "GEOLON",
+        "GEOLAT",
+        "ALTITUDE",
+    ]
+
+    _col = namedtuple("col", ["name", "unit"])
+    columns_required = [
+        _col(name="OBS_ID", unit=""),
+        _col(name="RA_PNT", unit="deg"),
+        _col(name="DEC_PNT", unit="deg"),
+        _col(name="TSTART", unit="s"),
+        _col(name="TSTOP", unit="s"),
+    ]
+
+    def __init__(self, obs_table):
+        self.obs_table = obs_table
+
+    def _record(self, level="info", msg=None):
+        return {"level": level, "hdu": "obs-index", "msg": msg}
+
+    def check_meta(self):
+        m = self.obs_table.meta
+
+        meta_missing = sorted(set(self.meta_required) - set(m))
+        if meta_missing:
+            yield self._record(
+                level="error", msg="Missing meta keys: {!r}".format(meta_missing)
+            )
+
+        if m.get("HDUCLAS1", "") != "INDEX":
+            yield self._record(level="error", msg="HDUCLAS1 must be INDEX")
+        if m.get("HDUCLAS2", "") != "OBS":
+            yield self._record(level="error", msg="HDUCLAS2 must be OBS")
+
+    def check_columns(self):
+        t = self.obs_table
+
+        if len(t) == 0:
+            yield self._record(level="error", msg="Observation table has zero rows")
+
+        for name, unit in self.columns_required:
+            if name not in t.colnames:
+                yield self._record(
+                    level="error", msg="Missing table column: {!r}".format(name)
+                )
+            else:
+                if Unit(unit) != (t[name].unit or ""):
+                    yield self._record(
+                        level="error", msg="Invalid unit for column: {!r}".format(name)
+                    )
