@@ -7,10 +7,10 @@ from ...data import DataStore
 
 @pytest.fixture(scope="session")
 def data_store():
-    return DataStore.from_dir("$GAMMAPY_EXTRA/datasets/hess-dl3-dr1/")
+    return DataStore.from_dir("$GAMMAPY_DATA/hess-dl3-dr1/")
 
 
-@requires_data("gammapy-extra")
+@requires_data("gammapy-data")
 def test_datastore_hd_hap(data_store):
     """Test HESS HAP-HD data access."""
     obs = data_store.obs(obs_id=23523)
@@ -28,26 +28,24 @@ def test_datastore_hd_hap(data_store):
     assert str(type(obs.psf)) == "<class 'gammapy.irf.psf_3d.PSF3D'>"
 
 
-@requires_data("gammapy-extra")
+@requires_data("gammapy-data")
 def test_datastore_from_dir():
     """Test the `from_dir` method."""
     data_store_rel_path = DataStore.from_dir(
-        "$GAMMAPY_EXTRA/datasets/hess-dl3-dr1/",
-        "hdu-index.fits.gz",
-        "obs-index.fits.gz",
+        "$GAMMAPY_DATA/hess-dl3-dr1/", "hdu-index.fits.gz", "obs-index.fits.gz"
     )
 
     data_store_abs_path = DataStore.from_dir(
-        "$GAMMAPY_EXTRA/datasets/hess-dl3-dr1/",
-        "$GAMMAPY_EXTRA/datasets/hess-dl3-dr1/hdu-index.fits.gz",
-        "$GAMMAPY_EXTRA/datasets/hess-dl3-dr1/obs-index.fits.gz",
+        "$GAMMAPY_DATA/hess-dl3-dr1/",
+        "$GAMMAPY_DATA/hess-dl3-dr1/hdu-index.fits.gz",
+        "$GAMMAPY_DATA/hess-dl3-dr1/obs-index.fits.gz",
     )
 
     assert "Data store" in data_store_rel_path.info(show=False)
     assert "Data store" in data_store_abs_path.info(show=False)
 
 
-@requires_data("gammapy-extra")
+@requires_data("gammapy-data")
 def test_datastore_from_file():
     filename = "$GAMMAPY_DATA/hess-dl3-dr1/hess-dl3-dr3-with-background.fits.gz"
     data_store = DataStore.from_file(filename)
@@ -57,28 +55,7 @@ def test_datastore_from_file():
     obs.bkg
 
 
-@requires_data("gammapy-extra")
-def test_datastore_pa():
-    """Test HESS ParisAnalysis data access."""
-    data_store = DataStore.from_dir("$GAMMAPY_EXTRA/datasets/hess-crab4-pa")
-
-    obs = data_store.obs(obs_id=23523)
-    filename = str(obs.location(hdu_type="bkg").path(abs_path=False))
-    assert filename == "background/bgmodel_alt7_az0.fits.gz"
-
-    assert (
-        str(type(obs.aeff))
-        == "<class 'gammapy.irf.effective_area.EffectiveAreaTable2D'>"
-    )
-    assert (
-        str(type(obs.edisp))
-        == "<class 'gammapy.irf.energy_dispersion.EnergyDispersion2D'>"
-    )
-    assert str(type(obs.psf)) == "<class 'gammapy.irf.psf_king.PSFKing'>"
-    assert str(type(obs.bkg)) == "<class 'gammapy.irf.background.Background3D'>"
-
-
-@requires_data("gammapy-extra")
+@requires_data("gammapy-data")
 def test_datastore_get_observations(data_store):
     """Test loading data and IRF files via the DataStore"""
     observations = data_store.get_observations([23523, 23592])
@@ -91,7 +68,7 @@ def test_datastore_get_observations(data_store):
     assert observations[0].obs_id == 23523
 
 
-@requires_data("gammapy-extra")
+@requires_data("gammapy-data")
 def test_datastore_subset(tmpdir, data_store):
     """Test creating a datastore as subset of another datastore"""
     selected_obs = data_store.obs_table.select_obs_id([23523, 23592])
@@ -118,12 +95,10 @@ def test_datastore_subset(tmpdir, data_store):
     assert len(substore.hdu_table) == 2
 
 
-@requires_data("gammapy-extra")
+@requires_data("gammapy-data")
 class TestDataStoreChecker:
     def setup(self):
-        self.data_store = DataStore.from_dir(
-            "$GAMMAPY_EXTRA/datasets/cta-1dc/index/gps"
-        )
+        self.data_store = DataStore.from_dir("$GAMMAPY_DATA/cta-1dc/index/gps")
 
     def test_check_all(self):
         records = list(self.data_store.check())
