@@ -1,14 +1,36 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 from __future__ import absolute_import, division, print_function, unicode_literals
+import pytest
+import numpy as np
+from astropy import units as u
 from numpy.testing import assert_allclose
 from ...utils.testing import requires_dependency, requires_data, mpl_plot_check
-from ...data.event_list import EventList, EventListLAT
+from ...data.event_list import EventListBase, EventList, EventListLAT
 
 
-@requires_data("gammapy-extra")
+@requires_data("gammapy-data")
+class TestEventListBase:
+    def setup(self):
+        filename = "$GAMMAPY_DATA/hess-dl3-dr1/data/hess_dl3_dr1_obs_id_020136.fits.gz"
+        self.events = EventListBase.read(filename)
+
+    @pytest.mark.parametrize(
+        "parameter, band", [("ENERGY", (0.8 * u.TeV, 5.0 * u.TeV))]
+    )
+    def test_select_parameter(self, parameter, band):
+        selected_events = self.events.select_parameter(parameter, band)
+        assert np.all(
+            (selected_events.table[parameter].quantity >= band[0])
+            & (selected_events.table[parameter].quantity < band[1])
+        )
+
+
+@requires_data("gammapy-data")
 class TestEventListHESS:
     def setup(self):
-        filename = "$GAMMAPY_EXTRA/test_datasets/unbundled/hess/run_0023037_hard_eventlist.fits.gz"
+        filename = (
+            "$GAMMAPY_DATA/tests/unbundled/hess/run_0023037_hard_eventlist.fits.gz"
+        )
         self.events = EventList.read(filename)
 
     def test_basics(self):
@@ -73,14 +95,15 @@ class TestEventListHESS:
             self.events.peek()
 
 
-@requires_data("gammapy-extra")
+@requires_data("gammapy-data")
 class TestEventListFermi:
     def setup(self):
-        filename = "$GAMMAPY_EXTRA/datasets/fermi_2fhl/2fhl_events.fits.gz"
+        filename = "$GAMMAPY_DATA/fermi-3fhl-gc/fermi-3fhl-gc-events.fits.gz"
         self.events = EventListLAT.read(filename)
 
     def test_basics(self):
         assert "EventList" in str(self.events)
+        assert len(self.events.table) == 32843
 
     @requires_dependency("matplotlib")
     def test_plot_image(self):
@@ -88,11 +111,11 @@ class TestEventListFermi:
             self.events.plot_image()
 
 
-@requires_data("gammapy-extra")
+@requires_data("gammapy-data")
 class TestEventListChecker:
     def setup(self):
         self.event_list = EventList.read(
-            "$GAMMAPY_EXTRA/datasets/cta-1dc/data/baseline/gps/gps_baseline_111140.fits"
+            "$GAMMAPY_DATA/cta-1dc/data/baseline/gps/gps_baseline_111140.fits"
         )
 
     def test_check_all(self):
