@@ -7,8 +7,8 @@ from ...data import observatory_locations
 
 def test_observatory_locations():
     # Check one example
-    location = observatory_locations['hess']
-    assert_allclose(location.longitude.deg, Angle('16d30m00.8s').deg)
-    assert_allclose(location.latitude.deg, Angle('-23d16m18.4s').deg)
+    location = observatory_locations["hess"]
+    assert_allclose(location.lon.deg, Angle("16d30m00.8s").deg)
+    assert_allclose(location.lat.deg, Angle("-23d16m18.4s").deg)
     assert_allclose(location.height.value, 1835)
-    assert str(location.height.unit) == 'm'
+    assert str(location.height.unit) == "m"
