@@ -1,9 +1,4 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-"""Access datasets.
-"""
+"""Access datasets."""
 from .core import *
 from .load import *
-from .make import *
-from .fermi import *
-
-
