@@ -1,20 +1,16 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 from __future__ import absolute_import, division, print_function, unicode_literals
 import pytest
-from numpy.testing.utils import assert_allclose
+from numpy.testing import assert_allclose
 from astropy.convolution import Gaussian2DKernel
 from ...utils.testing import requires_data
 from ...maps import Map
 from ...detect import TSMapEstimator
 
-pytest.importorskip("scipy")
-
 
 @pytest.fixture(scope="session")
 def input_maps():
-    filename = (
-        "$GAMMAPY_EXTRA/test_datasets/unbundled/poisson_stats_image/input_all.fits.gz"
-    )
+    filename = "$GAMMAPY_DATA/tests/unbundled/poisson_stats_image/input_all.fits.gz"
     return {
         "counts": Map.read(filename, hdu="counts"),
         "exposure": Map.read(filename, hdu="exposure"),
@@ -22,7 +18,7 @@ def input_maps():
     }
 
 
-@requires_data("gammapy-extra")
+@requires_data("gammapy-data")
 def test_compute_ts_map(input_maps):
     """Minimal test of compute_ts_image"""
     kernel = Gaussian2DKernel(5)
@@ -38,7 +34,7 @@ def test_compute_ts_map(input_maps):
     assert_allclose(result["flux_ul"].data[99, 99], 1.10e-09, rtol=1e-2)
 
 
-@requires_data("gammapy-extra")
+@requires_data("gammapy-data")
 def test_compute_ts_map_downsampled(input_maps):
     """Minimal test of compute_ts_image"""
     kernel = Gaussian2DKernel(2.5)
@@ -55,7 +51,7 @@ def test_compute_ts_map_downsampled(input_maps):
     assert_allclose(result["flux_ul"].data[99, 99], 1.10e-09, rtol=1e-2)
 
 
-@requires_data("gammapy-extra")
+@requires_data("gammapy-data")
 def test_large_kernel(input_maps):
     """Minimal test of compute_ts_image"""
     kernel = Gaussian2DKernel(100)
