@@ -1,7 +1,5 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-"""
-Sky images (2-dimensional: lon, lat).
-"""
+"""Sky images (2-dimensional: lon, lat)."""
 from .utils import *
 from .measure import *
 from .profile import *
