@@ -7,7 +7,6 @@ from astropy.io import fits
 import astropy.units as u
 from ..utils.nddata import NDDataArray, BinnedDataAxis
 from ..utils.scripts import make_path
-from ..utils.energy import EnergyBounds
 
 __all__ = ["Background3D", "Background2D"]
 
@@ -44,7 +43,9 @@ class Background3D(object):
     Data           : size = 27216, min =  0.000 1 / (MeV s sr), max =  0.421 1 / (MeV s sr)
     """
 
-    default_interp_kwargs = dict(bounds_error=False, fill_value=None)
+    default_interp_kwargs = dict(
+        bounds_error=False, fill_value=None, values_scale="log"
+    )
     """Default Interpolation kwargs for `~gammapy.utils.nddata.NDDataArray`. Extrapolate."""
 
     def __init__(
@@ -160,61 +161,39 @@ class Background3D(object):
         array : `~astropy.units.Quantity`
             Interpolated values, axis order is the same as for the NDData array
         """
-        points = dict(fov_lon=fov_lon, fov_lat=fov_lat, energy=energy_reco)
-        array = self.data.evaluate_at_coord(points=points, method=method, **kwargs)
-        return array
+        values = self.data.evaluate(
+            fov_lon=fov_lon,
+            fov_lat=fov_lat,
+            energy=energy_reco,
+            method=method,
+            **kwargs
+        )
+        return values
 
-    def integrate_on_energy_range(
-        self,
-        fov_lon,
-        fov_lat,
-        energy_range,
-        n_integration_bins=1,
-        method="linear",
-        **kwargs
+    def evaluate_integrate(
+        self, fov_lon, fov_lat, energy_reco, method="linear", **kwargs
     ):
-        """Integrate over an energy range.
+        """Evaluate at given FOV position and energy edges by integrating over the energy
+        axes.
 
         Parameters
         ----------
         fov_lon, fov_lat : `~astropy.coordinates.Angle`
             FOV coordinates expecting in AltAz frame.
-        energy_range: `~astropy.units.Quantity`
-            Energy range
-        n_integration_bins : int
-            Number of bins in the energy range
+        energy_reco: `~astropy.units.Quantity`
+            Reconstructed energy edges.
         method : {'linear', 'nearest'}, optional
             Interpolation method
-        kwargs : dict
-            Passed to `scipy.interpolate.RegularGridInterpolator`.
 
         Returns
         -------
         array : `~astropy.units.Quantity`
-            Returns 2D array with axes fov_lon, fov_lat
+            Returns 2D array with axes offset
         """
-        fov_lon = np.atleast_2d(fov_lon)
-        fov_lat = np.atleast_2d(fov_lat)
-        energy_edges = EnergyBounds.equal_log_spacing(
-            energy_range[0], energy_range[1], n_integration_bins
-        )
+        from ..spectrum.utils import _trapz_loglog
 
-        # TODO: insert new axes, remove tile and use numpy broadcasting
-        energy_reco = np.tile(energy_edges, reps=fov_lon.shape + (1,))
-        fov_lon = np.tile(fov_lon, reps=energy_edges.shape + (1, 1))
-        fov_lon = np.rollaxis(fov_lon, 0, 3)
-        fov_lat = np.tile(fov_lat, reps=energy_edges.shape + (1, 1))
-        fov_lat = np.rollaxis(fov_lat, 0, 3)
-
-        bkg_evaluated = self.evaluate(
-            fov_lon=fov_lon,
-            fov_lat=fov_lat,
-            energy_reco=energy_reco,
-            method=method,
-            **kwargs
-        )
-        # TODO: use gammapy.spectrum.utils._trapz_loglog for better precision
-        return np.trapz(bkg_evaluated, energy_edges).decompose()
+        data = self.evaluate(fov_lon, fov_lat, energy_reco, method=method)
+        return _trapz_loglog(data, energy_reco, axis=0, intervals=True)
 
     def to_2d(self):
         """Convert to `Background2D`.
@@ -361,60 +340,31 @@ class Background2D(object):
             Interpolated values, axis order is the same as for the NDData array
         """
         offset = np.sqrt(fov_lon ** 2 + fov_lat ** 2)
-        points = dict(offset=offset, energy=energy_reco)
-        return self.data.evaluate_at_coord(points=points, method=method, **kwargs)
+        return self.data.evaluate(
+            offset=offset, energy=energy_reco, method=method, **kwargs
+        )
 
-    def integrate_on_energy_range(
-        self,
-        fov_lon,
-        fov_lat,
-        energy_range,
-        n_integration_bins=1,
-        method="linear",
-        **kwargs
-    ):
-        """Integrate over an energy range.
+    def evaluate_integrate(self, fov_lon, fov_lat, energy_reco, method="linear"):
+        """Evaluate at given FOV position and energy, by integrating over the energy range.
 
         Parameters
         ----------
         fov_lon, fov_lat : `~astropy.coordinates.Angle`
             FOV coordinates expecting in AltAz frame.
-        energy_range: `~astropy.units.Quantity`
-            Energy range
-        n_integration_bins : int
-            Number of bins in the energy range
+        energy_reco: `~astropy.units.Quantity`
+            Reconstructed energy edges.
         method : {'linear', 'nearest'}, optional
             Interpolation method
-        kwargs : dict
-            Passed to `scipy.interpolate.RegularGridInterpolator`.
 
         Returns
         -------
         array : `~astropy.units.Quantity`
             Returns 2D array with axes offset
         """
-        fov_lon = np.atleast_2d(fov_lon)
-        fov_lat = np.atleast_2d(fov_lat)
-        energy_edges = EnergyBounds.equal_log_spacing(
-            energy_range[0], energy_range[1], n_integration_bins
-        )
-        # TODO: insert new axes, remove tile and use numpy broadcasting
-        energy_reco = np.tile(energy_edges, reps=fov_lon.shape + (1,))
-        fov_lon = np.tile(fov_lon, reps=energy_edges.shape + (1, 1))
-        fov_lon = np.rollaxis(fov_lon, 0, 3)
-        fov_lat = np.tile(fov_lat, reps=energy_edges.shape + (1, 1))
-        fov_lat = np.rollaxis(fov_lat, 0, 3)
+        from ..spectrum.utils import _trapz_loglog
 
-        bkg_evaluated = self.evaluate(
-            fov_lon=fov_lon,
-            fov_lat=fov_lat,
-            energy_reco=energy_reco,
-            method=method,
-            **kwargs
-        )
-
-        # TODO: use gammapy.spectrum.utils._trapz_loglog for better precision
-        return np.trapz(bkg_evaluated, energy_edges).decompose()
+        data = self.evaluate(fov_lon, fov_lat, energy_reco, method=method)
+        return _trapz_loglog(data, energy_reco, axis=0, intervals=True)
 
     def to_3d(self):
         """Convert to `Background3D`.
