@@ -8,12 +8,8 @@ from astropy.table import Table
 from ..utils.nddata import NDDataArray, BinnedDataAxis
 from ..utils.energy import EnergyBounds
 from ..utils.scripts import make_path
-from ..utils.fits import fits_table_to_table, table_to_fits_table
 
-__all__ = [
-    'EffectiveAreaTable',
-    'EffectiveAreaTable2D',
-]
+__all__ = ["EffectiveAreaTable", "EffectiveAreaTable2D"]
 
 
 class EffectiveAreaTable(object):
@@ -69,14 +65,18 @@ class EffectiveAreaTable(object):
     """
 
     def __init__(self, energy_lo, energy_hi, data, meta=None):
-        axes = [BinnedDataAxis(energy_lo, energy_hi,
-                               interpolation_mode='log', name='energy')]
-        self.data = NDDataArray(axes=axes, data=data)
+        axes = [
+            BinnedDataAxis(
+                energy_lo, energy_hi, interpolation_mode="log", name="energy"
+            )
+        ]
+        interp_kwargs = {"extrapolate": False, "bounds_error": False}
+        self.data = NDDataArray(axes=axes, data=data, interp_kwargs=interp_kwargs)
         self.meta = OrderedDict(meta) if meta else OrderedDict()
 
     @property
     def energy(self):
-        return self.data.axis('energy')
+        return self.data.axis("energy")
 
     def plot(self, ax=None, energy=None, show_energy=None, **kwargs):
         """Plot effective area.
@@ -96,28 +96,30 @@ class EffectiveAreaTable(object):
             Axis
         """
         import matplotlib.pyplot as plt
+
         ax = plt.gca() if ax is None else ax
 
-        kwargs.setdefault('lw', 2)
+        kwargs.setdefault("lw", 2)
 
         if energy is None:
             energy = self.energy.nodes
         eff_area = self.data.evaluate(energy=energy)
-        xerr = (energy.value - self.energy.lo.value,
-                self.energy.hi.value - energy.value)
+        xerr = (
+            energy.value - self.energy.lo.value,
+            self.energy.hi.value - energy.value,
+        )
         ax.errorbar(energy.value, eff_area.value, xerr=xerr, **kwargs)
         if show_energy is not None:
-            ener_val = u.Quantity(show_energy).to(self.energy.unit).value
-            ax.vlines(ener_val, 0, 1.1 * self.max_area.value,
-                      linestyles='dashed')
-        ax.set_xscale('log')
-        ax.set_xlabel('Energy [{}]'.format(self.energy.unit))
-        ax.set_ylabel('Effective Area [{}]'.format(self.data.data.unit))
+            ener_val = u.Quantity(show_energy).to_value(self.energy.unit)
+            ax.vlines(ener_val, 0, 1.1 * self.max_area.value, linestyles="dashed")
+        ax.set_xscale("log")
+        ax.set_xlabel("Energy [{}]".format(self.energy.unit))
+        ax.set_ylabel("Effective Area [{}]".format(self.data.data.unit))
 
         return ax
 
     @classmethod
-    def from_parametrization(cls, energy, instrument='HESS'):
+    def from_parametrization(cls, energy, instrument="HESS"):
         """Get parametrized effective area.
 
         Parametrizations of the effective areas of different Cherenkov
@@ -139,60 +141,59 @@ class EffectiveAreaTable(object):
         # Units: g1 (cm^2), g2 (), g3 (MeV)
         # Note that whereas in the paper the parameter index is 1-based,
         # here it is 0-based
-        pars = {'HESS': [6.85e9, 0.0891, 5e5],
-                'HESS2': [2.05e9, 0.0891, 1e5],
-                'CTA': [1.71e11, 0.0891, 1e5]}
+        pars = {
+            "HESS": [6.85e9, 0.0891, 5e5],
+            "HESS2": [2.05e9, 0.0891, 1e5],
+            "CTA": [1.71e11, 0.0891, 1e5],
+        }
 
         if instrument not in pars.keys():
-            ss = 'Unknown instrument: {}\n'.format(instrument)
-            ss += 'Valid instruments: HESS, HESS2, CTA'
+            ss = "Unknown instrument: {}\n".format(instrument)
+            ss += "Valid instruments: HESS, HESS2, CTA"
             raise ValueError(ss)
 
-        xx = energy.log_centers.to('MeV').value
+        xx = energy.log_centers.to_value("MeV")
 
         g1 = pars[instrument][0]
         g2 = pars[instrument][1]
         g3 = -pars[instrument][2]
 
         value = g1 * xx ** (-g2) * np.exp(g3 / xx)
-
-        data = value * u.cm ** 2
+        data = u.Quantity(value, "cm2", copy=False)
 
         return cls(
-            energy_lo=energy.lower_bounds,
-            energy_hi=energy.upper_bounds,
-            data=data,
+            energy_lo=energy.lower_bounds, energy_hi=energy.upper_bounds, data=data
         )
 
     @classmethod
     def from_table(cls, table):
         """Create from `~astropy.table.Table` in ARF format.
 
-        Data format specification: :ref:`gadf:ogip-arf`        
+        Data format specification: :ref:`gadf:ogip-arf`
         """
-        energy_lo = table['ENERG_LO'].quantity
-        energy_hi = table['ENERG_HI'].quantity
-        data = table['SPECRESP'].quantity
+        energy_lo = table["ENERG_LO"].quantity
+        energy_hi = table["ENERG_HI"].quantity
+        data = table["SPECRESP"].quantity
         return cls(energy_lo=energy_lo, energy_hi=energy_hi, data=data)
 
     @classmethod
-    def from_hdulist(cls, hdulist, hdu='SPECRESP'):
+    def from_hdulist(cls, hdulist, hdu="SPECRESP"):
         """Create from `~astropy.io.fits.HDUList`."""
-        fits_table = hdulist[hdu]
-        table = fits_table_to_table(fits_table)
-        return cls.from_table(table)
+        return cls.from_table(Table.read(hdulist[hdu]))
 
     @classmethod
-    def read(cls, filename, hdu='SPECRESP', **kwargs):
+    def read(cls, filename, hdu="SPECRESP"):
         """Read from file."""
         filename = make_path(filename)
-        hdulist = fits.open(str(filename), **kwargs)
-        try:
-            return cls.from_hdulist(hdulist, hdu=hdu)
-        except KeyError:
-            msg = 'File {} contains no HDU "{}"'.format(filename, hdu)
-            msg += '\n Available {}'.format([_.name for _ in hdulist])
-            raise ValueError(msg)
+        with fits.open(str(filename), memmap=False) as hdulist:
+            try:
+                aeff = cls.from_hdulist(hdulist, hdu=hdu)
+            except KeyError:
+                msg = 'File {} contains no HDU "{}"'.format(filename, hdu)
+                msg += "\n Available {}".format([_.name for _ in hdulist])
+                raise ValueError(msg)
+
+        return aeff
 
     def to_table(self):
         """Convert to `~astropy.table.Table` in ARF format.
@@ -200,22 +201,24 @@ class EffectiveAreaTable(object):
         Data format specification: :ref:`gadf:ogip-arf`
         """
         table = Table()
-        table.meta = OrderedDict([
-            ('EXTNAME', 'SPECRESP'),
-            ('hduclass', 'OGIP'),
-            ('hduclas1', 'RESPONSE'),
-            ('hduclas2', 'SPECRESP'),
-        ])
-        table['ENERG_LO'] = self.energy.lo
-        table['ENERG_HI'] = self.energy.hi
-        table['SPECRESP'] = self.evaluate_fill_nan()
+        table.meta = OrderedDict(
+            [
+                ("EXTNAME", "SPECRESP"),
+                ("hduclass", "OGIP"),
+                ("hduclas1", "RESPONSE"),
+                ("hduclas2", "SPECRESP"),
+            ]
+        )
+        table["ENERG_LO"] = self.energy.lo
+        table["ENERG_HI"] = self.energy.hi
+        table["SPECRESP"] = self.evaluate_fill_nan()
         return table
 
-    def to_hdulist(self):
+    def to_hdulist(self, name=None):
         """Convert to `~astropy.io.fits.HDUList`."""
-        hdu = table_to_fits_table(self.to_table())
-        prim_hdu = fits.PrimaryHDU()
-        return fits.HDUList([prim_hdu, hdu])
+        return fits.HDUList(
+            [fits.PrimaryHDU(), fits.BinTableHDU(self.to_table(), name=name)]
+        )
 
     def write(self, filename, **kwargs):
         """Write to file."""
@@ -276,18 +279,22 @@ class EffectiveAreaTable(object):
                 energy = self.energy.lo[idx].value
             # Perform linear interpolation otherwise
             else:
-                energy = np.interp(aeff.value,
-                                   (self.data.data[[idx - 1, idx]].value),
-                                   (self.energy.nodes[[idx - 1, idx]].value))
+                energy = np.interp(
+                    aeff.value,
+                    (self.data.data[[idx - 1, idx]].value),
+                    (self.energy.nodes[[idx - 1, idx]].value),
+                )
         else:
             # Return upper edge if last bin is selected
             if idx == self.data.data.size - 1:
                 energy = self.energy.hi[idx].value
             # Perform linear interpolation otherwise
             else:
-                energy = np.interp(aeff.value,
-                                   (self.data.data[[idx, idx + 1]].value),
-                                   (self.energy.nodes[[idx, idx + 1]].value))
+                energy = np.interp(
+                    aeff.value,
+                    (self.data.data[[idx, idx + 1]].value),
+                    (self.energy.nodes[[idx, idx + 1]].value),
+                )
         return energy * self.energy.unit
 
     def to_sherpa(self, name):
@@ -299,12 +306,13 @@ class EffectiveAreaTable(object):
             Instance name
         """
         from sherpa.astro.data import DataARF
+
         table = self.to_table()
         return DataARF(
             name=name,
-            energ_lo=table['ENERG_LO'].quantity.to('keV').value,
-            energ_hi=table['ENERG_HI'].quantity.to('keV').value,
-            specresp=table['SPECRESP'].quantity.to('cm2').value,
+            energ_lo=table["ENERG_LO"].quantity.to_value("keV"),
+            energ_hi=table["ENERG_HI"].quantity.to_value("keV"),
+            specresp=table["SPECRESP"].quantity.to_value("cm2"),
         )
 
 
@@ -327,7 +335,7 @@ class EffectiveAreaTable2D(object):
     Here's an example you can use to learn about this class:
 
     >>> from gammapy.irf import EffectiveAreaTable2D
-    >>> filename = '$GAMMAPY_EXTRA/datasets/cta-1dc/caldb/data/cta//1dc/bcf/South_z20_50h/irf_file.fits'
+    >>> filename = '$GAMMAPY_DATA/cta-1dc/caldb/data/cta/1dc/bcf/South_z20_50h/irf_file.fits'
     >>> aeff = EffectiveAreaTable2D.read(filename, hdu='EFFECTIVE AREA')
     >>> print(aeff)
     EffectiveAreaTable2D
@@ -344,7 +352,7 @@ class EffectiveAreaTable2D(object):
     >>> energy = np.logspace(0,1,11) * u.TeV
     >>> offset = np.linspace(0,1,4) * u.deg
     >>> data = np.ones(shape=(10,3)) * u.cm * u.cm
-    >>> aeff = EffectiveAreaTable2D(energy_lo=energy[:-1], energy_hi=energy[1:], offset_lo=offset[:-1], 
+    >>> aeff = EffectiveAreaTable2D(energy_lo=energy[:-1], energy_hi=energy[1:], offset_lo=offset[:-1],
     >>>                             offset_hi=offset[1:], data= data)
     >>> print(aeff)
     Data array summary info
@@ -352,66 +360,74 @@ class EffectiveAreaTable2D(object):
     offset         : size =     4, min =  0.000 deg, max =  1.000 deg
     Data           : size =    30, min =  1.000 cm2, max =  1.000 cm2
     """
+
     default_interp_kwargs = dict(bounds_error=False, fill_value=None)
     """Default Interpolation kwargs for `~NDDataArray`. Extrapolate."""
 
-    def __init__(self, energy_lo, energy_hi, offset_lo, offset_hi, data,
-                 meta=None, interp_kwargs=None):
+    def __init__(
+        self,
+        energy_lo,
+        energy_hi,
+        offset_lo,
+        offset_hi,
+        data,
+        meta=None,
+        interp_kwargs=None,
+    ):
 
         if interp_kwargs is None:
             interp_kwargs = self.default_interp_kwargs
         axes = [
             BinnedDataAxis(
-                energy_lo, energy_hi,
-                interpolation_mode='log', name='energy'),
+                energy_lo, energy_hi, interpolation_mode="log", name="energy"
+            ),
             BinnedDataAxis(
-                offset_lo, offset_hi,
-                interpolation_mode='linear', name='offset')
+                offset_lo, offset_hi, interpolation_mode="linear", name="offset"
+            ),
         ]
-        self.data = NDDataArray(axes=axes, data=data,
-                                interp_kwargs=interp_kwargs)
+        self.data = NDDataArray(axes=axes, data=data, interp_kwargs=interp_kwargs)
         self.meta = OrderedDict(meta) if meta else OrderedDict()
 
     def __str__(self):
         ss = self.__class__.__name__
-        ss += '\n{}'.format(self.data)
+        ss += "\n{}".format(self.data)
         return ss
 
     @property
     def low_threshold(self):
         """Low energy threshold"""
-        return self.meta['LO_THRES'] * u.TeV
+        return self.meta["LO_THRES"] * u.TeV
 
     @property
     def high_threshold(self):
         """High energy threshold"""
-        return self.meta['HI_THRES'] * u.TeV
+        return self.meta["HI_THRES"] * u.TeV
 
     @classmethod
     def from_table(cls, table):
         """Read from `~astropy.table.Table`."""
         return cls(
-            energy_lo=table['ENERG_LO'].quantity[0],
-            energy_hi=table['ENERG_HI'].quantity[0],
-            offset_lo=table['THETA_LO'].quantity[0],
-            offset_hi=table['THETA_HI'].quantity[0],
-            data=table['EFFAREA'].quantity[0].transpose(),
+            energy_lo=table["ENERG_LO"].quantity[0],
+            energy_hi=table["ENERG_HI"].quantity[0],
+            offset_lo=table["THETA_LO"].quantity[0],
+            offset_hi=table["THETA_HI"].quantity[0],
+            data=table["EFFAREA"].quantity[0].transpose(),
             meta=table.meta,
         )
 
     @classmethod
-    def from_hdulist(cls, hdulist, hdu='EFFECTIVE AREA'):
+    def from_hdulist(cls, hdulist, hdu="EFFECTIVE AREA"):
         """Create from `~astropy.io.fits.HDUList`."""
-        fits_table = hdulist[hdu]
-        table = fits_table_to_table(fits_table)
-        return cls.from_table(table)
+        return cls.from_table(Table.read(hdulist[hdu]))
 
     @classmethod
-    def read(cls, filename, hdu='EFFECTIVE AREA'):
+    def read(cls, filename, hdu="EFFECTIVE AREA"):
         """Read from file."""
         filename = make_path(filename)
-        hdulist = fits.open(str(filename))
-        return cls.from_hdulist(hdulist, hdu=hdu)
+        with fits.open(str(filename), memmap=False) as hdulist:
+            aeff = cls.from_hdulist(hdulist, hdu=hdu)
+
+        return aeff
 
     def to_effective_area_table(self, offset, energy=None):
         """Evaluate at a given offset and return `~gammapy.irf.EffectiveAreaTable`.
@@ -424,15 +440,13 @@ class EffectiveAreaTable2D(object):
             Energy axis bin edges
         """
         if energy is None:
-            energy = self.data.axis('energy').bins
+            energy = self.data.axis("energy").bins
 
         energy = EnergyBounds(energy)
         area = self.data.evaluate(offset=offset, energy=energy.log_centers)
 
         return EffectiveAreaTable(
-            energy_lo=energy.lower_bounds,
-            energy_hi=energy.upper_bounds,
-            data=area,
+            energy_lo=energy.lower_bounds, energy_hi=energy.upper_bounds, data=area
         )
 
     def plot_energy_dependence(self, ax=None, offset=None, energy=None, **kwargs):
@@ -459,22 +473,22 @@ class EffectiveAreaTable2D(object):
         ax = plt.gca() if ax is None else ax
 
         if offset is None:
-            off_min, off_max = self.data.axis('offset').nodes[[0, -1]].value
-            offset = np.linspace(off_min, off_max, 4) * self.data.axis('offset').unit
+            off_min, off_max = self.data.axis("offset").nodes[[0, -1]].value
+            offset = np.linspace(off_min, off_max, 4) * self.data.axis("offset").unit
 
         if energy is None:
-            energy = self.data.axis('energy').nodes
+            energy = self.data.axis("energy").nodes
 
         for off in offset:
             area = self.data.evaluate(offset=off, energy=energy)
-            label = 'offset = {:.1f}'.format(off)
+            label = "offset = {:.1f}".format(off)
             ax.plot(energy, area.value, label=label, **kwargs)
 
-        ax.set_xscale('log')
-        ax.set_xlabel('Energy [{}]'.format(self.data.axis('energy').unit))
-        ax.set_ylabel('Effective Area [{}]'.format(self.data.data.unit))
+        ax.set_xscale("log")
+        ax.set_xlabel("Energy [{}]".format(self.data.axis("energy").unit))
+        ax.set_ylabel("Effective Area [{}]".format(self.data.data.unit))
         ax.set_xlim(min(energy.value), max(energy.value))
-        ax.legend(loc='upper left')
+        ax.legend(loc="upper left")
 
         return ax
 
@@ -500,11 +514,11 @@ class EffectiveAreaTable2D(object):
         ax = plt.gca() if ax is None else ax
 
         if energy is None:
-            e_min, e_max = np.log10(self.data.axis('energy').nodes[[0, -1]].value)
-            energy = np.logspace(e_min, e_max, 4) * self.data.axis('energy').unit
+            e_min, e_max = np.log10(self.data.axis("energy").nodes[[0, -1]].value)
+            energy = np.logspace(e_min, e_max, 4) * self.data.axis("energy").unit
 
         if offset is None:
-            off_lo, off_hi = self.data.axis('offset').nodes[[0, -1]].to('deg').value
+            off_lo, off_hi = self.data.axis("offset").nodes[[0, -1]].to_value("deg")
             offset = np.linspace(off_lo, off_hi, 100) * u.deg
 
         for ee in energy:
@@ -512,13 +526,13 @@ class EffectiveAreaTable2D(object):
             area /= np.nanmax(area)
             if np.isnan(area).all():
                 continue
-            label = 'energy = {:.1f}'.format(ee)
+            label = "energy = {:.1f}".format(ee)
             ax.plot(offset, area, label=label, **kwargs)
 
         ax.set_ylim(0, 1.1)
-        ax.set_xlabel('Offset ({})'.format(self.data.axis('offset').unit))
-        ax.set_ylabel('Relative Effective Area')
-        ax.legend(loc='best')
+        ax.set_xlabel("Offset ({})".format(self.data.axis("offset").unit))
+        ax.set_ylabel("Relative Effective Area")
+        ax.legend(loc="best")
 
         return ax
 
@@ -528,35 +542,36 @@ class EffectiveAreaTable2D(object):
 
         ax = plt.gca() if ax is None else ax
 
-        offset = self.data.axis('offset').bins
-        energy = self.data.axis('energy').bins
-        aeff = self.data.evaluate(offset=offset, energy=energy)
+        offset = self.data.axis("offset").bins
+        energy = self.data.axis("energy").bins
+        aeff = self.data.evaluate(offset=offset, energy=energy[:, np.newaxis])
 
         vmin, vmax = np.nanmin(aeff.value), np.nanmax(aeff.value)
 
-        kwargs.setdefault('cmap', 'GnBu')
-        kwargs.setdefault('edgecolors', 'face')
-        kwargs.setdefault('vmin', vmin)
-        kwargs.setdefault('vmax', vmax)
+        kwargs.setdefault("cmap", "GnBu")
+        kwargs.setdefault("edgecolors", "face")
+        kwargs.setdefault("vmin", vmin)
+        kwargs.setdefault("vmax", vmax)
 
         caxes = ax.pcolormesh(energy.value, offset.value, aeff.value.T, **kwargs)
 
-        ax.set_xscale('log')
-        ax.set_ylabel('Offset ({})'.format(offset.unit))
-        ax.set_xlabel('Energy ({})'.format(energy.unit))
+        ax.set_xscale("log")
+        ax.set_ylabel("Offset ({})".format(offset.unit))
+        ax.set_xlabel("Energy ({})".format(energy.unit))
 
         xmin, xmax = energy.value.min(), energy.value.max()
         ax.set_xlim(xmin, xmax)
 
         if add_cbar:
-            label = 'Effective Area ({unit})'.format(unit=aeff.unit)
-            cbar = ax.figure.colorbar(caxes, ax=ax, label=label)
+            label = "Effective Area ({unit})".format(unit=aeff.unit)
+            ax.figure.colorbar(caxes, ax=ax, label=label)
 
         return ax
 
     def peek(self, figsize=(15, 5)):
         """Quick-look summary plots."""
         import matplotlib.pyplot as plt
+
         fig, axes = plt.subplots(nrows=1, ncols=3, figsize=figsize)
         self.plot(ax=axes[2])
         self.plot_energy_dependence(ax=axes[0])
@@ -567,13 +582,13 @@ class EffectiveAreaTable2D(object):
         """Convert to `~astropy.table.Table`."""
         meta = self.meta.copy()
         table = Table(meta=meta)
-        table['ENERG_LO'] = self.data.axis('energy').lo[np.newaxis]
-        table['ENERG_HI'] = self.data.axis('energy').hi[np.newaxis]
-        table['THETA_LO'] = self.data.axis('offset').lo[np.newaxis]
-        table['THETA_HI'] = self.data.axis('offset').hi[np.newaxis]
-        table['EFFAREA'] = self.data.data.T[np.newaxis]
+        table["ENERG_LO"] = self.data.axis("energy").lo[np.newaxis]
+        table["ENERG_HI"] = self.data.axis("energy").hi[np.newaxis]
+        table["THETA_LO"] = self.data.axis("offset").lo[np.newaxis]
+        table["THETA_HI"] = self.data.axis("offset").hi[np.newaxis]
+        table["EFFAREA"] = self.data.data.T[np.newaxis]
         return table
 
-    def to_fits(self, name='EFFECTIVE AREA'):
+    def to_fits(self, name="EFFECTIVE AREA"):
         """Convert to `~astropy.io.fits.BinTable`."""
-        return table_to_fits_table(self.to_table(), name)
\ No newline at end of file
+        return fits.BinTableHDU(self.to_table(), name=name)
