@@ -1,19 +1,17 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 from __future__ import absolute_import, division, print_function, unicode_literals
 import numpy as np
+from scipy.interpolate import RegularGridInterpolator
 from astropy.table import Table
 from astropy.io import fits
 from astropy.units import Quantity
 from astropy.coordinates import Angle
 from ..utils.array import array_stats_str
-from ..utils.fits import table_to_fits_table
 from ..utils.energy import Energy
 from ..utils.scripts import make_path
 from .psf_table import TablePSF, EnergyDependentTablePSF
 
-__all__ = [
-    'PSF3D',
-]
+__all__ = ["PSF3D"]
 
 
 class PSF3D(object):
@@ -41,29 +39,37 @@ class PSF3D(object):
         Upper energy threshold.
     """
 
-    def __init__(self, energy_lo, energy_hi, offset, rad_lo, rad_hi, psf_value,
-                 energy_thresh_lo=Quantity(0.1, 'TeV'),
-                 energy_thresh_hi=Quantity(100, 'TeV')):
-        self.energy_lo = energy_lo.to('TeV')
-        self.energy_hi = energy_hi.to('TeV')
+    def __init__(
+        self,
+        energy_lo,
+        energy_hi,
+        offset,
+        rad_lo,
+        rad_hi,
+        psf_value,
+        energy_thresh_lo=Quantity(0.1, "TeV"),
+        energy_thresh_hi=Quantity(100, "TeV"),
+    ):
+        self.energy_lo = energy_lo.to("TeV")
+        self.energy_hi = energy_hi.to("TeV")
         self.offset = Angle(offset)
         self.rad_lo = Angle(rad_lo)
         self.rad_hi = Angle(rad_hi)
-        self.psf_value = psf_value.to('sr^-1')
-        self.energy_thresh_lo = energy_thresh_lo.to('TeV')
-        self.energy_thresh_hi = energy_thresh_hi.to('TeV')
+        self.psf_value = psf_value.to("sr^-1")
+        self.energy_thresh_lo = energy_thresh_lo.to("TeV")
+        self.energy_thresh_hi = energy_thresh_hi.to("TeV")
 
     def info(self):
         """Print some basic info.
         """
         ss = "\nSummary PSF3D info\n"
         ss += "---------------------\n"
-        ss += array_stats_str(self.energy_lo, 'energy_lo')
-        ss += array_stats_str(self.energy_hi, 'energy_hi')
-        ss += array_stats_str(self.offset, 'offset')
-        ss += array_stats_str(self.rad_lo, 'rad_lo')
-        ss += array_stats_str(self.rad_hi, 'rad_hi')
-        ss += array_stats_str(self.psf_value, 'psf_value')
+        ss += array_stats_str(self.energy_lo, "energy_lo")
+        ss += array_stats_str(self.energy_hi, "energy_hi")
+        ss += array_stats_str(self.offset, "offset")
+        ss += array_stats_str(self.rad_lo, "rad_lo")
+        ss += array_stats_str(self.rad_hi, "rad_hi")
+        ss += array_stats_str(self.psf_value, "psf_value")
 
         # TODO: should quote containment values also
 
@@ -82,10 +88,10 @@ class PSF3D(object):
     def _rad_center(self):
         """Get centers of rad bins (`~astropy.coordinates.Angle` in deg).
         """
-        return ((self.rad_hi + self.rad_lo) / 2).to('deg')
+        return ((self.rad_hi + self.rad_lo) / 2).to("deg")
 
     @classmethod
-    def read(cls, filename, hdu='PSF_2D_TABLE'):
+    def read(cls, filename, hdu="PSF_2D_TABLE"):
         """Create `PSF3D` from FITS file.
 
         Parameters
@@ -108,23 +114,23 @@ class PSF3D(object):
         table : `~astropy.table.Table`
             Table Table-PSF info.
         """
-        theta_lo = table['THETA_LO'].quantity[0]
-        theta_hi = table['THETA_HI'].quantity[0]
+        theta_lo = table["THETA_LO"].quantity[0]
+        theta_hi = table["THETA_HI"].quantity[0]
         offset = (theta_hi + theta_lo) / 2
-        offset = Angle(offset, unit=table['THETA_LO'].unit)
+        offset = Angle(offset, unit=table["THETA_LO"].unit)
 
-        energy_lo = table['ENERG_LO'].quantity[0]
-        energy_hi = table['ENERG_HI'].quantity[0]
+        energy_lo = table["ENERG_LO"].quantity[0]
+        energy_hi = table["ENERG_HI"].quantity[0]
 
-        rad_lo = table['RAD_LO'].quantity[0]
-        rad_hi = table['RAD_HI'].quantity[0]
+        rad_lo = table["RAD_LO"].quantity[0]
+        rad_hi = table["RAD_HI"].quantity[0]
 
-        psf_value = table['RPSF'].quantity[0]
+        psf_value = table["RPSF"].quantity[0]
 
         opts = {}
         try:
-            opts['energy_thresh_lo'] = Quantity(table.meta['LO_THRES'], 'TeV')
-            opts['energy_thresh_hi'] = Quantity(table.meta['HI_THRES'], 'TeV')
+            opts["energy_thresh_lo"] = Quantity(table.meta["LO_THRES"], "TeV")
+            opts["energy_thresh_hi"] = Quantity(table.meta["HI_THRES"], "TeV")
         except KeyError:
             pass
 
@@ -140,21 +146,34 @@ class PSF3D(object):
             PSF in HDU list format.
         """
         # Set up data
-        names = ['ENERG_LO', 'ENERG_HI', 'THETA_LO', 'THETA_HI',
-                 'RAD_LO', 'RAD_HI', 'RPSF']
-        units = ['TeV', 'TeV', 'deg', 'deg',
-                 'deg', 'deg', 'sr^-1']
-        data = [self.energy_lo, self.energy_hi, self.offset, self.offset,
-                self.rad_lo, self.rad_hi, self.psf_value]
+        names = [
+            "ENERG_LO",
+            "ENERG_HI",
+            "THETA_LO",
+            "THETA_HI",
+            "RAD_LO",
+            "RAD_HI",
+            "RPSF",
+        ]
+        units = ["TeV", "TeV", "deg", "deg", "deg", "deg", "sr^-1"]
+        data = [
+            self.energy_lo,
+            self.energy_hi,
+            self.offset,
+            self.offset,
+            self.rad_lo,
+            self.rad_hi,
+            self.psf_value,
+        ]
 
         table = Table()
         for name_, data_, unit_ in zip(names, data, units):
             table[name_] = [data_]
             table[name_].unit = unit_
 
-        hdu = table_to_fits_table(table)
-        hdu.header['LO_THRES'] = self.energy_thresh_lo.value
-        hdu.header['HI_THRES'] = self.energy_thresh_hi.value
+        hdu = fits.BinTableHDU(table)
+        hdu.header["LO_THRES"] = self.energy_thresh_lo.value
+        hdu.header["HI_THRES"] = self.energy_thresh_hi.value
 
         return fits.HDUList([fits.PrimaryHDU(), hdu])
 
@@ -165,9 +184,8 @@ class PSF3D(object):
         """
         self.to_fits().writeto(filename, *args, **kwargs)
 
-    def evaluate(self, energy=None, offset=None, rad=None,
-                 interp_kwargs=None):
-        """Interpolate the value of the `EnergyOffsetArray` at a given offset and energy.
+    def evaluate(self, energy=None, offset=None, rad=None, interp_kwargs=None):
+        """Interpolate PSF value at a given offset and energy.
 
         Parameters
         ----------
@@ -185,7 +203,6 @@ class PSF3D(object):
         values : `~astropy.units.Quantity`
             Interpolated value
         """
-        from scipy.interpolate import RegularGridInterpolator
         if not interp_kwargs:
             interp_kwargs = dict(bounds_error=False, fill_value=None)
 
@@ -196,23 +213,23 @@ class PSF3D(object):
         if rad is None:
             rad = self._rad_center()
 
-        energy = Energy(energy).to('TeV')
-        offset = Angle(offset).to('deg')
-        rad = Angle(rad).to('deg')
+        energy = Energy(energy).to("TeV")
+        offset = Angle(offset).to("deg")
+        rad = Angle(rad).to("deg")
 
         energy_bin = self._energy_logcenter()
 
-        offset_bin = self.offset.to('deg')
+        offset_bin = self.offset.to("deg")
         rad_bin = self._rad_center()
         points = (rad_bin, offset_bin, energy_bin)
         interpolator = RegularGridInterpolator(points, self.psf_value, **interp_kwargs)
-        rr, off, ee = np.meshgrid(rad.value, offset.value, energy.value, indexing='ij')
+        rr, off, ee = np.meshgrid(rad.value, offset.value, energy.value, indexing="ij")
         shape = ee.shape
         pix_coords = np.column_stack([rr.flat, off.flat, ee.flat])
         data_interp = interpolator(pix_coords)
         return Quantity(data_interp.reshape(shape), self.psf_value.unit)
 
-    def to_energy_dependent_table_psf(self, theta='0 deg', exposure=None):
+    def to_energy_dependent_table_psf(self, theta="0 deg", rad=None, exposure=None):
         """
         Convert PSF3D in EnergyDependentTablePSF.
 
@@ -220,6 +237,9 @@ class PSF3D(object):
         ----------
         theta : `~astropy.coordinates.Angle`
             Offset in the field of view
+        rad : `~astropy.coordinates.Angle`
+            Offset from PSF center used for evaluating the PSF on a grid.
+            Default is the ``rad`` from this PSF.
         exposure : `~astropy.units.Quantity`
             Energy dependent exposure. Should be in units equivalent to 'cm^2 s'.
             Default exposure = 1.
@@ -231,17 +251,21 @@ class PSF3D(object):
         """
         theta = Angle(theta)
         energies = self._energy_logcenter()
-        rad = self._rad_center()
-        psf_value = self.evaluate(offset=theta)
+
+        if rad is None:
+            rad = self._rad_center()
+        else:
+            rad = Angle(rad)
+
+        psf_value = self.evaluate(offset=theta, rad=rad)
         psf_value = psf_value[:, 0, :].transpose()
 
         return EnergyDependentTablePSF(
-            energy=energies, rad=rad,
-            exposure=exposure, psf_value=psf_value,
+            energy=energies, rad=rad, exposure=exposure, psf_value=psf_value
         )
 
-    def to_table_psf(self, energy, theta='0 deg', interp_kwargs=None, **kwargs):
-        """Evaluate the `EnergyOffsetArray` at one given energy.
+    def to_table_psf(self, energy, theta="0 deg", interp_kwargs=None, **kwargs):
+        """Create `~gammapy.irf.TablePSF` at one given energy.
 
         Parameters
         ----------
@@ -254,18 +278,18 @@ class PSF3D(object):
 
         Returns
         -------
-        table : `~astropy.table.Table`
-            Table with two columns: offset, value
+        psf : `~gammapy.irf.TablePSF`
+            Table PSF
         """
         energy = Quantity(energy)
         theta = Angle(theta)
         psf_value = self.evaluate(energy, theta, interp_kwargs=interp_kwargs).squeeze()
         rad = self._rad_center()
-        table_psf = TablePSF(rad, psf_value, **kwargs)
+        return TablePSF(rad, psf_value, **kwargs)
 
-        return table_psf
-
-    def containment_radius(self, energy, theta='0 deg', fraction=0.68, interp_kwargs=None):
+    def containment_radius(
+        self, energy, theta="0 deg", fraction=0.68, interp_kwargs=None
+    ):
         """Containment radius.
 
         Parameters
@@ -308,29 +332,29 @@ class PSF3D(object):
 
         return Quantity(radius.squeeze(), unit)
 
-    def plot_containment_vs_energy(self, fractions=[0.68, 0.95],
-                                   thetas=Angle([0, 1], 'deg'), ax=None):
+    def plot_containment_vs_energy(
+        self, fractions=[0.68, 0.95], thetas=Angle([0, 1], "deg"), ax=None
+    ):
         """Plot containment fraction as a function of energy.
         """
         import matplotlib.pyplot as plt
 
         ax = plt.gca() if ax is None else ax
 
-        energy = Energy.equal_log_spacing(
-            self.energy_lo[0], self.energy_hi[-1], 100)
+        energy = Energy.equal_log_spacing(self.energy_lo[0], self.energy_hi[-1], 100)
 
         for theta in thetas:
             for fraction in fractions:
                 radius = self.containment_radius(energy, theta, fraction).squeeze()
-                label = '{} deg, {:.1f}%'.format(theta, 100 * fraction)
+                label = "{} deg, {:.1f}%".format(theta, 100 * fraction)
                 ax.plot(energy.value, radius.value, label=label)
 
         ax.semilogx()
-        ax.legend(loc='best')
-        ax.set_xlabel('Energy (TeV)')
-        ax.set_ylabel('Containment radius (deg)')
+        ax.legend(loc="best")
+        ax.set_xlabel("Energy (TeV)")
+        ax.set_ylabel("Containment radius (deg)")
 
-    def plot_psf_vs_rad(self, theta='0 deg', energy=Quantity(1, 'TeV')):
+    def plot_psf_vs_rad(self, theta="0 deg", energy=Quantity(1, "TeV")):
         """Plot PSF vs rad.
 
         Parameters
@@ -344,8 +368,9 @@ class PSF3D(object):
         table = self.to_table_psf(energy=energy, theta=theta)
         return table.plot_psf_vs_rad()
 
-    def plot_containment(self, fraction=0.68, ax=None, show_safe_energy=False,
-                         add_cbar=True, **kwargs):
+    def plot_containment(
+        self, fraction=0.68, ax=None, show_safe_energy=False, add_cbar=True, **kwargs
+    ):
         """
         Plot containment image with energy and theta axes.
 
@@ -367,9 +392,9 @@ class PSF3D(object):
         containment = self.containment_radius(energy, offset, fraction)
 
         # plotting defaults
-        kwargs.setdefault('cmap', 'GnBu')
-        kwargs.setdefault('vmin', np.nanmin(containment.value))
-        kwargs.setdefault('vmax', np.nanmax(containment.value))
+        kwargs.setdefault("cmap", "GnBu")
+        kwargs.setdefault("vmin", np.nanmin(containment.value))
+        kwargs.setdefault("vmax", np.nanmax(containment.value))
 
         # Plotting
         x = energy.value
@@ -378,8 +403,8 @@ class PSF3D(object):
 
         # Axes labels and ticks, colobar
         ax.semilogx()
-        ax.set_ylabel('Offset ({unit})'.format(unit=offset.unit))
-        ax.set_xlabel('Energy ({unit})'.format(unit=energy.unit))
+        ax.set_ylabel("Offset ({unit})".format(unit=offset.unit))
+        ax.set_xlabel("Energy ({unit})".format(unit=energy.unit))
         ax.set_xlim(x.min(), x.max())
         ax.set_ylim(y.min(), y.max())
 
@@ -387,9 +412,10 @@ class PSF3D(object):
             self._plot_safe_energy_range(ax)
 
         if add_cbar:
-            label = ('Containment radius R{0:.0f} ({1})'
-                     ''.format(100 * fraction, containment.unit))
-            cbar = ax.figure.colorbar(caxes, ax=ax, label=label)
+            label = "Containment radius R{0:.0f} ({1})" "".format(
+                100 * fraction, containment.unit
+            )
+            ax.figure.colorbar(caxes, ax=ax, label=label)
 
         return ax
 
@@ -399,12 +425,13 @@ class PSF3D(object):
         omin = self.offset.value.min()
         omax = self.offset.value.max()
         ax.hlines(y=esafe.value, xmin=omin, xmax=omax)
-        label = 'Safe energy threshold: {0:3.2f}'.format(esafe)
-        ax.text(x=0.1, y=0.9 * esafe.value, s=label, va='top')
+        label = "Safe energy threshold: {0:3.2f}".format(esafe)
+        ax.text(x=0.1, y=0.9 * esafe.value, s=label, va="top")
 
     def peek(self, figsize=(15, 5)):
         """Quick-look summary plots."""
         import matplotlib.pyplot as plt
+
         fig, axes = plt.subplots(nrows=1, ncols=3, figsize=figsize)
 
         self.plot_containment(fraction=0.68, ax=axes[0])
