@@ -58,7 +58,7 @@ class EnergyDependentMultiGaussPSF(object):
 
         import matplotlib.pyplot as plt
         from gammapy.irf import EnergyDependentMultiGaussPSF
-        filename = '$GAMMAPY_EXTRA/test_datasets/unbundled/irfs/psf.fits'
+        filename = '$GAMMAPY_DATA/tests/unbundled/irfs/psf.fits'
         psf = EnergyDependentMultiGaussPSF.read(filename, hdu='POINT SPREAD FUNCTION')
         psf.plot_containment(0.68, show_safe_energy=False)
         plt.show()
@@ -369,8 +369,8 @@ class EnergyDependentMultiGaussPSF(object):
     def info(
         self,
         fractions=[0.68, 0.95],
-        energies=Quantity([1., 10.], "TeV"),
-        thetas=Quantity([0.], "deg"),
+        energies=Quantity([1.0, 10.0], "TeV"),
+        thetas=Quantity([0.0], "deg"),
     ):
         """
         Print PSF summary info.
