@@ -1,17 +1,15 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 from __future__ import absolute_import, division, print_function, unicode_literals
-import copy
 import numpy as np
 from astropy.io import fits
-from .utils import unpack_seq
-from .geom import MapCoord, pix_tuple_to_idx, coord_to_idx
+from astropy.units import Quantity
+from ..utils.units import unit_from_fits_image_hdu
+from .geom import MapCoord, pix_tuple_to_idx
 from .utils import interp_to_order
 from .hpxmap import HpxMap
 from .hpx import HpxGeom, HpxToWcsMapping, nside_to_order
 
-__all__ = [
-    'HpxNDMap',
-]
+__all__ = ["HpxNDMap"]
 
 
 class HpxNDMap(HpxMap):
@@ -32,28 +30,31 @@ class HpxNDMap(HpxMap):
         If none then an empty array will be allocated.
     meta : `~collections.OrderedDict`
         Dictionary to store meta data.
+    unit : str or `~astropy.units.Unit`
+        The map unit
     """
 
-    def __init__(self, geom, data=None, dtype='float32', meta=None):
+    def __init__(self, geom, data=None, dtype="float32", meta=None, unit=""):
+        data_shape = geom.data_shape
 
-        shape = tuple([np.max(geom.npix)] + [ax.nbin for ax in geom.axes])
         if data is None:
+            data = self._make_default_data(geom, data_shape, dtype)
 
-            if geom.npix.size > 1:
-                data = np.nan * np.ones(shape, dtype=dtype).T
-                idx = geom.get_idx(local=True)
-                data[idx[::-1]] = 0.0
-            else:
-                data = np.zeros(shape, dtype=dtype).T
-
-        elif data.shape != shape[::-1]:
-            raise ValueError('Wrong shape for input data array. Expected {} '
-                             'but got {}'.format(shape, data.shape))
-
-        super(HpxNDMap, self).__init__(geom, data, meta)
+        super(HpxNDMap, self).__init__(geom, data, meta, unit)
         self._wcs2d = None
         self._hpx2wcs = None
 
+    @staticmethod
+    def _make_default_data(geom, shape_np, dtype):
+        if geom.npix.size > 1:
+            data = np.full(shape_np, np.nan, dtype=dtype)
+            idx = geom.get_idx(local=True)
+            data[idx[::-1]] = 0
+        else:
+            data = np.zeros(shape_np, dtype=dtype)
+
+        return data
+
     @classmethod
     def from_hdu(cls, hdu, hdu_bands=None):
         """Make a HpxNDMap object from a FITS HDU.
@@ -67,20 +68,21 @@ class HpxNDMap(HpxMap):
         """
         hpx = HpxGeom.from_header(hdu.header, hdu_bands)
         shape = tuple([ax.nbin for ax in hpx.axes[::-1]])
-        shape_data = shape + tuple([np.max(hpx.npix)])
+        # shape_data = shape + tuple([np.max(hpx.npix)])
 
         # TODO: Should we support extracting slices?
 
         meta = cls._get_meta_from_header(hdu.header)
-        map_out = cls(hpx, None, meta=meta)
+        unit = unit_from_fits_image_hdu(hdu.header)
+        map_out = cls(hpx, None, meta=meta, unit=unit)
 
         colnames = hdu.columns.names
         cnames = []
-        if hdu.header.get('INDXSCHM', None) == 'SPARSE':
-            pix = hdu.data.field('PIX')
-            vals = hdu.data.field('VALUE')
-            if 'CHANNEL' in hdu.data.columns.names:
-                chan = hdu.data.field('CHANNEL')
+        if hdu.header.get("INDXSCHM", None) == "SPARSE":
+            pix = hdu.data.field("PIX")
+            vals = hdu.data.field("VALUE")
+            if "CHANNEL" in hdu.data.columns.names:
+                chan = hdu.data.field("CHANNEL")
                 chan = np.unravel_index(chan, shape)
                 idx = chan + (pix,)
             else:
@@ -92,7 +94,7 @@ class HpxNDMap(HpxMap):
                 if c.find(hpx.hpx_conv.colstring) == 0:
                     cnames.append(c)
             nbin = len(cnames)
-            if len(cnames) == 1:
+            if nbin == 1:
                 map_out.data = hdu.data.field(cnames[0])
             else:
                 for i, cname in enumerate(cnames):
@@ -101,7 +103,9 @@ class HpxNDMap(HpxMap):
 
         return map_out
 
-    def make_wcs_mapping(self, sum_bands=False, proj='AIT', oversample=2, width_pix=None):
+    def make_wcs_mapping(
+        self, sum_bands=False, proj="AIT", oversample=2, width_pix=None
+    ):
         """Make a HEALPix to WCS mapping object.
 
         Parameters
@@ -126,64 +130,57 @@ class HpxNDMap(HpxMap):
         hpx2wcs : `~HpxToWcsMapping`
 
         """
-        self._wcs2d = self.geom.make_wcs(proj=proj, oversample=oversample,
-                                         width_pix=width_pix,
-                                         drop_axes=True)
+        self._wcs2d = self.geom.make_wcs(
+            proj=proj, oversample=oversample, width_pix=width_pix, drop_axes=True
+        )
         self._hpx2wcs = HpxToWcsMapping.create(self.geom, self._wcs2d)
         return self._hpx2wcs
 
-    def to_wcs(self, sum_bands=False, normalize=True, proj='AIT', oversample=2,
-               width_pix=None, hpx2wcs=None):
-
+    def to_wcs(
+        self,
+        sum_bands=False,
+        normalize=True,
+        proj="AIT",
+        oversample=2,
+        width_pix=None,
+        hpx2wcs=None,
+    ):
         from .wcsnd import WcsNDMap
 
         if sum_bands and self.geom.nside.size > 1:
             map_sum = self.sum_over_axes()
-            return map_sum.to_wcs(sum_bands=False, normalize=normalize, proj=proj,
-                                  oversample=oversample, width_pix=width_pix)
+            return map_sum.to_wcs(
+                sum_bands=False,
+                normalize=normalize,
+                proj=proj,
+                oversample=oversample,
+                width_pix=width_pix,
+            )
 
         # FIXME: Check whether the old mapping is still valid and reuse it
         if hpx2wcs is None:
-            hpx2wcs = self.make_wcs_mapping(oversample=oversample, proj=proj,
-                                            width_pix=width_pix)
+            hpx2wcs = self.make_wcs_mapping(
+                oversample=oversample, proj=proj, width_pix=width_pix
+            )
 
         # FIXME: Need a function to extract a valid shape from npix property
 
         if sum_bands:
-            hpx_data = np.apply_over_axes(np.sum, self.data,
-                                          axes=np.arange(self.data.ndim - 1))
+            axes = np.arange(self.data.ndim - 1)
+            hpx_data = np.apply_over_axes(np.sum, self.data, axes=axes)
             hpx_data = np.squeeze(hpx_data)
             wcs_shape = tuple([t.flat[0] for t in hpx2wcs.npix])
             wcs_data = np.zeros(wcs_shape).T
             wcs = hpx2wcs.wcs.to_image()
         else:
             hpx_data = self.data
-            wcs_shape = tuple([t.flat[0] for t in
-                               hpx2wcs.npix]) + self.geom._shape
+            wcs_shape = tuple([t.flat[0] for t in hpx2wcs.npix]) + self.geom.shape
             wcs_data = np.zeros(wcs_shape).T
             wcs = hpx2wcs.wcs.to_cube(self.geom.axes)
 
         # FIXME: Should reimplement instantiating map first and fill data array
         hpx2wcs.fill_wcs_map_from_hpx_data(hpx_data, wcs_data, normalize)
-        return WcsNDMap(wcs, wcs_data)
-
-    def iter_by_image(self):
-        for idx in np.ndindex(self.geom.shape):
-            yield self.data[idx[::-1]], idx
-
-    def iter_by_pix(self, buffersize=1):
-        idx = list(self.geom.get_idx(flat=True))
-        vals = self.data[np.isfinite(self.data)]
-        return unpack_seq(np.nditer([vals] + idx,
-                                    flags=['external_loop', 'buffered'],
-                                    buffersize=buffersize))
-
-    def iter_by_coord(self, buffersize=1):
-        coords = list(self.geom.get_coord(flat=True))
-        vals = self.data[np.isfinite(self.data)]
-        return unpack_seq(np.nditer([vals] + coords,
-                                    flags=['external_loop', 'buffered'],
-                                    buffersize=buffersize))
+        return WcsNDMap(wcs, wcs_data, unit=self.unit)
 
     def sum_over_axes(self):
         """Sum over all non-spatial dimensions.
@@ -193,119 +190,94 @@ class HpxNDMap(HpxMap):
         map_out : `~HpxNDMap`
             Summed map.
         """
-        hpx_out = self.geom.to_image()
-        map_out = self.__class__(hpx_out)
-
-        if self.geom.nside.size > 1:
-            vals = self.get_by_idx(self.geom.get_idx(flat=True))
-            map_out.fill_by_coord(self.geom.get_coord(flat=True)[:2], vals)
-        else:
-            axes = np.arange(self.data.ndim - 1).tolist()
-            data = np.apply_over_axes(np.sum, self.data, axes=axes)
-            map_out.data = np.squeeze(data, axis=axes)
-
-        return map_out
-
-    def _reproject_wcs(self, geom, order=1, mode='interp'):
+        geom = self.geom.to_image()
+        axis = tuple(range(self.data.ndim - 1))
+        data = np.nansum(self.data, axis=axis)
+        return self._init_copy(geom=geom, data=data)
 
+    def _reproject_to_wcs(self, geom, order=1, mode="interp"):
         from reproject import reproject_from_healpix
-        from .wcsnd import WcsNDMap
 
-        map_out = WcsNDMap(geom)
-        coordsys = 'galactic' if geom.coordsys == 'GAL' else 'icrs'
-        axes_eq = np.all([ax0 == ax1 for ax0, ax1 in
-                          zip(geom.axes, self.geom.axes)])
-
-        for vals, idx in map_out.iter_by_image():
-
-            if self.geom.ndim == 2 or axes_eq:
-                img = self.data[idx[::-1]]
-            else:
-                raise NotImplementedError
+        data = np.empty(geom.data_shape)
+        coordsys = "galactic" if geom.coordsys == "GAL" else "icrs"
 
+        for img, idx in self.iter_by_image():
             # TODO: Create WCS object for image plane if
             # multi-resolution geom
             shape_out = geom.get_image_shape(idx)[::-1]
+            vals, footprint = reproject_from_healpix(
+                (img, coordsys),
+                geom.wcs,
+                shape_out=shape_out,
+                nested=self.geom.nest,
+                order=order,
+            )
+            data[idx] = vals
 
-            data, footprint = reproject_from_healpix((img, coordsys),
-                                                     geom.wcs,
-                                                     shape_out=shape_out)
-            vals[...] = data
+        return self._init_copy(geom=geom, data=data)
 
-        return map_out
+    def _reproject_to_hpx(self):
+        raise NotImplementedError("Maybe try using Map.interp_by_coord().")
 
-    def _reproject_hpx(self, geom, order=1, mode='interp'):
-        map_out = HpxNDMap(geom)
-        axes_eq = np.all([ax0 == ax1 for ax0, ax1 in
-                          zip(geom.axes, self.geom.axes)])
-
-        for vals, idx in map_out.iter_by_image():
-            raise NotImplementedError
-
-        return map_out
-
-    def pad(self, pad_width, mode='constant', cval=0.0, order=1):
+    def pad(self, pad_width, mode="constant", cval=0, order=1):
         geom = self.geom.pad(pad_width)
-        map_out = self.__class__(geom, meta=copy.deepcopy(self.meta))
+        map_out = self._init_copy(geom=geom, data=None)
         map_out.coadd(self)
         coords = geom.get_coord(flat=True)
         m = self.geom.contains(coords)
         coords = tuple([c[~m] for c in coords])
 
-        if mode == 'constant':
+        if mode == "constant":
             map_out.set_by_coord(coords, cval)
-        elif mode in ['edge', 'interp']:
+        elif mode == "interp":
             # FIXME: These modes don't work at present because
             # interp_by_coord doesn't support extrapolation
-            vals = self.interp_by_coord(coords, interp=0 if mode == 'edge'
-                                        else order)
+            vals = self.interp_by_coord(coords, interp=order)
             map_out.set_by_coord(coords, vals)
         else:
-            raise ValueError('Unrecognized pad mode: {}'.format(mode))
+            raise ValueError("Unrecognized pad mode: {!r}".format(mode))
 
         return map_out
 
     def crop(self, crop_width):
         geom = self.geom.crop(crop_width)
-        map_out = self.__class__(geom, meta=copy.deepcopy(self.meta))
+        map_out = self._init_copy(geom=geom, data=None)
         map_out.coadd(self)
         return map_out
 
     def upsample(self, factor, preserve_counts=True):
-
-        map_out = self.__class__(self.geom.upsample(factor),
-                                 meta=copy.deepcopy(self.meta))
-        coords = map_out.geom.get_coord(flat=True)
-        vals = self.get_by_coord(coords)
-        m = np.isfinite(vals)
-        map_out.fill_by_coord([c[m] for c in coords], vals[m])
+        geom = self.geom.upsample(factor)
+        coords = geom.get_coord()
+        data = self.get_by_coord(coords)
 
         if preserve_counts:
-            map_out.data /= factor**2
+            data /= factor ** 2
 
-        return map_out
+        return self._init_copy(geom=geom, data=data)
 
     def downsample(self, factor, preserve_counts=True):
+        geom = self.geom.downsample(factor)
+        coords = self.geom.get_coord()
+        vals = self.get_by_coord(coords)
 
-        map_out = self.__class__(self.geom.downsample(factor),
-                                 meta=copy.deepcopy(self.meta))
-        idx = self.geom.get_idx(flat=True)
-        coords = self.geom.pix_to_coord(idx)
-        vals = self.get_by_idx(idx)
+        map_out = self._init_copy(geom=geom, data=None)
         map_out.fill_by_coord(coords, vals)
 
         if not preserve_counts:
-            map_out.data /= factor**2
+            map_out.data /= factor ** 2
 
         return map_out
 
     def interp_by_coord(self, coords, interp=1):
+        # inherited docstring
+        coords = MapCoord.create(coords, coordsys=self.geom.coordsys)
+        coords = coords.match_axes_units(self.geom)
 
         order = interp_to_order(interp)
         if order == 1:
             return self._interp_by_coord(coords, order)
         else:
-            raise ValueError('Invalid interpolation order: {}'.format(order))
+            raise ValueError("Invalid interpolation order: {!r}".format(order))
 
     def interp_by_pix(self, pix, interp=None):
         """Interpolate map values at the given pixel coordinates.
@@ -313,36 +285,30 @@ class HpxNDMap(HpxMap):
         raise NotImplementedError
 
     def get_by_idx(self, idx):
+        # inherited docstring
         idx = pix_tuple_to_idx(idx)
         idx = self.geom.global_to_local(idx)
         return self.data.T[idx]
 
-    def _get_interp_weights(self, coords, idxs):
-
+    def _get_interp_weights(self, coords, idxs=None):
         import healpy as hp
 
-        c = MapCoord.create(coords)
-        coords_ctr = list(coords[:2])
-        coords_ctr += [ax.pix_to_coord(t)
-                       for ax, t in zip(self.geom.axes, idxs)]
-        idx_ctr = pix_tuple_to_idx(self.geom.coord_to_pix(coords_ctr))
-        idx_ctr = self.geom.global_to_local(idx_ctr)
+        if idxs is None:
+            idxs = self.geom.coord_to_idx(coords, clip=True)[1:]
 
-        theta = np.array(np.pi / 2. - np.radians(c.lat), ndmin=1)
-        phi = np.array(np.radians(c.lon), ndmin=1)
+        theta, phi = coords.theta, coords.phi
 
         m = ~np.isfinite(theta)
-        theta[m] = 0.0
-        phi[m] = 0.0
+        theta[m] = 0
+        phi[m] = 0
 
-        if self.geom.nside.size > 1:
-            nside = self.geom.nside[idxs]
+        if not self.geom.is_regular:
+            nside = self.geom.nside[tuple(idxs)]
         else:
             nside = self.geom.nside
 
-        pix, wts = hp.get_interp_weights(nside, theta,
-                                         phi, nest=self.geom.nest)
-        wts[:, m] = 0.0
+        pix, wts = hp.get_interp_weights(nside, theta, phi, nest=self.geom.nest)
+        wts[:, m] = 0
         pix[:, m] = -1
 
         if not self.geom.is_regular:
@@ -350,47 +316,49 @@ class HpxNDMap(HpxMap):
         else:
             pix_local = [self.geom[pix]]
 
-        # If a pixel lies outside of the geometry set its index to the
-        # center pixel
+        # If a pixel lies outside of the geometry set its index to the center pixel
         m = pix_local[0] == -1
-        pix_local[0][m] = (idx_ctr[0] * np.ones(pix.shape, dtype=int))[m]
+        if m.any():
+            coords_ctr = [coords.lon, coords.lat]
+            coords_ctr += [ax.pix_to_coord(t) for ax, t in zip(self.geom.axes, idxs)]
+            idx_ctr = self.geom.coord_to_idx(coords_ctr)
+            idx_ctr = self.geom.global_to_local(idx_ctr)
+            pix_local[0][m] = (idx_ctr[0] * np.ones(pix.shape, dtype=int))[m]
+
         pix_local += [np.broadcast_to(t, pix_local[0].shape) for t in idxs]
         return pix_local, wts
 
     def _interp_by_coord(self, coords, order):
         """Linearly interpolate map values."""
-        c = MapCoord.create(coords)
-        idx_ax = self.geom.coord_to_idx(c, clip=True)[1:]
-        pix, wts = self._get_interp_weights(coords, idx_ax)
+        pix, wts = self._get_interp_weights(coords)
 
-        if self.geom.ndim == 2:
-            return np.sum(self.data.T[pix] * wts, axis=0)
+        if self.geom.is_image:
+            return np.sum(self.data.T[tuple(pix)] * wts, axis=0)
 
         val = np.zeros(pix[0].shape[1:])
+
         # Loop over function values at corners
-        for i, t in enumerate(range(2 ** len(self.geom.axes))):
-
+        for i in range(2 ** len(self.geom.axes)):
             pix_i = []
-            wt = np.ones(pix[0].shape[1:])[None, ...]
+            wt = np.ones(pix[0].shape[1:])[np.newaxis, ...]
             for j, ax in enumerate(self.geom.axes):
-
-                idx = coord_to_idx(ax.center[:-1],
-                                   c[2 + j], clip=True)  # [None, ...]
+                idx = ax.coord_to_idx(coords[ax.name])
+                idx = np.clip(idx, 0, len(ax.center) - 2)
 
                 w = ax.center[idx + 1] - ax.center[idx]
                 if i & (1 << j):
-                    wt *= (c[2 + j] - ax.center[idx]) / w
-                    pix_i += [1 + idx]
+                    wt *= (coords[ax.name] - ax.center[idx]) / w
+                    pix_i += [idx + 1]
                 else:
-                    wt *= (1.0 - (c[2 + j] - ax.center[idx]) / w)
+                    wt *= 1.0 - (coords[ax.name] - ax.center[idx]) / w
                     pix_i += [idx]
 
             if not self.geom.is_regular:
                 pix, wts = self._get_interp_weights(coords, pix_i)
 
-            wts[pix[0] == -1] = 0.0
-            wt[~np.isfinite(wt)] = 0.0
-            val += np.nansum(wts * wt * self.data.T[pix[:1] + pix_i], axis=0)
+            wts[pix[0] == -1] = 0
+            wt[~np.isfinite(wt)] = 0
+            val += np.nansum(wts * wt * self.data.T[tuple(pix[:1] + pix_i)], axis=0)
 
         return val
 
@@ -405,6 +373,8 @@ class HpxNDMap(HpxMap):
         msk = idx_local[0] >= 0
         idx_local = [t[msk] for t in idx_local]
         if weights is not None:
+            if isinstance(weights, Quantity):
+                weights = weights.to_value(self.unit)
             weights = weights[msk]
 
         idx_local = np.ravel_multi_index(idx_local, self.data.T.shape)
@@ -420,36 +390,38 @@ class HpxNDMap(HpxMap):
     def _make_cols(self, header, conv):
         shape = self.data.shape
         cols = []
-        if header['INDXSCHM'] == 'SPARSE':
+
+        if header["INDXSCHM"] == "SPARSE":
             data = self.data.copy()
             data[~np.isfinite(data)] = 0
             nonzero = np.where(data > 0)
+            value = data[nonzero].astype(float)
             pix = self.geom.local_to_global(nonzero[::-1])[0]
             if len(shape) == 1:
-                cols.append(fits.Column('PIX', 'J', array=pix))
-                cols.append(fits.Column('VALUE', 'E',
-                                        array=data[nonzero].astype(float)))
-
+                cols.append(fits.Column("PIX", "J", array=pix))
+                cols.append(fits.Column("VALUE", "E", array=value))
             else:
                 channel = np.ravel_multi_index(nonzero[:-1], shape[:-1])
-                cols.append(fits.Column('PIX', 'J', array=pix))
-                cols.append(fits.Column('CHANNEL', 'I', array=channel))
-                cols.append(fits.Column('VALUE', 'E',
-                                        array=data[nonzero].astype(float)))
-
+                cols.append(fits.Column("PIX", "J", array=pix))
+                cols.append(fits.Column("CHANNEL", "I", array=channel))
+                cols.append(fits.Column("VALUE", "E", array=value))
         elif len(shape) == 1:
-            cols.append(fits.Column(conv.colname(indx=conv.firstcol),
-                                    'E', array=self.data.astype(float)))
+            name = conv.colname(indx=conv.firstcol)
+            array = self.data.astype(float)
+            cols.append(fits.Column(name, "E", array=array))
         else:
             for i, idx in enumerate(np.ndindex(shape[:-1])):
-                cols.append(fits.Column(conv.colname(indx=i + conv.firstcol), 'E',
-                                        array=self.data[idx].astype(float)))
+                name = conv.colname(indx=i + conv.firstcol)
+                array = self.data[idx].astype(float)
+                cols.append(fits.Column(name, "E", array=array))
+
         return cols
 
     def to_swapped(self):
         import healpy as hp
+
         hpx_out = self.geom.to_swapped()
-        map_out = self.__class__(hpx_out, meta=copy.deepcopy(self.meta))
+        map_out = self._init_copy(geom=hpx_out, data=None)
         idx = self.geom.get_idx(flat=True)
         vals = self.get_by_idx(idx)
         if self.geom.nside.size > 1:
@@ -466,13 +438,11 @@ class HpxNDMap(HpxMap):
         return map_out
 
     def to_ud_graded(self, nside, preserve_counts=False):
-
         # FIXME: Should we remove/deprecate this method?
 
-        import healpy as hp
         order = nside_to_order(nside)
         new_hpx = self.geom.to_ud_graded(order)
-        map_out = self.__class__(new_hpx, meta=copy.deepcopy(self.meta))
+        map_out = self._init_copy(geom=new_hpx, data=None)
 
         if np.all(order <= self.geom.order):
             # Downsample
@@ -496,8 +466,16 @@ class HpxNDMap(HpxMap):
 
         return map_out
 
-    def plot(self, method='raster', ax=None, idx=None, normalize=False, proj='AIT', oversample=4,
-             width_pix=1000, **kwargs):
+    def plot(
+        self,
+        method="raster",
+        ax=None,
+        normalize=False,
+        proj="AIT",
+        oversample=2,
+        width_pix=1000,
+        **kwargs
+    ):
         """Quickplot method.
 
         This will generate a visualization of the map by converting to
@@ -524,35 +502,34 @@ class HpxNDMap(HpxMap):
             be set to the number of pixels satisfying ``oversample``
             or ``width_pix`` whichever is smaller.  If this parameter
             is None then the width will be set from ``oversample``.
-        idx : tuple
-            Set the image slice to plot if this map has non-spatial
-            dimensions.
         **kwargs : dict
             Keyword arguments passed to `~matplotlib.pyplot.imshow`.
+
         Returns
         -------
         fig : `~matplotlib.figure.Figure`
             Figure object.
-
         ax : `~astropy.visualization.wcsaxes.WCSAxes`
             WCS axis object
-
         im : `~matplotlib.image.AxesImage` or `~matplotlib.collections.PatchCollection`
             Image object.
 
         """
-        if method == 'raster':
-            m = self.to_wcs(sum_bands=True,
-                            normalize=normalize,
-                            proj=proj, oversample=oversample,
-                            width_pix=width_pix)
+        if method == "raster":
+            m = self.to_wcs(
+                sum_bands=True,
+                normalize=normalize,
+                proj=proj,
+                oversample=oversample,
+                width_pix=width_pix,
+            )
             return m.plot(ax, **kwargs)
-        elif method == 'poly':
+        elif method == "poly":
             return self._plot_poly(proj=proj, ax=ax)
         else:
-            raise ValueError('Invalid method: {}'.format(method))
+            raise ValueError("Invalid method: {!r}".format(method))
 
-    def _plot_poly(self, proj='AIT', step=1, ax=None):
+    def _plot_poly(self, proj="AIT", step=1, ax=None):
         """Plot the map using a collection of polygons.
 
         Parameters
@@ -576,12 +553,11 @@ class HpxNDMap(HpxMap):
         wcs = self.geom.make_wcs(proj=proj, oversample=1)
         if ax is None:
             fig = plt.gcf()
-            ax = fig.add_subplot(111, projection=wcs.wcs, aspect='equal')
+            ax = fig.add_subplot(111, projection=wcs.wcs, aspect="equal")
 
         wcs_lonlat = wcs.center_coord[:2]
         idx = self.geom.get_idx()
-        vtx = hp.boundaries(self.geom.nside, idx[0],
-                            nest=self.geom.nest, step=step)
+        vtx = hp.boundaries(self.geom.nside, idx[0], nest=self.geom.nest, step=step)
         theta, phi = hp.vec2ang(np.rollaxis(vtx, 2))
         theta = theta.reshape((4 * step, -1)).T
         phi = phi.reshape((4 * step, -1)).T
@@ -590,26 +566,25 @@ class HpxNDMap(HpxMap):
         data = []
 
         def get_angle(x, t):
-            return 180. - (180. - x + t) % 360.
+            return 180.0 - (180.0 - x + t) % 360.0
 
         for i, (x, y) in enumerate(zip(phi, theta)):
 
-            lon, lat = np.degrees(x), np.degrees(np.pi / 2. - y)
+            lon, lat = np.degrees(x), np.degrees(np.pi / 2.0 - y)
             # Add a small ofset to avoid vertices wrapping to the
             # other size of the projection
-            if get_angle(np.median(lon), wcs_lonlat[0]) > 0.0:
-                idx = wcs.coord_to_pix((lon - 1E-4, lat))
+            if get_angle(np.median(lon), wcs_lonlat[0]) > 0:
+                idx = wcs.coord_to_pix((lon - 1e-4, lat))
             else:
-                idx = wcs.coord_to_pix((lon + 1E-4, lat))
+                idx = wcs.coord_to_pix((lon + 1e-4, lat))
 
             dist = np.max(np.abs(idx[0][0] - idx[0]))
 
             # Split pixels that wrap around the edges of the projection
-            if (dist > wcs.npix[0] / 1.5):
-
-                lon, lat = np.degrees(x), np.degrees(np.pi / 2. - y)
-                lon0 = lon - 1E-4
-                lon1 = lon + 1E-4
+            if dist > wcs.npix[0] / 1.5:
+                lon, lat = np.degrees(x), np.degrees(np.pi / 2.0 - y)
+                lon0 = lon - 1e-4
+                lon1 = lon + 1e-4
                 pix0 = wcs.coord_to_pix((lon0, lat))
                 pix1 = wcs.coord_to_pix((lon1, lat))
 
@@ -623,16 +598,15 @@ class HpxNDMap(HpxMap):
                 patches.append(Polygon(np.vstack((pix1[0], pix1[1])).T, True))
                 data.append(self.data[i])
                 data.append(self.data[i])
-
             else:
                 polygon = Polygon(np.vstack((idx[0], idx[1])).T, True)
                 patches.append(polygon)
                 data.append(self.data[i])
 
-        p = PatchCollection(patches, linewidths=0, edgecolors='None')
+        p = PatchCollection(patches, linewidths=0, edgecolors="None")
         p.set_array(np.array(data))
         ax.add_collection(p)
         ax.autoscale_view()
-        ax.coords.grid(color='w', linestyle=':', linewidth=0.5)
+        ax.coords.grid(color="w", linestyle=":", linewidth=0.5)
 
         return fig, ax, p
