@@ -8,8 +8,6 @@ from astropy import units as u
 from astropy.coordinates import SkyCoord
 from ..geom import MapAxis, MapCoord
 
-pytest.importorskip("scipy")
-
 mapaxis_geoms = [
     (np.array([0.25, 0.75, 1.0, 2.0]), "lin"),
     (np.array([0.25, 0.75, 1.0, 2.0]), "log"),
@@ -121,7 +119,7 @@ def test_mapcoords_create():
 
     # 2D Tuple w/ SkyCoord
     lon, lat = np.array([0.0, 1.0]), np.array([2.0, 3.0])
-    energy = np.array([100., 1000.])
+    energy = np.array([100.0, 1000.0])
     skycoord_cel = SkyCoord(lon, lat, unit="deg", frame="icrs")
     skycoord_gal = SkyCoord(lon, lat, unit="deg", frame="galactic")
     coords = MapCoord.create((skycoord_cel,))
@@ -186,7 +184,7 @@ def test_mapcoords_create():
 
 def test_mapcoords_to_coordsys():
     lon, lat = np.array([0.0, 1.0]), np.array([2.0, 3.0])
-    energy = np.array([100., 1000.])
+    energy = np.array([100.0, 1000.0])
     skycoord_cel = SkyCoord(lon, lat, unit="deg", frame="icrs")
     skycoord_gal = SkyCoord(lon, lat, unit="deg", frame="galactic")
 
@@ -225,3 +223,41 @@ def test_mapaxis_repr():
 def test_mapcoord_repr():
     coord = MapCoord({"lon": 0, "lat": 0, "energy": 5})
     assert "MapCoord" in repr(coord)
+
+
+nodes_array = np.array([0.25, 0.75, 1.0, 2.0])
+
+mapaxis_geoms_node_type_unit = [
+    (nodes_array, "lin", "edges", "s", "TEST", True),
+    (nodes_array, "log", "edges", "s", "test", False),
+    (nodes_array, "lin", "edges", "TeV", "TEST", False),
+    (nodes_array, "sqrt", "edges", "s", "test", False),
+    (nodes_array, "lin", "center", "s", "test", False),
+    (nodes_array + 1e-9, "lin", "edges", "s", "test", True),
+    (nodes_array + 1e-3, "lin", "edges", "s", "test", False),
+]
+
+
+@pytest.mark.parametrize(
+    ("nodes", "interp", "node_type", "unit", "name", "result"),
+    mapaxis_geoms_node_type_unit,
+)
+def test_mapaxis_equal(nodes, interp, node_type, unit, name, result):
+    axis1 = MapAxis(nodes_array, name="test", unit="s", interp="lin", node_type="edges")
+
+    axis2 = MapAxis(nodes, name=name, unit=unit, interp=interp, node_type=node_type)
+
+    assert (axis1 == axis2) is result
+    assert (axis1 != axis2) is not result
+
+
+def test_squash():
+    axis = MapAxis(
+        nodes=[0, 1, 2, 3], unit="TeV", name="energy", node_type="edges", interp="lin"
+    )
+    ax_sq = axis.squash()
+
+    assert_allclose(ax_sq.nbin, 1)
+    assert_allclose(axis.edges[0], ax_sq.edges[0])
+    assert_allclose(axis.edges[-1], ax_sq.edges[1])
+    assert_allclose(ax_sq.center, 1.5)
