@@ -72,29 +72,39 @@ def cli_image():
 
 
 @cli.group("download", short_help="Download datasets and notebooks")
-def cli_download():
-    """Download datasets and notebooks.
+@click.pass_context
+def cli_download(ctx):
+    """Download notebooks, scripts and datasets.
 
-    Download notebooks published as tutorials and the related datasets needed
-    to execute them. It is also possible to download individual notebooks
-    or datasets. The option `tutorials` will download by default the versioned
-    file-structure of the  tutorials into a `gammapy-tutorials` folder created
-    at the current working directory. The option `datasets` will download by
-    default the datasets used by Gammapy into a `gammapy-datasets` folder
-    created at the current working directory. The option `notebooks` will
-    download by default the jupyter notebook files used in the tutorilas into
-    a `gammapy-notebooks` folder created at the current working directory.
+    \b
+    Download notebooks published as tutorials, example python scripts and the
+    related datasets needed to execute them. It is also possible to download
+    individual notebooks, scrtipts or datasets.
+    \b
+    - The option `tutorials` will download versioned folders for the notebooks
+    and python scripts into a `gammapy-tutorials` folder created at the current
+    working directory, as well as the datasets needed to reproduce them.
+    \b
+    - The option `notebooks` will download the notebook files used in the tutorials
+    into a `gammapy-notebooks` folder created at the current working directory.
+    \b
+    - The option `scripts` will download a collection of example python scripts
+    into a `gammapy-scripts` folder created at the current working directory.
+    \b
+    - The option `datasets` will download the datasets used by Gammapy into a
+    `gammapy-datasets` folder created at the current working directory.
 
     \b
     Examples
     --------
 
     \b
+    $ gammapy download scripts
     $ gammapy download notebooks
     $ gammapy download datasets
     $ gammapy download tutorials --release 0.8
     $ gammapy download notebooks --src first_steps
-    $ gammapy download datasets --src fermi_3fhl --out localfolder/
+    $ gammapy download datasets --src fermi-3fhl-gc --out localfolder/
     """
 
 
@@ -149,6 +159,10 @@ def add_subcommands():
 
     cli_download.add_command(cli_download_notebooks)
 
+    from .download import cli_download_scripts
+
+    cli_download.add_command(cli_download_scripts)
+
     from .download import cli_download_datasets
 
     cli_download.add_command(cli_download_datasets)
