@@ -1,12 +1,9 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-"""
-Spectrum estimation and modeling methods (1-dimensional, with an energy axis).
-"""
+"""1D spectrum analysis."""
 from .core import *
 from .observation import *
 from .cosmic_ray import *
 from .crab import *
-from .diffuse import *
 from .energy_group import *
 from .flux_point import *
 from .utils import *
@@ -14,3 +11,4 @@ from .extract import *
 from .simulation import *
 from .fit import *
 from .results import *
+from .sensitivity import *
