@@ -43,7 +43,7 @@ magic_lp = {
 magic_ecpl = {
     "amplitude": 3.80e-11 * u.Unit("1 / (cm2 s TeV)"),
     "index": 2.21,
-    "lambda_": 1 / (6. * u.TeV),
+    "lambda_": 1 / (6.0 * u.TeV),
     "reference": 1 * u.TeV,
 }
 
@@ -62,9 +62,9 @@ class MeyerCrabModel(SpectralModel):
     @staticmethod
     def evaluate(energy):
         polynomial = np.poly1d(MeyerCrabModel.coefficients)
-        log_energy = np.log10(energy.to("TeV").value)
+        log_energy = np.log10(energy.to_value("TeV"))
         log_flux = polynomial(log_energy)
-        flux = np.power(10, log_flux) * u.Unit("erg / (cm2 s)")
+        flux = u.Quantity(np.power(10, log_flux), "erg / (cm2 s)", copy=False)
         return flux / energy ** 2
 
 
