@@ -9,17 +9,12 @@ from astropy.io.registry import IORegistryError
 from ..utils.scripts import make_path
 from ..utils.table import table_standardise_units_copy, table_from_row_data
 from ..utils.fitting import Fit
-from ..stats.fit_statistics import chi2
-from .models import PowerLaw
+from ..utils.interpolation import ScaledRegularGridInterpolator
+from .models import PowerLaw, ScaleModel
 from .powerlaw import power_law_integral_flux
-from . import SpectrumObservationList, SpectrumObservation
+from .observation import SpectrumObservationList, SpectrumObservation
 
-__all__ = [
-    "FluxPoints",
-    # 'FluxPointProfiles',
-    "FluxPointEstimator",
-    "FluxPointFit",
-]
+__all__ = ["FluxPoints", "FluxPointEstimator", "FluxPointFit"]
 
 log = logging.getLogger(__name__)
 
@@ -29,6 +24,19 @@ REQUIRED_COLUMNS = OrderedDict(
         ("e2dnde", ["e_ref", "e2dnde"]),
         ("flux", ["e_min", "e_max", "flux"]),
         ("eflux", ["e_min", "e_max", "eflux"]),
+        # TODO: extend required columns
+        (
+            "likelihood",
+            [
+                "e_min",
+                "e_max",
+                "e_ref",
+                "ref_dnde",
+                "norm",
+                "norm_scan",
+                "dloglike_scan",
+            ],
+        ),
     ]
 )
 
@@ -51,6 +59,18 @@ DEFAULT_UNIT = OrderedDict(
 )
 
 
+def _interp_likelihood_profile(norm_scan, dloglike_scan, norm):
+    """Helper function to interpolate likelihood profiles"""
+    # likelihood profiles are typically of parabolic shape, so we use a
+    # sqrt scaling of the values and perform linear interpolation on the scaled
+    # values
+    sign = np.sign(np.gradient(dloglike_scan))
+    interp = ScaledRegularGridInterpolator(
+        points=(norm_scan,), values=sign * dloglike_scan, values_scale="sqrt"
+    )
+    return interp((norm,))
+
+
 class FluxPoints(object):
     """Flux points container.
 
@@ -76,20 +96,17 @@ class FluxPoints(object):
     Examples
     --------
     The `FluxPoints` object is most easily created by reading a file with
-    flux points given in one of the formats documented above:
-
-    .. code:: python
+    flux points given in one of the formats documented above::
 
         from gammapy.spectrum import FluxPoints
-        filename = '$GAMMAPY_EXTRA/test_datasets/spectrum/flux_points/flux_points.fits'
+        filename = '$GAMMAPY_DATA/tests/spectrum/flux_points/flux_points.fits'
         flux_points = FluxPoints.read(filename)
         flux_points.plot()
 
     An instance of `FluxPoints` can also be created by passing an instance of
     `astropy.table.Table`, which contains the required columns, such as `'e_ref'`
-    and `'dnde'`:
-
-    .. code:: python
+    and `'dnde'`. The corresponding `sed_type` has to be defined in the meta data
+    of the table::
 
         from astropy import units as u
         from astropy.table import Table
@@ -107,15 +124,14 @@ class FluxPoints(object):
         flux_points.plot()
 
     If you have flux points in a different data format, the format can be changed
-    by renamimg the table columns and adding meta data:
+    by renaming the table columns and adding meta data::
 
-    .. code:: python
 
         from astropy import units as u
         from astropy.table import Table
         from gammapy.spectrum import FluxPoints
 
-        table = Table.read('$GAMMAPY_EXTRA/test_datasets/spectrum/flux_points/flux_points_ctb_37b.txt',
+        table = Table.read('$GAMMAPY_DATA/tests/spectrum/flux_points/flux_points_ctb_37b.txt',
                            format='ascii.csv', delimiter=' ', comment='#')
         table.meta['SED_TYPE'] = 'dnde'
         table.rename_column('Differential_Flux', 'dnde')
@@ -139,12 +155,27 @@ class FluxPoints(object):
         self.table = table_standardise_units_copy(table)
         # validate that the table is a valid representation
         # of the given flux point sed type
-        self._validate_table(self.table)
+        self._validate_table(self.table, table.meta["SED_TYPE"])
 
     def __repr__(self):
         fmt = '{}(sed_type="{}", n_points={})'
         return fmt.format(self.__class__.__name__, self.sed_type, len(self.table))
 
+    @property
+    def table_formatted(self):
+        """Return formatted version of the flux points table. Used for pretty printing"""
+        table = self.table.copy()
+
+        for column in table.colnames:
+            if column.startswith(("dnde", "eflux", "flux", "e2dnde", "ref")):
+                table[column].format = ".3e"
+            elif column.startswith(
+                ("e_min", "e_max", "e_ref", "sqrt_ts", "norm", "ts", "loglike")
+            ):
+                table[column].format = ".3f"
+
+        return table
+
     @classmethod
     def read(cls, filename, **kwargs):
         """Read flux points.
@@ -231,7 +262,7 @@ class FluxPoints(object):
         --------
 
         >>> from gammapy.spectrum import FluxPoints
-        >>> filename = '$GAMMAPY_EXTRA/test_datasets/spectrum/flux_points/flux_points.fits'
+        >>> filename = '$GAMMAPY_DATA/tests/spectrum/flux_points/flux_points.fits'
         >>> flux_points = FluxPoints.read(filename)
         >>> print(flux_points)
         FluxPoints(sed_type="flux", n_points=24)
@@ -241,6 +272,59 @@ class FluxPoints(object):
         table_drop_ul = self.table[~self.is_ul]
         return self.__class__(table_drop_ul)
 
+    def _flux_to_dnde(self, e_ref, table, model, pwl_approx):
+        if model is None:
+            model = PowerLaw()
+
+        e_min, e_max = self.e_min, self.e_max
+
+        flux = table["flux"].quantity
+        dnde = self._dnde_from_flux(flux, model, e_ref, e_min, e_max, pwl_approx)
+
+        # Add to result table
+        table["e_ref"] = e_ref
+        table["dnde"] = dnde
+
+        if "flux_err" in table.colnames:
+            table["dnde_err"] = dnde * table["flux_err"].quantity / flux
+
+        if "flux_errn" in table.colnames:
+            table["dnde_errn"] = dnde * table["flux_errn"].quantity / flux
+            table["dnde_errp"] = dnde * table["flux_errp"].quantity / flux
+
+        if "flux_ul" in table.colnames:
+            flux_ul = table["flux_ul"].quantity
+            dnde_ul = self._dnde_from_flux(
+                flux_ul, model, e_ref, e_min, e_max, pwl_approx
+            )
+            table["dnde_ul"] = dnde_ul
+
+        return table
+
+    @staticmethod
+    def _dnde_to_e2dnde(e_ref, table):
+        for suffix in ["", "_ul", "_err", "_errp", "_errn"]:
+            try:
+                data = table["dnde" + suffix].quantity
+                table["e2dnde" + suffix] = (e_ref ** 2 * data).to(
+                    DEFAULT_UNIT["e2dnde"]
+                )
+            except KeyError:
+                continue
+
+        return table
+
+    @staticmethod
+    def _e2dnde_to_dnde(e_ref, table):
+        for suffix in ["", "_ul", "_err", "_errp", "_errn"]:
+            try:
+                data = table["e2dnde" + suffix].quantity
+                table["dnde" + suffix] = (data / e_ref ** 2).to(DEFAULT_UNIT["dnde"])
+            except KeyError:
+                continue
+
+        return table
+
     def to_sed_type(self, sed_type, method="log_center", model=None, pwl_approx=False):
         """Convert to a different SED type (return new `FluxPoints`).
 
@@ -273,64 +357,47 @@ class FluxPoints(object):
 
         Examples
         --------
-        >>> from astropy import units as u
         >>> from gammapy.spectrum import FluxPoints
         >>> from gammapy.spectrum.models import PowerLaw
-        >>> filename = '$GAMMAPY_EXTRA/test_datasets/spectrum/flux_points/flux_points.fits'
+        >>> filename = '$GAMMAPY_DATA/tests/spectrum/flux_points/flux_points.fits'
         >>> flux_points = FluxPoints.read(filename)
-        >>> model = PowerLaw(2.2 * u.Unit(''), 1e-12 * u.Unit('cm-2 s-1 TeV-1'), 1 * u.TeV)
+        >>> model = PowerLaw(index=2.2)
         >>> flux_points_dnde = flux_points.to_sed_type('dnde', model=model)
         """
-        # TODO: implement other directions. Refactor!
-        if sed_type != "dnde":
+        # TODO: implement other directions.
+        table = self.table.copy()
+
+        if self.sed_type == "flux" and sed_type == "dnde":
+            # Compute e_ref
+            if method == "table":
+                e_ref = table["e_ref"].quantity
+            elif method == "log_center":
+                e_ref = np.sqrt(self.e_min * self.e_max)
+            elif method == "lafferty":
+                # set e_ref that it represents the mean dnde in the given energy bin
+                e_ref = self._e_ref_lafferty(model, self.e_min, self.e_max)
+            else:
+                raise ValueError("Invalid method: {}".format(method))
+            table = self._flux_to_dnde(e_ref, table, model, pwl_approx)
+
+        elif self.sed_type == "dnde" and sed_type == "e2dnde":
+            table = self._dnde_to_e2dnde(self.e_ref, table)
+
+        elif self.sed_type == "e2dnde" and sed_type == "dnde":
+            table = self._e2dnde_to_dnde(self.e_ref, table)
+
+        elif self.sed_type == "likelihood" and sed_type in ["dnde", "flux", "eflux"]:
+            for suffix in ["", "_ul", "_err", "_errp", "_errn"]:
+                try:
+                    table[sed_type + suffix] = (
+                        table["ref_" + sed_type] * table["norm" + suffix]
+                    )
+                except KeyError:
+                    continue
+        else:
             raise NotImplementedError
 
-        if model is None:
-            model = PowerLaw(
-                index=2 * u.Unit(""),
-                amplitude=1 * u.Unit("cm-2 s-1 TeV-1"),
-                reference=1 * u.TeV,
-            )
-
-        input_table = self.table.copy()
-
-        e_min, e_max = self.e_min, self.e_max
-
-        # Compute e_ref
-        if method == "table":
-            e_ref = input_table["e_ref"].quantity
-        elif method == "log_center":
-            e_ref = np.sqrt(e_min * e_max)
-        elif method == "lafferty":
-            # set e_ref that it represents the mean dnde in the given energy bin
-            e_ref = self._e_ref_lafferty(model, e_min, e_max)
-        else:
-            raise ValueError("Invalid method: {}".format(method))
-
-        flux = input_table["flux"].quantity
-        dnde = self._dnde_from_flux(flux, model, e_ref, e_min, e_max, pwl_approx)
-
-        # Add to result table
-        table = input_table.copy()
-        table["e_ref"] = e_ref
-        table["dnde"] = dnde
-
-        if "flux_err" in table.colnames:
-            # TODO: implement better error handling, e.g. MC based method
-            table["dnde_err"] = dnde * table["flux_err"].quantity / flux
-
-        if "flux_errn" in table.colnames:
-            table["dnde_errn"] = dnde * table["flux_errn"].quantity / flux
-            table["dnde_errp"] = dnde * table["flux_errp"].quantity / flux
-
-        if "flux_ul" in table.colnames:
-            flux_ul = table["flux_ul"].quantity
-            dnde_ul = self._dnde_from_flux(
-                flux_ul, model, e_ref, e_min, e_max, pwl_approx
-            )
-            table["dnde_ul"] = dnde_ul
-
-        table.meta["SED_TYPE"] = "dnde"
+        table.meta["SED_TYPE"] = sed_type
         return FluxPoints(table)
 
     @staticmethod
@@ -388,12 +455,8 @@ class FluxPoints(object):
                 return sed_type
 
     @staticmethod
-    def _validate_table(table):
+    def _validate_table(table, sed_type):
         """Validate input table."""
-        # TODO: do we really want to error out on tables that don't have `SED_TYPE` in meta?
-        # If yes, then this needs to be documented in the docstring,
-        # and the workaround pointed out (to add the meta key before creating FluxPoints).
-        sed_type = table.meta["SED_TYPE"]
         required = set(REQUIRED_COLUMNS[sed_type])
 
         if not required.issubset(table.colnames):
@@ -409,11 +472,8 @@ class FluxPoints(object):
         except IndexError:
             return u.Unit("TeV")
 
-    def get_energy_err(self, sed_type=None):
+    def _plot_get_energy_err(self):
         """Compute energy error for given sed type"""
-        # TODO: sed_type is not used
-        if sed_type is None:
-            sed_type = self.sed_type
         try:
             e_min = self.table["e_min"].quantity
             e_max = self.table["e_max"].quantity
@@ -423,10 +483,8 @@ class FluxPoints(object):
             x_err = None
         return x_err
 
-    def get_flux_err(self, sed_type=None):
+    def _plot_get_flux_err(self, sed_type=None):
         """Compute flux error for given sed type"""
-        if sed_type is None:
-            sed_type = self.sed_type
         try:
             # asymmetric error
             y_errn = self.table[sed_type + "_errn"].quantity
@@ -466,6 +524,19 @@ class FluxPoints(object):
         except KeyError:
             return np.sqrt(self.e_min * self.e_max)
 
+    @property
+    def e_edges(self):
+        """Edges of the energy bin.
+
+        Returns
+        -------
+        e_edges : `~astropy.units.Quantity`
+            Energy edges.
+        """
+        e_edges = list(self.e_min)
+        e_edges += [self.e_max[-1]]
+        return u.Quantity(e_edges, self.e_min.unit, copy=False)
+
     @property
     def e_min(self):
         """Lower bound of energy bin.
@@ -493,13 +564,7 @@ class FluxPoints(object):
         return self.table["e_max"].quantity
 
     def plot(
-        self,
-        ax=None,
-        sed_type=None,
-        energy_unit="TeV",
-        flux_unit=None,
-        energy_power=0,
-        **kwargs
+        self, ax=None, energy_unit="TeV", flux_unit=None, energy_power=0, **kwargs
     ):
         """Plot flux points.
 
@@ -507,8 +572,6 @@ class FluxPoints(object):
         ----------
         ax : `~matplotlib.axes.Axes`
             Axis object to plot on.
-        sed_type : ['dnde', 'flux', 'eflux']
-            Which sed type to plot.
         energy_unit : str, `~astropy.units.Unit`, optional
             Unit of the energy axis
         flux_unit : str, `~astropy.units.Unit`, optional
@@ -528,7 +591,7 @@ class FluxPoints(object):
         if ax is None:
             ax = plt.gca()
 
-        sed_type = sed_type or self.sed_type
+        sed_type = self.sed_type
         y_unit = u.Unit(flux_unit or DEFAULT_UNIT[sed_type])
 
         y = self.table[sed_type].quantity.to(y_unit)
@@ -536,8 +599,8 @@ class FluxPoints(object):
 
         # get errors and ul
         is_ul = self.is_ul
-        x_err_all = self.get_energy_err(sed_type)
-        y_err_all = self.get_flux_err(sed_type)
+        x_err_all = self._plot_get_energy_err()
+        y_err_all = self._plot_get_flux_err(sed_type)
 
         # handle energy power
         e_unit = self._get_y_energy_unit(y_unit)
@@ -549,13 +612,13 @@ class FluxPoints(object):
         if y_err_all:
             y_errn = (y_err_all[0] * np.power(x, energy_power)).to(y_unit)
             y_errp = (y_err_all[1] * np.power(x, energy_power)).to(y_unit)
-            y_err = (y_errn[~is_ul].to(y_unit).value, y_errp[~is_ul].to(y_unit).value)
+            y_err = (y_errn[~is_ul].to_value(y_unit), y_errp[~is_ul].to_value(y_unit))
 
         if x_err_all:
             x_errn, x_errp = x_err_all
             x_err = (
-                x_errn[~is_ul].to(energy_unit).value,
-                x_errp[~is_ul].to(energy_unit).value,
+                x_errn[~is_ul].to_value(energy_unit),
+                x_errp[~is_ul].to_value(energy_unit),
             )
 
         # set flux points plotting defaults
@@ -570,8 +633,8 @@ class FluxPoints(object):
             if x_err_all:
                 x_errn, x_errp = x_err_all
                 x_err = (
-                    x_errn[is_ul].to(energy_unit).value,
-                    x_errp[is_ul].to(energy_unit).value,
+                    x_errn[is_ul].to_value(energy_unit),
+                    x_errp[is_ul].to_value(energy_unit),
                 )
 
             y_ul = self.table[sed_type + "_ul"].quantity
@@ -579,7 +642,7 @@ class FluxPoints(object):
 
             y_err = (0.5 * y_ul[is_ul].value, np.zeros_like(y_ul[is_ul].value))
 
-            kwargs.setdefault("c", ebar[0].get_color())
+            kwargs.setdefault("color", ebar[0].get_color())
 
             # pop label keyword to avoid that it appears twice in the legend
             kwargs.pop("label", None)
@@ -598,21 +661,105 @@ class FluxPoints(object):
         ax.set_ylabel("{} ({})".format(self.sed_type, y_unit))
         return ax
 
+    def plot_likelihood(
+        self,
+        ax=None,
+        energy_unit="TeV",
+        add_cbar=True,
+        y_values=None,
+        y_unit=None,
+        **kwargs
+    ):
+        """Plot likelihood SED profiles as a density plot..
+
+        Parameters
+        ----------
+        ax : `~matplotlib.axes.Axes`
+            Axis object to plot on.
+        energy_unit : str, `~astropy.units.Unit`, optional
+            Unit of the energy axis
+        y_values : `astropy.units.Quantity`
+            Array of y-values to use for the likelihood profile evaluation.
+        y_unit : str or `astropy.units.Unit`
+            Unit to use for the y-axis.
+        add_cbar : bool
+            Whether to add a colorbar to the plot.
+        kwargs : dict
+            Keyword arguments passed to :func:`matplotlib.pyplot.pcolormesh`
+
+        Returns
+        -------
+        ax : `~matplotlib.axes.Axes`
+            Axis object
+        """
+        import matplotlib.pyplot as plt
+
+        if ax is None:
+            ax = plt.gca()
+
+        self._validate_table(self.table, "likelihood")
+        y_unit = u.Unit(y_unit or DEFAULT_UNIT[self.sed_type])
+
+        if y_values is None:
+            ref_values = self.table["ref_" + self.sed_type].quantity
+            y_values = np.logspace(
+                np.log10(ref_values.value.min()) - 1,
+                np.log10(ref_values.value.max()) + 1,
+                500,
+            )
+            y_values = u.Quantity(y_values, y_unit, copy=False)
+
+        x = self.e_edges.to(energy_unit)
+
+        # Compute likelihood "image" one energy bin at a time
+        # by interpolating e2dnde at the log bin centers
+        z = np.empty((len(self.table), len(y_values)))
+        for idx in range(len(self.table)):
+            y_ref = self.table["ref_" + self.sed_type].quantity[idx]
+            norm = (y_values / y_ref).to_value("")
+            norm_scan = self.table[idx]["norm_scan"]
+            dloglike_scan = (
+                self.table[idx]["dloglike_scan"] - self.table[idx]["loglike"]
+            )
+            z[idx] = _interp_likelihood_profile(norm_scan, dloglike_scan, norm)
+
+        kwargs.setdefault("vmax", 0)
+        kwargs.setdefault("vmin", -4)
+        kwargs.setdefault("zorder", 0)
+        kwargs.setdefault("cmap", "Blues")
+        kwargs.setdefault("linewidths", 0)
+
+        # clipped values are set to NaN so that they appear white on the plot
+        z[-z < kwargs["vmin"]] = np.nan
+        caxes = ax.pcolormesh(x, y_values, -z.T, **kwargs)
+        ax.set_xscale("log", nonposx="clip")
+        ax.set_yscale("log", nonposy="clip")
+        ax.set_xlabel("Energy ({})".format(energy_unit))
+        ax.set_ylabel("{} ({})".format(self.sed_type, y_values.unit))
+
+        if add_cbar:
+            label = "delta log-likelihood"
+            ax.figure.colorbar(caxes, ax=ax, label=label)
+
+        return ax
+
 
 class FluxPointEstimator(object):
     """Flux point estimator.
 
-    Computes flux points for a given spectrum observation dataset
-    (a 1-dim on/off observation), energy binning and spectral model.
+    Estimates flux points for a given spectrum observation dataset, energy groups
+    and spectral model.
 
-    A spectral model shape is assumed, all parameters except the norm are fixed
-    A 1D amplitude fit is done, to find the amplitude so that npred equals excess.
+    To estimate the flux point the amplitude of the reference spectral model is
+    fitted within the energy range defined by the energy group. This is done for
+    each group independently. The amplitude is re-normalized using the "norm" parameter,
+    which specifies the deviation of the flux from the reference model in this
+    energy group. See https://gamma-astro-data-formats.readthedocs.io/en/latest/spectra/binned_likelihoods/index.html
+    for details.
 
-    This is done for each group independently.
-
-    The method is used for example in this FERMI-LAT catalog paper
+    The method is also described in the FERMI-LAT catalog paper
     https://ui.adsabs.harvard.edu/#abs/2015ApJS..218...23A
-    or the HESS GPS paper
+    or the HESS Galactic Plane Survey paper
     https://ui.adsabs.harvard.edu/#abs/2018A%26A...612A...1H
 
     Parameters
@@ -623,14 +770,50 @@ class FluxPointEstimator(object):
         Energy groups (usually output of `~gammapy.spectrum.SpectrumEnergyGroupMaker`)
     model : `~gammapy.spectrum.models.SpectralModel`
         Global model (usually output of `~gammapy.spectrum.SpectrumFit`)
+    norm_min : float
+        Minimum value for the norm used for the likelihood profile evaluation.
+    norm_max : float
+        Maximum value for the norm used for the likelihood profile evaluation.
+    norm_n_values : int
+        Number of norm values used for the likelihood profile.
+    norm_values : `numpy.ndarray`
+        Array of norm values to be used for the likelihood profile.
+    sigma : int
+        Sigma to use for asymmetric error computation.
+    sigma_ul : int
+        Sigma to use for upper limit computation.
     """
 
-    def __init__(self, obs, groups, model):
-        self.obs = obs
+    def __init__(
+        self,
+        obs,
+        groups,
+        model,
+        norm_min=0.2,
+        norm_max=5,
+        norm_n_values=11,
+        norm_values=None,
+        sigma=1,
+        sigma_ul=2,
+    ):
+        if isinstance(obs, SpectrumObservation):
+            obs = SpectrumObservationList([obs])
+        self.obs = SpectrumObservationList(obs)
+
         self.groups = groups
-        self.model = model
-        self.flux_points = None
-        self._fit = None
+        self.model = ScaleModel(model)
+        self.model.parameters["norm"].min = 0
+        if norm_values is None:
+            norm_values = np.logspace(
+                np.log10(norm_min), np.log10(norm_max), norm_n_values
+            )
+        self.norm_values = norm_values
+        self.sigma = sigma
+        self.sigma_ul = sigma_ul
+
+    @property
+    def ref_model(self):
+        return self.model.model
 
     def __str__(self):
         s = "{}:\n".format(self.__class__.__name__)
@@ -639,161 +822,192 @@ class FluxPointEstimator(object):
         s += str(self.model) + "\n"
         return s
 
-    @property
-    def fit(self):
-        """Instance of `~gammapy.spectrum.SpectrumFit`"""
-        return self._fit
+    def run(self, steps="all"):
+        """Run the flux point estimator for all energy groups.
 
-    @property
-    def obs(self):
-        """Observations participating in the fit"""
-        return self._obs
-
-    @obs.setter
-    def obs(self, obs):
-        if isinstance(obs, SpectrumObservation):
-            obs = SpectrumObservationList([obs])
-
-        self._obs = SpectrumObservationList(obs)
-
-    def compute_points(self):
+        Returns
+        -------
+        flux_points : `FluxPoints`
+            Estimated flux points.
+        steps : list of str
+            Which steps to execute. See `estimate_flux_point` for details
+            and available options.
+        """
         rows = []
         for group in self.groups:
             if group.bin_type != "normal":
                 log.debug("Skipping energy group:\n{}".format(group))
                 continue
 
-            row = self.compute_flux_point(group)
+            row = self.estimate_flux_point(group, steps=steps)
             rows.append(row)
 
-        meta = OrderedDict([("method", "TODO"), ("SED_TYPE", "dnde")])
+        meta = OrderedDict([("SED_TYPE", "likelihood")])
         table = table_from_row_data(rows=rows, meta=meta)
-        self.flux_points = FluxPoints(table)
+        return FluxPoints(table).to_sed_type("dnde")
 
-    def compute_flux_point(self, energy_group):
-        log.debug("Computing flux point for energy group:\n{}".format(energy_group))
+    def estimate_flux_point(self, e_group, steps="all"):
+        """Estimate flux point for a single energy group.
 
-        model = self._get_spectral_model(self.model)
+        Parameters
+        ----------
+        e_group : `SpectrumEnergyGroup`
+            Energy group to compute the flux point for.
+        steps : list of str
+            Which steps to execute. Available options are:
 
+                * "err": estimate symmetric error.
+                * "errn-errp": estimate asymmetric errors.
+                * "ul": estimate upper limits.
+                * "ts": estimate ts and sqrt(ts) values.
+                * "norm-scan": estimate likelihood profiles.
+
+            By default all steps are executed.
+
+        Returns
+        -------
+        result : dict
+            Dict with results for the flux point.
+        """
         # Put at log center of the bin
-        energy_ref = np.sqrt(energy_group.energy_min * energy_group.energy_max)
+        e_min, e_max = e_group.energy_min, e_group.energy_max
+        e_ref = np.sqrt(e_min * e_max)
 
-        return self.fit_point(
-            model=model, energy_group=energy_group, energy_ref=energy_ref
+        result = OrderedDict(
+            [
+                ("e_ref", e_ref),
+                ("e_min", e_min),
+                ("e_max", e_max),
+                ("ref_dnde", self.ref_model(e_ref)),
+                ("ref_flux", self.ref_model.integral(e_min, e_max)),
+                ("ref_eflux", self.ref_model.energy_flux(e_min, e_max)),
+                ("ref_e2dnde", self.ref_model(e_ref) * e_ref ** 2),
+            ]
         )
 
-    @staticmethod
-    def _get_spectral_model(global_model):
-        model = global_model.copy()
-        for par in model.parameters.parameters:
-            if par.name != "amplitude":
-                par.frozen = True
-        return model
+        quality_orig = self._set_quality(e_group)
+        result.update(self.estimate_norm())
 
-    def compute_flux_point_ul(self, fit, stat_best_fit, delta_ts=4, negative=False):
-        """
-        Compute upper limits for flux point values.
+        if steps == "all":
+            steps = ["err", "errp-errn", "ul", "ts", "norm-scan"]
 
+        if "err" in steps:
+            result.update(self.estimate_norm_err())
 
-        Parameters
-        ----------
-        fit : `SpectrumFit`
-            Instance of spectrum fit.
-        stat_best_fit : float
-            TS value for best fit result.
-        delta_ts : float (4)
-            Difference in log-likelihood for given confidence interval.
-            See Example below.
-        negative : bool
-            Compute limit in negative direction.
+        if "errp-errn" in steps:
+            result.update(self.estimate_norm_errn_errp())
 
+        if "ul" in steps:
+            result.update(self.estimate_norm_ul())
 
-        Examples
-        --------
-        To compute ~95% confidence upper limits (or 2 sigma) you can use::
+        if "ts" in steps:
+            result.update(self.estimate_norm_ts())
 
-            from scipy.stats import chi2, norm
+        if "norm-scan" in steps:
+            result.update(self.estimate_norm_scan(result))
 
-            sigma = 2
-            cl = 1 - 2 * norm.sf(sigma) # using two sided p-value
-            delta_ts = chi2.isf(1 - cl, df=1)
+        self._restore_quality(quality_orig)
+        return result
+
+    def estimate_norm_errn_errp(self):
+        """Estimate asymmetric errors for a flux point.
 
         Returns
         -------
-        dnde_ul : `~astropy.units.Quantity`
-            Flux point upper limit.
+        result : dict
+            Dict with asymmetric errors for the flux point norm.
         """
-        from scipy.optimize import brentq
-
-        model = fit.result[0].model.copy()
-        # this is a prototype for fast flux point upper limit
-        # calculation using brentq
-        amplitude = model.parameters["amplitude"].value / 1E-12
-        amplitude_err = model.parameters.error("amplitude") / 1E-12
-
-        if negative:
-            amplitude_max = amplitude
-            amplitude_min = amplitude_max - 1E3 * amplitude_err
-        else:
-            amplitude_max = amplitude + 1E3 * amplitude_err
-            amplitude_min = amplitude
-
-        def ts_diff(x):
-            model.parameters["amplitude"].value = x * 1E-12
-            stat = fit.total_stat(model.parameters)
-            return (stat_best_fit + delta_ts) - stat
-
-        try:
-            result = brentq(
-                ts_diff, amplitude_min, amplitude_max, maxiter=100, rtol=1e-2
-            )
-            model.parameters["amplitude"].value = result * 1E-12
-            return model(model.parameters["reference"].quantity)
-        except (RuntimeError, ValueError):
-            # Where the root finding fails NaN is set as amplitude
-            log.debug("Flux point upper limit computation failed.")
-            return np.nan * u.Unit(model.parameters["amplitude"].unit)
-
-    def compute_flux_point_sqrt_ts(self, fit, stat_best_fit):
-        """
-        Compute sqrt(TS) for flux point.
-
-
-        Parameters
-        ----------
-        fit : `SpectrumFit`
-            Instance of spectrum fit.
-        stat_best_fit : float
-            TS value for best fit result.
+        result = self.fit.confidence(parameter="norm", sigma=self.sigma)
+        return {"norm_errp": result["errp"], "norm_errn": result["errn"]}
 
+    def estimate_norm_err(self):
+        """Estimate covariance errors for a flux point.
 
         Returns
         -------
-        sqrt_ts : float
-            Sqrt(TS) for flux point.
-
+        result : dict
+            Dict with symmetric error for the flux point norm.
         """
-        model = fit.result[0].model.copy()
+        result = self.fit.covariance()
+        norm_err = result.model.parameters.error("norm")
+        return {"norm_err": norm_err}
+
+    def estimate_norm_ul(self):
+        """Estimate upper limit for a flux point.
+
+        Returns
+        -------
+        result : dict
+            Dict with upper limit for the flux point norm.
+        """
+        norm = self.model.parameters["norm"].value
+        result = self.fit.confidence(parameter="norm", sigma=self.sigma_ul)
+        return {"norm_ul": result["errp"] + norm}
+
+    def estimate_norm_ts(self):
+        """Estimate ts and sqrt(ts) for the flux point.
+
+        Returns
+        -------
+        result : dict
+            Dict with ts and srtq_ts for the flux point.
+        """
+        parameters = self.model.parameters
+
+        loglike = self.fit.total_stat(parameters)
+        norm_best_fit = parameters["norm"].value
+
         # store best fit amplitude, set amplitude of fit model to zero
-        amplitude = model.parameters["amplitude"].value
-
-        # determine TS value for amplitude zero
-        model.parameters["amplitude"].value = 0
-        stat_null = fit.total_stat(model.parameters)
-
-        # set amplitude of fit model to best fit amplitude
-        model.parameters["amplitude"].value = amplitude
+        parameters["norm"].value = 0
+        loglike_null = self.fit.total_stat(parameters)
+        parameters["norm"].value = 1.0
 
         # compute sqrt TS
-        ts = np.abs(stat_null - stat_best_fit)
-        return np.sign(amplitude) * np.sqrt(ts)
+        ts = np.abs(loglike_null - loglike)
+        sqrt_ts = np.sign(norm_best_fit) * np.sqrt(ts)
+        return {"sqrt_ts": sqrt_ts, "ts": ts}
 
-    def fit_point(self, model, energy_group, energy_ref, sqrt_ts_threshold=1):
+    def estimate_norm_scan(self, flux_point):
+        """Estimate likelihood profile for the norm parameter
+
+        Returns
+        -------
+        result : dict
+            Dict with norm_scan and dloglike_scan for the flux point.
+        """
+        # norm = self.model.parameters["norm"]
+        result = self.fit.likelihood_profile("norm", values=self.norm_values)
+        dloglike_scan = result["likelihood"]
+        return {"norm_scan": result["values"], "dloglike_scan": dloglike_scan}
+
+    def estimate_norm(self):
+        """Fit norm of the flux point.
+
+        Returns
+        -------
+        result : dict
+            Dict with "norm" and "loglike" for the flux point.
+        """
         from .fit import SpectrumFit
 
-        energy_min = energy_group.energy_min
-        energy_max = energy_group.energy_max
+        self.fit = SpectrumFit(self.obs, self.model)
+        result = self.fit.optimize()
 
+        if result.success:
+            norm = result.model.parameters["norm"].value
+            self.model.parameters["norm"].value = norm
+        else:
+            emin, emax = self.fit.true_fit_range[0]
+            log.warning(
+                "Fit failed for flux point between {emin:.3f} and {emax:.3f},"
+                " setting NaN.".format(emin=emin, emax=emax)
+            )
+            norm = np.nan
+
+        return {"norm": norm, "loglike": result.total_stat}
+
+    # TODO: clean up this helper function and maybe move it to SpectrumObservations
+    def _set_quality(self, energy_group):
         quality_orig = []
 
         for index in range(len(self.obs)):
@@ -811,79 +1025,12 @@ class FluxPointEstimator(object):
                     quality[bin] = 1
             self.obs[index].on_vector.quality = quality
 
-        # Set reference and remove min amplitude
-        model.parameters["reference"].value = energy_ref.to("TeV").value
-
-        self._fit = SpectrumFit(self.obs, model)
+        return quality_orig
 
+    def _restore_quality(self, quality_orig):
         for index in range(len(quality_orig)):
             self.obs[index].on_vector.quality = quality_orig[index]
 
-        log.debug(
-            "Calling Sherpa fit for flux point "
-            " in energy range:\n{}".format(self.fit)
-        )
-
-        result = self.fit.run()
-
-        # compute TS value for all observations
-        stat_best_fit = result.total_stat
-
-        dnde, dnde_err = self.fit.result[0].model.evaluate_error(energy_ref)
-        sqrt_ts = self.compute_flux_point_sqrt_ts(self.fit, stat_best_fit=stat_best_fit)
-
-        dnde_ul = self.compute_flux_point_ul(self.fit, stat_best_fit=stat_best_fit)
-        dnde_errp = (
-            self.compute_flux_point_ul(
-                self.fit, stat_best_fit=stat_best_fit, delta_ts=1.
-            )
-            - dnde
-        )
-        dnde_errn = dnde - self.compute_flux_point_ul(
-            self.fit, stat_best_fit=stat_best_fit, delta_ts=1., negative=True
-        )
-
-        return OrderedDict(
-            [
-                ("e_ref", energy_ref),
-                ("e_min", energy_min),
-                ("e_max", energy_max),
-                ("dnde", dnde.to(DEFAULT_UNIT["dnde"])),
-                ("dnde_err", dnde_err.to(DEFAULT_UNIT["dnde"])),
-                ("dnde_ul", dnde_ul.to(DEFAULT_UNIT["dnde"])),
-                ("is_ul", sqrt_ts < sqrt_ts_threshold),
-                ("sqrt_ts", sqrt_ts),
-                ("dnde_errp", dnde_errp),
-                ("dnde_errn", dnde_errn),
-            ]
-        )
-
-
-class FluxPointProfiles(object):
-    """Flux point likelihood profiles.
-
-    See :ref:`gadf:likelihood_sed`.
-
-    TODO: merge this class with the classes in ``fermipy/castro.py``,
-    which are much more advanced / feature complete.
-    This is just a temp solution because we don't have time for that.
-
-    Parameters
-    ----------
-    table : `~astropy.table.Table`
-        Table holding the data
-    """
-
-    def __init__(self, table):
-        self.table = table
-
-    @classmethod
-    def read(cls, filename, **kwargs):
-        """Read from file."""
-        filename = make_path(filename)
-        table = Table.read(str(filename), **kwargs)
-        return cls(table=table)
-
 
 class FluxPointFit(Fit):
     """
@@ -892,7 +1039,7 @@ class FluxPointFit(Fit):
     Parameters
     ----------
     model : `~gammapy.spectrum.models.SpectralModel`
-        Spectral model (with fit start parameters)
+        Spectral model
     data : `~gammapy.spectrum.FluxPoints`
         Flux points.
 
@@ -905,22 +1052,19 @@ class FluxPointFit(Fit):
         from gammapy.spectrum import FluxPoints, FluxPointFit
         from gammapy.spectrum.models import PowerLaw
 
-        filename = '$GAMMAPY_EXTRA/test_datasets/spectrum/flux_points/diff_flux_points.fits'
+        filename = '$GAMMAPY_DATA/tests/spectrum/flux_points/diff_flux_points.fits'
         flux_points = FluxPoints.read(filename)
 
-        model = PowerLaw(
-            index=2. * u.Unit(''),
-            amplitude=1e-12 * u.Unit('cm-2 s-1 TeV-1'),
-            reference=1. * u.TeV,
-        )
+        model = PowerLaw()
 
-        fitter = FluxPointFit(model, flux_points)
-        result = fitter.run()
-        print(result['best_fit_model'])
+        fit = FluxPointFit(model, flux_points)
+        result = fit.run()
+        print(result)
+        print(result.model)
     """
 
     def __init__(self, model, data, stat="chi2"):
-        self._model = model.copy()
+        self._model = model
         self.data = data
 
         if stat in ["chi2", "chi2assym"]:
@@ -937,7 +1081,7 @@ class FluxPointFit(Fit):
         model = self._model(self.data.e_ref)
         data = self.data.table["dnde"].quantity
         sigma = self.data.table["dnde_err"].quantity
-        return ((data - model) / sigma).to("").value ** 2
+        return ((data - model) / sigma).to_value("") ** 2
 
     @property
     def _stat_chi2_assym(self):
@@ -949,8 +1093,8 @@ class FluxPointFit(Fit):
         data_errp = self.data.table["dnde_errp"].quantity
         data_errn = self.data.table["dnde_errn"].quantity
 
-        val_n = ((data - model) / data_errn).to("").value ** 2
-        val_p = ((data - model) / data_errp).to("").value ** 2
+        val_n = ((data - model) / data_errn).to_value("") ** 2
+        val_p = ((data - model) / data_errp).to_value("") ** 2
         return np.where(model > data, val_p, val_n)
 
     @property
@@ -962,5 +1106,4 @@ class FluxPointFit(Fit):
 
     def total_stat(self, parameters):
         """Total likelihood given the current model parameters"""
-        self._model.parameters = parameters
         return np.nansum(self.stat, dtype=np.float64)
