@@ -13,12 +13,9 @@ from ...utils.testing import (
     mpl_plot_check,
 )
 from ...utils.fitting import Parameters
-from ..results import SpectrumResult
-from ..fit import SpectrumFit
-from ..observation import SpectrumObservation
-from ..energy_group import SpectrumEnergyGroupMaker
 from ..models import PowerLaw, SpectralModel
-from ..flux_point import FluxPoints, FluxPointProfiles, FluxPointFit, FluxPointEstimator
+from ..flux_point import FluxPoints, FluxPointFit
+
 
 FLUX_POINTS_FILES = [
     "diff_flux_points.ecsv",
@@ -36,10 +33,10 @@ class LWTestModel(SpectralModel):
         return 1e4 * np.exp(-6 * x)
 
     def integral(self, xmin, xmax, **kwargs):
-        return -1. / 6 * 1e4 * (np.exp(-6 * xmax) - np.exp(-6 * xmin))
+        return -1.0 / 6 * 1e4 * (np.exp(-6 * xmax) - np.exp(-6 * xmin))
 
     def inverse(self, y):
-        return -1. / 6 * np.log(y * 1e-4)
+        return -1.0 / 6 * np.log(y * 1e-4)
 
 
 class XSqrTestModel(SpectralModel):
@@ -50,7 +47,7 @@ class XSqrTestModel(SpectralModel):
         return x ** 2
 
     def integral(self, xmin, xmax, **kwargs):
-        return 1. / 3 * (xmax ** 3 - xmin ** 2)
+        return 1.0 / 3 * (xmax ** 3 - xmin ** 2)
 
     def inverse(self, y):
         return np.sqrt(y)
@@ -88,7 +85,6 @@ def test_e_ref_lafferty():
     assert_allclose(actual, desired, atol=1e-3)
 
 
-@requires_dependency("scipy")
 def test_dnde_from_flux():
     """Tests y-value normalization adjustment method.
     """
@@ -114,7 +110,6 @@ def test_dnde_from_flux():
     assert_allclose(actual, desired, rtol=1e-6)
 
 
-@requires_dependency("scipy")
 @pytest.mark.parametrize("method", ["table", "lafferty", "log_center"])
 def test_compute_flux_points_dnde_exp(method):
     """
@@ -153,99 +148,19 @@ def test_compute_flux_points_dnde_exp(method):
     assert_quantity_allclose(actual, desired, rtol=1e-8)
 
 
-@pytest.fixture(scope="session")
-def obs():
-    filename = "$GAMMAPY_EXTRA/datasets/joint-crab/spectra/hess/pha_obs23523.fits"
-    obs = SpectrumObservation.read(filename)
-    return obs
-
-
-@pytest.fixture(scope="session")
-def model():
-    model = PowerLaw()
-    fit = SpectrumFit(obs(), model)
-    result = fit.run()
-    return result.model
-
-
-@pytest.fixture(scope="session")
-def seg():
-    ebounds = [0.3, 1, 30] * u.TeV
-    segm = SpectrumEnergyGroupMaker(obs=obs())
-    segm.compute_groups_fixed(ebounds=ebounds)
-    return segm.groups
-
-
-@requires_data("gammapy-extra")
-@requires_dependency("sherpa")
-@requires_dependency("matplotlib")
-@requires_dependency("scipy")
-class TestFluxPointEstimator:
-    def setup(self):
-        self.fpe = FluxPointEstimator(obs=obs(), model=model(), groups=seg())
-
-    def test_basic(self):
-        assert "FluxPointEstimator" in str(self.fpe)
-
-    def test_energy_range(self):
-        group = self.fpe.groups[1]
-        point = self.fpe.compute_flux_point(group)
-        fit_range = self.fpe.fit.true_fit_range[0]
-        assert_quantity_allclose(fit_range[0], group.energy_min)
-        assert_quantity_allclose(fit_range[1], group.energy_max)
-
-    def test_values(self):
-        self.fpe.compute_points()
-        flux_points = self.fpe.flux_points
-
-        actual = flux_points.table["dnde"][0]
-        assert_allclose(actual, 2.361e-10, rtol=1e-2)
-
-        actual = flux_points.table["dnde_err"][0]
-        assert_allclose(actual, 2.9128e-11, rtol=1e-2)
-
-        actual = flux_points.table["dnde_ul"][0]
-        assert_allclose(actual, 2.994e-10, rtol=1e-2)
-
-        actual = flux_points.table["dnde_errn"][0]
-        assert_allclose(actual, np.nan, rtol=1e-2)
-
-        actual = flux_points.table["dnde_errp"][0]
-        assert_allclose(actual, np.nan, rtol=1e-2)
-
-    def test_spectrum_result(self):
-        # TODO: Don't run this again
-        self.fpe.compute_points()
-        result = SpectrumResult(model=self.fpe.model, points=self.fpe.flux_points)
-
-        actual = result.flux_point_residuals[0][0]
-        assert_allclose(actual, -0.058407, rtol=1e-2)
-
-        actual = result.flux_point_residuals[1][0]
-        assert_allclose(actual, np.nan, rtol=1e-2)
-
-        with mpl_plot_check():
-            result.plot(energy_range=[1, 10] * u.TeV)
-
-
-@requires_data("gammapy-extra")
-class TestFluxPointProfiles:
-    def setup(self):
-        filename = "$GAMMAPY_EXTRA/datasets/spectrum/llsed_hights.fits"
-        self.sed = FluxPointProfiles.read(filename)
-
-    def test_basics(self):
-        assert isinstance(self.sed.table, Table)
-
-
 @pytest.fixture(params=FLUX_POINTS_FILES, scope="session")
 def flux_points(request):
-    path = "$GAMMAPY_EXTRA/test_datasets/spectrum/flux_points/" + request.param
+    path = "$GAMMAPY_DATA/tests/spectrum/flux_points/" + request.param
     return FluxPoints.read(path)
 
 
-@requires_dependency("yaml")
-@requires_data("gammapy-extra")
+@pytest.fixture(scope="session")
+def flux_points_likelihood():
+    path = "$GAMMAPY_DATA/tests/spectrum/flux_points/binlike.fits"
+    return FluxPoints.read(path).to_sed_type("dnde")
+
+
+@requires_data("gammapy-data")
 class TestFluxPoints:
     def test_info(self, flux_points):
         info = str(flux_points)
@@ -301,38 +216,22 @@ class TestFluxPoints:
         with mpl_plot_check():
             flux_points.plot()
 
-
-@requires_data("gammapy-extra")
-def test_compute_flux_points_dnde():
-    """
-    Test compute_flux_points_dnde on reference spectra.
-    """
-    path = "$GAMMAPY_EXTRA/test_datasets/spectrum/flux_points/"
-    flux_points = FluxPoints.read(path + "flux_points.fits")
-    desired_fp = FluxPoints.read(path + "diff_flux_points.fits")
-
-    # TODO: verify index=2.2, but it seems to give reasonable values
-    model = PowerLaw(2.2 * u.Unit(""), 1e-12 * u.Unit("cm-2 s-1 TeV-1"), 1 * u.TeV)
-    actual_fp = flux_points.to_sed_type("dnde", model=model, method="log_center")
-
-    for column in ["dnde", "dnde_err", "dnde_ul"]:
-        actual = actual_fp.table[column].quantity
-        desired = desired_fp.table[column].quantity
-        assert_quantity_allclose(actual, desired, rtol=1e-12)
+    @requires_dependency("matplotlib")
+    def test_plot_likelihood(self, flux_points_likelihood):
+        with mpl_plot_check():
+            flux_points_likelihood.plot_likelihood()
 
 
-@requires_data("gammapy-extra")
+@requires_data("gammapy-data")
 def test_compute_flux_points_dnde_fermi():
     """
     Test compute_flux_points_dnde on fermi source.
     """
     fermi_3fgl = SourceCatalog3FGL()
     source = fermi_3fgl["3FGL J0835.3-4510"]
-
     flux_points = source.flux_points.to_sed_type(
         "dnde", model=source.spectral_model, method="log_center", pwl_approx=True
     )
-
     for column in ["dnde", "dnde_errn", "dnde_errp", "dnde_ul"]:
         actual = flux_points.table["e2" + column].quantity
         desired = flux_points.table[column].quantity * flux_points.e_ref ** 2
@@ -341,8 +240,10 @@ def test_compute_flux_points_dnde_fermi():
 
 @pytest.fixture(scope="session")
 def sed_flux_points():
-    path = "$GAMMAPY_EXTRA/test_datasets/spectrum/flux_points/diff_flux_points.fits"
-    return FluxPoints.read(path)
+    path = "$GAMMAPY_DATA/tests/spectrum/flux_points/diff_flux_points.fits"
+    fp = FluxPoints.read(path)
+    fp.table["e_ref"] = fp.e_ref.to("TeV")
+    return fp
 
 
 @pytest.fixture(scope="session")
@@ -350,20 +251,25 @@ def sed_model():
     return PowerLaw(index=2.3, amplitude="1e-12 cm-2 s-1 TeV-1", reference="1 TeV")
 
 
-@requires_data("gammapy-extra")
+@requires_data("gammapy-data")
 class TestFluxPointFit:
     @requires_dependency("iminuit")
     def test_fit_pwl_minuit(self, sed_model, sed_flux_points):
         optimize_opts = {"backend": "minuit"}
-        fitter = FluxPointFit(sed_model, sed_flux_points)
-        result = fitter.run(optimize_opts=optimize_opts)
+        fit = FluxPointFit(sed_model, sed_flux_points)
+        result = fit.run(optimize_opts=optimize_opts)
         self.assert_result(result)
 
+        assert sed_model is fit._model
+        assert fit._model is result.model
+        assert sed_model is result.model
+
     @requires_dependency("sherpa")
+    @pytest.mark.skip(reason="Sherpa backend does not support fixing parameters yet.")
     def test_fit_pwl_sherpa(self, sed_model, sed_flux_points):
-        optimize_opts = {"backend": "sherpa", "method": "simplex"}
-        fitter = FluxPointFit(sed_model, sed_flux_points)
-        result = fitter.run(optimize_opts=optimize_opts, steps=["optimize"])
+        # TODO: add test for covariance or error estimation here
+        fit = FluxPointFit(sed_model, sed_flux_points)
+        result = fit.optimize(backend="sherpa", method="simplex")
         self.assert_result(result)
 
     @staticmethod
@@ -376,17 +282,15 @@ class TestFluxPointFit:
 
         # Right now sherpa also fits the reference energy
         amplitude = result.model(1 * u.TeV).to("cm-2 s-1 TeV-1")
-        assert_allclose(amplitude.value, 2.1616E-13, rtol=1e-3)
+        assert_allclose(amplitude.value, 2.1616e-13, rtol=1e-3)
 
     @requires_dependency("iminuit")
     def test_likelihood_profile(self, sed_model, sed_flux_points):
         optimize_opts = {"backend": "minuit"}
-        fitter = FluxPointFit(sed_model, sed_flux_points)
-        result = fitter.run(optimize_opts=optimize_opts)
+        fit = FluxPointFit(sed_model, sed_flux_points)
+        result = fit.run(optimize_opts=optimize_opts)
 
-        profile = fitter.likelihood_profile(
-            model=result.model, parameter="amplitude", nvalues=3, bounds=1
-        )
+        profile = fit.likelihood_profile("amplitude", nvalues=3, bounds=1)
 
         ts_diff = profile["likelihood"] - result.total_stat
         assert_allclose(ts_diff, [110.1, 0, 110.1], rtol=1e-2, atol=1e-7)
@@ -395,9 +299,7 @@ class TestFluxPointFit:
         err = result.model.parameters.error("amplitude")
         values = np.array([value - err, value, value + err])
 
-        profile = fitter.likelihood_profile(
-            model=result.model, parameter="amplitude", values=values
-        )
+        profile = fit.likelihood_profile("amplitude", values=values)
 
         ts_diff = profile["likelihood"] - result.total_stat
         assert_allclose(ts_diff, [110.1, 0, 110.1], rtol=1e-2, atol=1e-7)
