@@ -1,32 +1,35 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-"""
-Poisson significance computations for these two cases.
+"""Poisson significance computations for these two cases.
 
 * known background level ``mu_bkg``
 * background estimated from ``n_off`
 """
 from __future__ import absolute_import, division, print_function, unicode_literals
 import numpy as np
+from scipy.stats import norm, poisson
+from scipy.special import erf
+from scipy.optimize import fsolve
+from .significance import significance_to_probability_normal
 
 __all__ = [
-    'background',
-    'background_error',
-    'excess',
-    'excess_error',
-    'significance',
-    'significance_on_off',
-    'excess_matching_significance',
-    'excess_matching_significance_on_off',
+    "background",
+    "background_error",
+    "excess",
+    "excess_error",
+    "significance",
+    "significance_on_off",
+    "excess_matching_significance",
+    "excess_matching_significance_on_off",
+    "excess_ul_helene",
 ]
 
-__doctest_skip__ = ['*']
+__doctest_skip__ = ["*"]
 
 
 def background(n_off, alpha):
     r"""Estimate background in the on-region from an off-region observation.
 
     .. math::
-
         \mu_{background} = \alpha \times n_{off}
 
     Parameters
@@ -38,7 +41,7 @@ def background(n_off, alpha):
 
     Returns
     -------
-    background : ndarray
+    background : `numpy.ndarray`
         Background estimate for the on region
 
     Examples
@@ -59,7 +62,6 @@ def background_error(n_off, alpha):
     in the on region from an off-region observation.
 
     .. math::
-
           \Delta\mu_{bkg} = \alpha \times \sqrt{n_{off}}
 
     Parameters
@@ -71,7 +73,7 @@ def background_error(n_off, alpha):
 
     Returns
     -------
-    background : ndarray
+    background : `numpy.ndarray`
         Background estimate for the on region
 
     Examples
@@ -91,7 +93,6 @@ def excess(n_on, n_off, alpha):
     r"""Estimate excess in the on region for an on-off observation.
 
     .. math::
-
           \mu_{excess} = n_{on} - \alpha \times n_{off}
 
     Parameters
@@ -105,7 +106,7 @@ def excess(n_on, n_off, alpha):
 
     Returns
     -------
-    excess : ndarray
+    excess : `numpy.ndarray`
         Excess estimate for the on region
 
     Examples
@@ -126,7 +127,6 @@ def excess_error(n_on, n_off, alpha):
     r"""Estimate error on excess for an on-off measurement.
 
     .. math::
-
         \Delta\mu_{excess} = \sqrt{n_{on} + \alpha ^ 2 \times n_{off}}
 
     TODO: Implement better error and limit estimates (Li & Ma, Rolke)!
@@ -142,7 +142,7 @@ def excess_error(n_on, n_off, alpha):
 
     Returns
     -------
-    excess_error : ndarray
+    excess_error : `numpy.ndarray`
         Excess error estimate
 
     Examples
@@ -160,28 +160,25 @@ def excess_error(n_on, n_off, alpha):
     return np.sqrt(variance)
 
 
-# TODO: rename this function to something more explicit.
-# It currently has the same name as the `gammapy/stats/significance.py`
-# and shadows in in `gammapy/stats/__init.py`
-# Maybe `significance_poisson`?
-def significance(n_on, mu_bkg, method='lima', n_on_min=1):
+def significance(n_on, mu_bkg, method="lima", n_on_min=1):
     r"""Compute significance for an observed number of counts and known background.
 
-    The simple significance estimate :math:`S_{simple}` is given by
+    The default ``method="lima"`` gives the significance estimate corresponding
+    to equation (17) from the Li & Ma paper [1]_ in the limiting of known background
+    :math:`\mu_{bkg} = \alpha \times n_{off}` with :math:`\alpha \to 0`.
 
-    .. math ::
+    It is given by the following formula:
 
+    .. math::
+        S_{lima} = \left[
+          2 n_{on} \log \left( \frac{n_{on}}{\mu_{bkg}} \right) - n_{on} + \mu_{bkg}
+        \right] ^ {1/2}
+
+    For ``method="simple"``, the significance estimate is given by:
+
+    .. math::
         S_{simple} = (n_{on} - \mu_{bkg}) / \sqrt{\mu_{bkg}}
 
-    The Li & Ma significance estimate corresponds to the Li & Ma formula (17)
-    in the limiting case of known background :math:`\mu_{bkg} = \alpha \times n_{off}`
-    with :math:`\alpha \to 0`.
-    The following formula for :math:`S_{lima}` was obtained with Mathematica:
-
-    .. math ::
-
-        S_{lima} = \left[ 2 n_{on} \log \left( \frac{n_{on}}{\mu_{bkg}} \right) - n_{on} + \mu_{bkg} \right] ^ {1/2}
-
 
     Parameters
     ----------
@@ -189,15 +186,15 @@ def significance(n_on, mu_bkg, method='lima', n_on_min=1):
         Observed number of counts
     mu_bkg : array_like
         Known background level
-    method : str
-        Select method: 'lima' or 'simple'
+    method : {"lima", "simple"}
+        Method for significance estimation
     n_on_min : float
         Minimum ``n_on`` (return ``NaN`` for smaller values)
 
     Returns
     -------
-    significance : ndarray
-        Significance according to the method chosen.
+    significance : `~numpy.ndarray`
+        Significance estimate
 
     References
     ----------
@@ -210,31 +207,27 @@ def significance(n_on, mu_bkg, method='lima', n_on_min=1):
 
     Examples
     --------
-    >>> significance(n_on=11, mu_bkg=9, method='lima')
-    0.64401498442763649
-    >>> significance(n_on=11, mu_bkg=9, method='simple')
-    0.66666666666666663
-    >>> significance(n_on=7, mu_bkg=9, method='lima')
-    -0.69397262486881672
-    >>> significance(n_on=7, mu_bkg=9, method='simple')
-    -0.66666666666666663
+    >>> significance(n_on=10, mu_bkg=2, method='lima')
+    4.0235256
+    >>> significance(n_on=10, mu_bkg=2, method='simple')
+    5.65685425
     """
     n_on = np.asanyarray(n_on, dtype=np.float64)
     mu_bkg = np.asanyarray(mu_bkg, dtype=np.float64)
 
-    if method == 'simple':
+    if method == "simple":
         func = _significance_simple
-    elif method == 'lima':
+    elif method == "lima":
         func = _significance_lima
-    elif method == 'direct':
+    elif method == "direct":
         func = _significance_direct
     else:
-        raise ValueError('Invalid method: {}'.format(method))
+        raise ValueError("Invalid method: {}".format(method))
 
     # For low `n_on` values, don't try to compute a significance and return `NaN`.
     n_on = np.atleast_1d(n_on)
     mu_bkg = np.atleast_1d(mu_bkg)
-    mask = (n_on >= n_on_min)
+    mask = n_on >= n_on_min
     s = np.ones_like(n_on) * np.nan
     s[mask] = func(n_on[mask], mu_bkg[mask])
 
@@ -243,6 +236,7 @@ def significance(n_on, mu_bkg, method='lima', n_on_min=1):
 
 def _significance_simple(n_on, mu_bkg):
     # TODO: check this formula against ???
+    # Is this the limit from the on/off case for alpha -> 0?
     excess = n_on - mu_bkg
     bkg_err = np.sqrt(mu_bkg)
     return excess / bkg_err
@@ -254,39 +248,22 @@ def _significance_lima(n_on, mu_bkg):
     return sign * val
 
 
-def _significance_direct(n_on, mu_bkg):
-    """Compute significance directly via Poisson probability.
-
-    Use this method for small ``n_on < 10``.
-    In this case the Li & Ma formula isn't correct any more.
-
-    TODO: add large unit test coverage (where is it numerically precise enough)?
-    TODO: check coverage with MC simulation
-
-    I'm getting a positive significance for zero observed counts and small mu_bkg.
-    That doesn't make too much sense ...
-
-    >>> stats.poisson._significance_direct(0, 2)
-    -1.1015196284987503
-    >>> stats.poisson._significance_direct(0, 0.1)
-    1.309617799458493
-    """
-    from scipy.stats import norm, poisson
-
-    # Compute tail probability to see n_on or more counts
-    probability = poisson.sf(n_on, mu_bkg)
-
-    # Convert probability to a significance
-    significance = norm.isf(probability)
-
-    return significance
-
-
-def significance_on_off(n_on, n_off, alpha, method='lima',
-                        neglect_background_uncertainty=False):
+def significance_on_off(n_on, n_off, alpha, method="lima"):
     r"""Compute significance of an on-off observation.
 
-    TODO: describe available methods.
+    The default ``method="lima"`` gives the significance estimate corresponding
+    to equation (17) from the Li & Ma paper [1]_.
+
+    For ``method="simple"``, the significance estimate is given by Equation (5)
+    from the Li & Ma paper [1]_. It is somewhat biased, but has the advantage
+    of being analytically invertible, which is useful for sensitivity computations.
+
+    .. math::
+        S_{simple} = \mu_{excess} / \Delta\mu_{excess}
+
+        \mu_{excess} = n_{on} - \alpha n_{off}
+
+        \Delta\mu_{excess} = \sqrt{n_{on} + \alpha ^ 2 n_{off}}
 
     Parameters
     ----------
@@ -296,13 +273,13 @@ def significance_on_off(n_on, n_off, alpha, method='lima',
         Observed number of counts in the off region
     alpha : array_like
         On / off region exposure ratio for background events
-    method : {'lima', 'simple', 'direct'}
-        Select method
+    method : {"lima", "simple"}
+        Method for significance estimation
 
     Returns
     -------
-    significance : array
-        Significance according to the method chosen.
+    significance : `~numpy.ndarray`
+        Significance estimate
 
     References
     ----------
@@ -319,56 +296,24 @@ def significance_on_off(n_on, n_off, alpha, method='lima',
     3.6850322319420274
     >>> significance_on_off(n_on=10, n_off=20, alpha=0.1, method='simple')
     2.5048971643405982
-    >>> significance_on_off(n_on=10, n_off=20, alpha=0.1, method='direct')
-    3.5281644971409953
     """
     n_on = np.asanyarray(n_on, dtype=np.float64)
     n_off = np.asanyarray(n_off, dtype=np.float64)
     alpha = np.asanyarray(alpha, dtype=np.float64)
 
-    if method == 'simple':
-        if neglect_background_uncertainty:
-            mu_bkg = background(n_off, alpha)
-            return _significance_simple(n_on, mu_bkg)
-        else:
+    with np.errstate(invalid="ignore", divide="ignore"):
+        if method == "simple":
             return _significance_simple_on_off(n_on, n_off, alpha)
-    elif method == 'lima':
-        if neglect_background_uncertainty:
-            mu_bkg = background(n_off, alpha)
-            return _significance_lima(n_on, mu_bkg)
-        else:
+        elif method == "lima":
             return _significance_lima_on_off(n_on, n_off, alpha)
-    elif method == 'direct':
-        if neglect_background_uncertainty:
-            mu_bkg = background(n_off, alpha)
-            return _significance_direct(n_on, mu_bkg)
-        else:
+        elif method == "direct":
             return _significance_direct_on_off(n_on, n_off, alpha)
-    else:
-        raise ValueError('Invalid method: {}'.format(method))
+        else:
+            raise ValueError("Invalid method: {}".format(method))
 
 
 def _significance_simple_on_off(n_on, n_off, alpha):
-    r"""Compute significance with a simple, somewhat biased formula.
-
-    .. math::
-
-        S = \mu_{excess} / \Delta\mu_{excess}
-
-        where
-
-        \mu_{excess} = n_{on} - \alpha \times n_{off}
-
-        \Delta\mu_{excess} = \sqrt{n_{on} + \alpha ^ 2 \times n_{off}}
-
-    Notes
-    -----
-    This function implements formula (5) of Li & Ma.
-    Li & Ma show that it is somewhat biased,
-    but it does have the advantage of being analytically invertible,
-    i.e. there is an analytical formula for the inverse,
-    which is often used in practice as part of sensitivity computation.
-    """
+    """Compute significance with the simple Equation (5) from Li & Ma."""
     excess_ = excess(n_on, n_off, alpha)
     excess_error_ = excess_error(n_on, n_off, alpha)
 
@@ -387,34 +332,114 @@ def _significance_lima_on_off(n_on, n_off, alpha):
     return sign * val
 
 
+def _significance_direct(n_on, mu_bkg):
+    """Compute significance directly via Poisson probability.
+
+    Reference: TODO (is this ever used?)
+    """
+    # Compute tail probability to see n_on or more counts
+    # Note that we're using ``k = n_on - 1`` to get the probability
+    # for n_on included or more, because `poisson.sf(k)` returns the
+    # probability for more than k, with k excluded
+    # For `n_on = 0` this returns `
+    probability = poisson.sf(n_on - 1, mu_bkg)
+
+    # Convert probability to a significance
+    return norm.isf(probability)
+
+
 def _significance_direct_on_off(n_on, n_off, alpha):
     """Compute significance directly via Poisson probability.
 
-    Use this method for small n_on < 10.
-    In this case the Li & Ma formula isn't correct any more.
+    Reference: http://adsabs.harvard.edu/abs/1993NIMPA.328..570A
 
-    * TODO: add reference
-    * TODO: add large unit test coverage (where is it numerically precise enough)?
-    * TODO: check coverage with MC simulation
-    * TODO: implement in Cython and vectorize n_on (accept numpy  array n_on as input)
+    You can use this method for small n_on < 10.
+    In this case the Li & Ma formula isn't correct any more.
     """
-    from math import factorial as fac
-    from scipy.stats import norm
+    f = np.math.factorial
+
+    # Not vectorised, only works for scalar, integer inputs
+    n_on = int(n_on)
+    n_off = int(n_off)
 
     # Compute tail probability to see n_on or more counts
     probability = 1
     for n in range(0, n_on):
         term_1 = alpha ** n / (1 + alpha) ** (n_off + n + 1)
-        term_2 = fac(n_off + n) / (fac(n) * fac(n_off))
+        term_2 = f(n_off + n) / (f(n) * f(n_off))
         probability -= term_1 * term_2
 
     # Convert probability to a significance
-    significance = norm.isf(probability)
-
-    return significance
+    return norm.isf(probability)
 
 
-def excess_matching_significance(mu_bkg, significance, method='lima'):
+def excess_ul_helene(excess, excess_error, significance):
+    """Compute excess upper limit using the Helene method.
+
+    Reference: http://adsabs.harvard.edu/abs/1984NIMPA.228..120H
+
+    Parameters
+    ----------
+    excess : float
+        Signal excess
+    excess_error : float
+        Gaussian excess error
+        For on / off measurement, use this function to compute it:
+        `~gammapy.stats.excess_error`.
+    significance : float
+        Confidence level significance for the excess upper limit.
+
+    Returns
+    -------
+    excess_ul : float
+        Upper limit for the excess
+    """
+    conf_level1 = significance_to_probability_normal(significance)
+
+    if excess_error <= 0:
+        raise ValueError("Non-positive excess_error: {}".format(excess_error))
+
+    if excess >= 0.0:
+        zeta = excess / excess_error
+        value = zeta / np.sqrt(2.0)
+        integral = (1.0 + erf(value)) / 2.0
+        integral2 = 1.0 - conf_level1 * integral
+        value_old = value
+        value_new = value_old + 0.01
+        if integral > integral2:
+            value_new = 0.0
+        integral = (1.0 + erf(value_new)) / 2.0
+    else:
+        zeta = -excess / excess_error
+        value = zeta / np.sqrt(2.0)
+        integral = 1 - (1.0 + erf(value)) / 2.0
+        integral2 = 1.0 - conf_level1 * integral
+        value_old = value
+        value_new = value_old + 0.01
+        integral = (1.0 + erf(value_new)) / 2.0
+
+    # The 1st Loop is for Speed & 2nd For Precision
+    while integral < integral2:
+        value_old = value_new
+        value_new = value_new + 0.01
+        integral = (1.0 + erf(value_new)) / 2.0
+    value_new = value_old + 0.0000001
+    integral = (1.0 + erf(value_new)) / 2.0
+
+    while integral < integral2:
+        value_new = value_new + 0.0000001
+        integral = (1.0 + erf(value_new)) / 2.0
+    value_new = value_new * np.sqrt(2.0)
+
+    if excess >= 0.0:
+        conf_limit = (value_new + zeta) * excess_error
+    else:
+        conf_limit = (value_new - zeta) * excess_error
+
+    return conf_limit
+
+
+def excess_matching_significance(mu_bkg, significance, method="lima"):
     r"""Compute excess matching a given significance.
 
     This function is the inverse of `significance`.
@@ -430,7 +455,7 @@ def excess_matching_significance(mu_bkg, significance, method='lima'):
 
     Returns
     -------
-    excess : ndarray
+    excess : `numpy.ndarray`
         Excess
 
     See Also
@@ -447,23 +472,15 @@ def excess_matching_significance(mu_bkg, significance, method='lima'):
     mu_bkg = np.asanyarray(mu_bkg, dtype=np.float64)
     significance = np.asanyarray(significance, dtype=np.float64)
 
-    if method == 'simple':
+    if method == "simple":
         return _excess_matching_significance_simple(mu_bkg, significance)
-    elif method == 'lima':
+    elif method == "lima":
         return _excess_matching_significance_lima(mu_bkg, significance)
     else:
-        raise ValueError('Invalid method: {}'.format(method))
+        raise ValueError("Invalid method: {}".format(method))
 
 
-def _excess_matching_significance_simple(mu_bkg, significance):
-    raise NotImplementedError
-
-
-def _excess_matching_significance_lima(mu_bkg, significance):
-    raise NotImplementedError
-
-
-def excess_matching_significance_on_off(n_off, alpha, significance, method='lima'):
+def excess_matching_significance_on_off(n_off, alpha, significance, method="lima"):
     r"""Compute sensitivity of an on-off observation.
 
     This function is the inverse of `significance_on_off`.
@@ -507,12 +524,16 @@ def excess_matching_significance_on_off(n_off, alpha, significance, method='lima
     alpha = np.asanyarray(alpha, dtype=np.float64)
     significance = np.asanyarray(significance, dtype=np.float64)
 
-    if method == 'simple':
+    if method == "simple":
         return _excess_matching_significance_on_off_simple(n_off, alpha, significance)
-    elif method == 'lima':
+    elif method == "lima":
         return _excess_matching_significance_on_off_lima(n_off, alpha, significance)
     else:
-        raise ValueError('Invalid method: {}'.format(method))
+        raise ValueError("Invalid method: {}".format(method))
+
+
+def _excess_matching_significance_simple(mu_bkg, significance):
+    return significance * np.sqrt(mu_bkg)
 
 
 def _excess_matching_significance_on_off_simple(n_off, alpha, significance):
@@ -524,9 +545,35 @@ def _excess_matching_significance_on_off_simple(n_off, alpha, significance):
     return n_on - background(n_off, alpha)
 
 
-def _excess_matching_significance_on_off_lima(n_off, alpha, significance):
-    from scipy.optimize import fsolve
+# This is mostly a copy & paste from _excess_matching_significance_on_off_lima
+# TODO: simplify this, or avoid code duplication?
+# Looking at the formula for significance_lima_on_off, I don't think
+# it can be analytically inverted because the n_on appears inside and outside the log
+# So probably root finding is still needed here.
+def _excess_matching_significance_lima(mu_bkg, significance):
+    # Significance not well-defined for n_on < 0
+    # Return Nan if given significance can't be reached
+    s0 = _significance_lima(n_on=1e-5, mu_bkg=mu_bkg)
+    if s0 >= significance:
+        return np.nan
 
+    def target_significance(n_on):
+        if n_on >= 0:
+            return _significance_lima(n_on, mu_bkg) - significance
+        else:
+            # This high value is to tell the optimizer to stay n_on >= 0
+            return 1e10
+
+    excess_guess = _excess_matching_significance_simple(mu_bkg, significance)
+    n_on_guess = excess_guess + mu_bkg
+
+    # solver options to control robustness / accuracy / speed
+    opts = dict(factor=0.1)
+    n_on = fsolve(target_significance, n_on_guess, **opts)
+    return n_on - mu_bkg
+
+
+def _excess_matching_significance_on_off_lima(n_off, alpha, significance):
     # Significance not well-defined for n_on < 0
     # Return Nan if given significance can't be reached
     s0 = _significance_lima_on_off(n_on=1e-5, n_off=n_off, alpha=alpha)
@@ -537,10 +584,12 @@ def _excess_matching_significance_on_off_lima(n_off, alpha, significance):
         if n_on >= 0:
             return _significance_lima_on_off(n_on, n_off, alpha) - significance
         else:
-            # This high value is to tell the optimiser to stay n_on >= 0
+            # This high value is to tell the optimizer to stay n_on >= 0
             return 1e10
 
-    excess_guess = _excess_matching_significance_on_off_simple(n_off, alpha, significance)
+    excess_guess = _excess_matching_significance_on_off_simple(
+        n_off, alpha, significance
+    )
     n_on_guess = excess_guess + background(n_off, alpha)
 
     # solver options to control robustness / accuracy / speed
@@ -549,4 +598,7 @@ def _excess_matching_significance_on_off_lima(n_off, alpha, significance):
     return n_on - background(n_off, alpha)
 
 
-_excess_matching_significance_on_off_lima = np.vectorize(_excess_matching_significance_on_off_lima)
+_excess_matching_significance_lima = np.vectorize(_excess_matching_significance_lima)
+_excess_matching_significance_on_off_lima = np.vectorize(
+    _excess_matching_significance_on_off_lima
+)
