@@ -351,7 +351,7 @@ class LightCurve(object):
 class LightCurveEstimator(object):
     """Light curve estimator.
 
-    For a usage example see :gp-extra-notebook:`light_curve`.
+    For a usage example see :gp-notebook:`light_curve`.
 
     Parameters
     ----------
