@@ -1,23 +1,23 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 from __future__ import absolute_import, division, print_function, unicode_literals
 import numpy as np
+from scipy.interpolate import InterpolatedUnivariateSpline
 from astropy.utils import lazyproperty
 from astropy import units as u
 from astropy.table import Table
 from ..utils.scripts import make_path
 from ..utils.time import time_ref_from_dict
-from ..utils.fitting import Parameter, Parameters
+from ..utils.fitting import Parameter, Parameters, Model
 
 __all__ = ["PhaseCurveTableModel", "LightCurveTableModel"]
 
 
-class PhaseCurveTableModel(object):
-    """Temporal phase curve model.
+class PhaseCurveTableModel(Model):
+    r"""Temporal phase curve model.
 
-    Phase for a given time is computed as
+    Phase for a given time is computed as:
 
     .. math::
-
         \phi(t) = \phi_0 + f_0(t-t_0) + (1/2)f_1(t-t_0)^2 + (1/6)f_2(t-t_0)^3
 
     Strictly periodic sources such as gamma-ray binaries have ``f1=0`` and ``f2=0``.
@@ -41,7 +41,6 @@ class PhaseCurveTableModel(object):
         Derivatives of the function phi with time of order 1, 2, 3
         in units of ``s^-1, s^-2 & s^-3``, respectively.
 
-
     Examples
     --------
     Create an example phase curve object::
@@ -49,7 +48,7 @@ class PhaseCurveTableModel(object):
         from astropy.table import Table
         from gammapy.utils.scripts import make_path
         from gammapy.time.models import PhaseCurveTableModel
-        filename = make_path('$GAMMAPY_EXTRA/test_datasets/phasecurve_LSI_DC.fits')
+        filename = make_path('$GAMMAPY_DATA/tests/phasecurve_LSI_DC.fits')
         table = Table.read(str(filename))
         phase_curve = PhaseCurveTableModel(table, time_0=43366.275, phase_0=0.0, f0=4.367575e-7, f1=0.0, f2=0.0)
 
@@ -120,7 +119,7 @@ class PhaseCurveTableModel(object):
         return np.interp(x=phase, xp=xp, fp=fp, period=1)
 
 
-class LightCurveTableModel(object):
+class LightCurveTableModel(Model):
     """Temporal light curve model.
 
     The lightcurve is given as a table with columns ``time`` and ``norm``.
@@ -145,7 +144,7 @@ class LightCurveTableModel(object):
     Read an example light curve object:
 
     >>> from gammapy.time.models import LightCurveTableModel
-    >>> path = '$GAMMAPY_EXTRA/test_datasets/models/light_curve/lightcrv_PKSB1222+216.fits'
+    >>> path = '$GAMMAPY_DATA/tests/models/light_curve/lightcrv_PKSB1222+216.fits'
     >>> light_curve = LightCurveTableModel.read(path)
 
     Show basic information about the lightcurve:
@@ -190,11 +189,8 @@ class LightCurveTableModel(object):
 
     @lazyproperty
     def _interpolator(self):
-        from scipy.interpolate import InterpolatedUnivariateSpline
-
         x = self.table["TIME"].data
         y = self.table["NORM"].data
-
         return InterpolatedUnivariateSpline(x, y, k=1)
 
     @lazyproperty
