@@ -1,10 +1,10 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 from __future__ import absolute_import, division, print_function, unicode_literals
 import sys
+from datetime import datetime, timedelta
 import pytest
 import numpy as np
 from numpy.testing import assert_allclose
-from datetime import datetime, timedelta
 from astropy.coordinates import SkyCoord, Angle
 from astropy.time import Time
 import astropy.units as u
@@ -91,7 +91,6 @@ def test_lightcurve_properties_flux(lc):
     sys.version_info >= (3, 7),
     reason="https://github.com/astropy/astropy/issues/7744#issuecomment-419813519",
 )
-@requires_dependency("yaml")
 @pytest.mark.parametrize("format", ["fits", "ascii.ecsv", "ascii.csv"])
 def test_lightcurve_read_write(tmpdir, lc, format):
     filename = str(tmpdir / "spam")
@@ -114,7 +113,6 @@ def test_lightcurve_fvar(lc):
     assert_allclose(fvar_err, 0.07905694150420949, rtol=1e-2)
 
 
-@requires_dependency("scipy")
 def test_lightcurve_chisq(lc):
     chi2, pval = lc.compute_chisq()
     assert_quantity_allclose(chi2, 1.0000000000000001e-11)
@@ -145,7 +143,10 @@ def test_lightcurve_plot_flux_ul(lc, flux_unit):
 @pytest.mark.parametrize(
     "time_format, output",
     [
-        ("mjd", (np.array([55198., 55201]), (np.array([1., 2.]), np.array([1., 5.])))),
+        (
+            "mjd",
+            (np.array([55198.0, 55201]), (np.array([1.0, 2.0]), np.array([1.0, 5.0]))),
+        ),
         (
             "iso",
             (
@@ -171,23 +172,23 @@ def test_lightcurve_plot_time(lc, time_format, output):
 # TODO: Reuse fixtures from spectrum tests
 @pytest.fixture(scope="session")
 def spec_extraction():
-    data_store = DataStore.from_dir("$GAMMAPY_EXTRA/datasets/hess-dl3-dr1/")
+    data_store = DataStore.from_dir("$GAMMAPY_DATA/hess-dl3-dr1/")
     obs_ids = [23523, 23526]
-    obs_list = data_store.obs_list(obs_ids)
+    observations = data_store.get_observations(obs_ids)
 
     target_position = SkyCoord(ra=83.63308, dec=22.01450, unit="deg")
     on_region_radius = Angle("0.11 deg")
     on_region = CircleSkyRegion(center=target_position, radius=on_region_radius)
 
     bkg_estimator = ReflectedRegionsBackgroundEstimator(
-        on_region=on_region, obs_list=obs_list
+        on_region=on_region, observations=observations
     )
     bkg_estimator.run()
 
     e_reco = EnergyBounds.equal_log_spacing(0.2, 100, 50, unit="TeV")  # fine binning
     e_true = EnergyBounds.equal_log_spacing(0.05, 100, 200, unit="TeV")
     extraction = SpectrumExtraction(
-        obs_list=obs_list,
+        observations=observations,
         bkg_estimate=bkg_estimator.result,
         containment_correction=False,
         e_reco=e_reco,
@@ -198,15 +199,13 @@ def spec_extraction():
     return extraction
 
 
-@requires_data("gammapy-extra")
-@requires_dependency("scipy")
-def test_lightcurve_estimator():
-    spec_extract = spec_extraction()
-    lc_estimator = LightCurveEstimator(spec_extract)
+@requires_data("gammapy-data")
+def test_lightcurve_estimator(spec_extraction):
+    lc_estimator = LightCurveEstimator(spec_extraction)
 
     # param
     intervals = []
-    for obs in spec_extract.obs_list:
+    for obs in spec_extraction.observations:
         intervals.append([obs.events.time[0], obs.events.time[-1]])
 
     model = PowerLaw(
@@ -247,12 +246,9 @@ def test_lightcurve_estimator():
     # TODO: add asserts on all measured quantities
 
 
-@requires_data("gammapy-extra")
-@requires_dependency("scipy")
-def test_lightcurve_interval_maker():
-    spec_extract = spec_extraction()
-
-    table = LightCurveEstimator.make_time_intervals_fixes(500, spec_extract)
+@requires_data("gammapy-data")
+def test_lightcurve_interval_maker(spec_extraction):
+    table = LightCurveEstimator.make_time_intervals_fixes(500, spec_extraction)
     intervals = list(zip(table["t_start"], table["t_stop"]))
 
     assert len(intervals) == 9
@@ -260,11 +256,9 @@ def test_lightcurve_interval_maker():
     assert_allclose(t[1].value - t[0].value, 500 / (24 * 3600), rtol=1e-5)
 
 
-@requires_data("gammapy-extra")
-@requires_dependency("scipy")
-def test_lightcurve_adaptative_interval_maker():
-    spec_extract = spec_extraction()
-    lc_estimator = LightCurveEstimator(spec_extract)
+@requires_data("gammapy-data")
+def test_lightcurve_adaptative_interval_maker(spec_extraction):
+    lc_estimator = LightCurveEstimator(spec_extraction)
     separator = [
         Time((53343.94050200008 + 53343.952979345195) / 2, scale="tt", format="mjd")
     ]
@@ -272,7 +266,7 @@ def test_lightcurve_adaptative_interval_maker():
         significance=3,
         significance_method="lima",
         energy_range=[0.2, 100] * u.TeV,
-        spectrum_extraction=spec_extract,
+        spectrum_extraction=spec_extraction,
         separators=separator,
     )
     assert_allclose(table["significance"] >= 3, True)
