@@ -29,22 +29,22 @@ import nbformat
 from ..extern.pathlib import Path
 
 try:
-    gammapy_extra_path = Path(os.environ["GAMMAPY_EXTRA"])
-    HAS_GP_EXTRA = True
+    gammapy_data_path = Path(os.environ["GAMMAPY_DATA"])
+    HAS_GP_DATA = True
 except KeyError:
-    HAS_GP_EXTRA = False
+    HAS_GP_DATA = False
 
 log = logging.getLogger("__name__")
 
 
-class ExtraImage(Image):
-    """Directive to add optional images from gammapy-extra"""
+class DocsImage(Image):
+    """Directive to add optional images from gammapy-data"""
 
     def run(self):
         filename = self.arguments[0]
 
-        if HAS_GP_EXTRA:
-            path = gammapy_extra_path / "figures" / filename
+        if HAS_GP_DATA:
+            path = gammapy_data_path / "figures" / filename
             if not path.is_file():
                 msg = "Error in {} directive: File not found: {}".format(
                     self.name, path
@@ -56,16 +56,16 @@ class ExtraImage(Image):
             self.arguments[0] = "/" + path.absolute().as_posix()
         else:
             self.warning(
-                "GAMMAPY_EXTRA not available. "
+                "GAMMAPY_DATA not available. "
                 "Missing image: name: {!r} filename: {!r}".format(self.name, filename)
             )
             self.options["alt"] = self.arguments[1]
 
-        return super(ExtraImage, self).run()
+        return super(DocsImage, self).run()
 
 
-def notebook_role(name, rawtext, notebook, lineno, inliner, options={}, content=[]):
-    """Link to a notebook on gammapy-extra"""
+def LinkNotebook(name, rawtext, notebook, lineno, inliner, options={}, content=[]):
+    """Link to a notebook"""
 
     # check if file exists in local notebooks folder
     nbfolder = Path("notebooks")
@@ -89,7 +89,7 @@ def make_link_node(rawtext, app, refuri, notebook, options):
     # base = 'https://github.com/gammapy/gammapy/tree/master/notebooks/'
     # base = 'https://nbviewer.jupyter.org/github/gammapy/gammapy/blob/master/notebooks/'
 
-    relpath = refuri.split(str(Path("/gammapy/docs")))[1]
+    relpath = refuri.split(str(Path("/docs")))[1]
     foldersplit = relpath.split(os.sep)
     base = ((".." + os.sep) * (len(foldersplit) - 2)) + "notebooks" + os.sep
     full_name = notebook + ".html"
@@ -100,17 +100,17 @@ def make_link_node(rawtext, app, refuri, notebook, options):
 
 
 def gammapy_sphinx_ext_activate():
-    if HAS_GP_EXTRA:
-        log.info("*** Found GAMMAPY_EXTRA = {}".format(gammapy_extra_path))
+    if HAS_GP_DATA:
+        log.info("*** Found GAMMAPY_DATA = {}".format(gammapy_data_path))
         log.info("*** Nice!")
     else:
-        log.info("*** gammapy-extra *not* found.")
-        log.info("*** Set the GAMMAPY_EXTRA environment variable!")
+        log.info("*** gammapy-data *not* found.")
+        log.info("*** Set the GAMMAPY_DATA environment variable!")
         log.info("*** Docs build will be incomplete.")
 
     # Register our directives and roles with Sphinx
-    register_directive("gp-extra-image", ExtraImage)
-    roles.register_local_role("gp-extra-notebook", notebook_role)
+    register_directive("gp-image", DocsImage)
+    roles.register_local_role("gp-notebook", LinkNotebook)
 
 
 def parse_notebooks(folder, url_docs, git_commit):
@@ -121,9 +121,9 @@ def parse_notebooks(folder, url_docs, git_commit):
     """
 
     DOWNLOAD_CELL = """
-<script type="text/javascript" src="../_static/linksdl.js"></script>
-<div class='alert alert-info'>
-**This is a fixed-text formatted version of a Jupyter notebook.**
+<div class="alert alert-info">
+
+**This is a fixed-text formatted version of a Jupyter notebook**
 
 - Try online [![Binder](https://mybinder.org/badge.svg)](https://mybinder.org/v2/gh/gammapy/gammapy/{git_commit}?urlpath=lab/tree/{nb_filename})
 - You can contribute with your own notebooks in this
