@@ -80,7 +80,11 @@ class Fit(object):
     # and only use `parameters` from `Fit`, not `model`.
     @property
     def _parameters(self):
-        return self._model.parameters
+        try:
+            parameters = self.evaluator.parameters
+        except AttributeError:
+            parameters = self._model.parameters
+        return parameters
 
     def run(self, optimize_opts=None, covariance_opts=None):
         """
@@ -172,7 +176,7 @@ class Fit(object):
 
         return FitResult(
             model=self._model,
-            total_stat=self.total_stat(self._model.parameters),
+            total_stat=self.total_stat(self._parameters),
             backend=backend,
             method=kwargs.get("method", backend),
             **info
